@@ -18,10 +18,19 @@
 //!
 //! Also supports rumdl-specific syntax with same semantics.
 
+use crate::markdownlint_config::markdownlint_to_rumdl_rule_key;
 use crate::utils::code_block_utils::CodeBlockUtils;
 use serde_json::Value as JsonValue;
 use std::collections::{HashMap, HashSet};
 
+/// Normalize a rule name to its canonical form (e.g., "line-length" -> "MD013").
+/// If the rule name is not recognized, returns it uppercase (for forward compatibility).
+fn normalize_rule_name(rule: &str) -> String {
+    markdownlint_to_rumdl_rule_key(rule)
+        .map(|s| s.to_string())
+        .unwrap_or_else(|| rule.to_uppercase())
+}
+
 #[derive(Debug, Clone)]
 pub struct InlineConfig {
     /// Rules that are disabled at each line (1-indexed line -> set of disabled rules)
@@ -110,12 +119,12 @@ impl InlineConfig {
                     if config.file_disabled_rules.contains("*") {
                         // All rules are disabled, so remove from enabled list
                         for rule in rules {
-                            config.file_enabled_rules.remove(rule);
+                            config.file_enabled_rules.remove(&normalize_rule_name(rule));
                         }
                     } else {
                         // Normal case: add to disabled list
                         for rule in rules {
-                            config.file_disabled_rules.insert(rule.to_string());
+                            config.file_disabled_rules.insert(normalize_rule_name(rule));
                         }
                     }
                 }
@@ -132,12 +141,12 @@ impl InlineConfig {
                     if config.file_disabled_rules.contains("*") {
                         // All rules are disabled, so add to enabled list
                         for rule in rules {
-                            config.file_enabled_rules.insert(rule.to_string());
+                            config.file_enabled_rules.insert(normalize_rule_name(rule));
                         }
                     } else {
                         // Normal case: remove from disabled list
                         for rule in rules {
-                            config.file_disabled_rules.remove(rule);
+                            config.file_disabled_rules.remove(&normalize_rule_name(rule));
                         }
                     }
                 }
@@ -165,7 +174,7 @@ impl InlineConfig {
                     line_rules.insert("*".to_string());
                 } else {
                     for rule in rules {
-                        line_rules.insert(rule.to_string());
+                        line_rules.insert(normalize_rule_name(rule));
                     }
                 }
             }
@@ -185,7 +194,7 @@ impl InlineConfig {
                     line_rules.insert("*".to_string());
                 } else {
                     for rule in rules {
-                        line_rules.insert(rule.to_string());
+                        line_rules.insert(normalize_rule_name(rule));
                     }
                 }
             }
@@ -250,12 +259,12 @@ impl InlineConfig {
                                 if currently_disabled.contains("*") {
                                     // All rules are disabled, so remove from enabled list
                                     for rule in rules {
-                                        currently_enabled.remove(rule);
+                                        currently_enabled.remove(&normalize_rule_name(rule));
                                     }
                                 } else {
                                     // Normal case: add to disabled list
                                     for rule in rules {
-                                        currently_disabled.insert(rule.to_string());
+                                        currently_disabled.insert(normalize_rule_name(rule));
                                     }
                                 }
                             }
@@ -272,12 +281,12 @@ impl InlineConfig {
                                 if currently_disabled.contains("*") {
                                     // All rules are disabled, so add to enabled list
                                     for rule in rules {
-                                        currently_enabled.insert(rule.to_string());
+                                        currently_enabled.insert(normalize_rule_name(rule));
                                     }
                                 } else {
                                     // Normal case: remove from disabled list
                                     for rule in rules {
-                                        currently_disabled.remove(rule);
+                                        currently_disabled.remove(&normalize_rule_name(rule));
                                     }
                                 }
                             }
@@ -376,6 +385,26 @@ impl InlineConfig {
     pub fn get_all_rule_configs(&self) -> &HashMap<String, JsonValue> {
         &self.file_rule_config
     }
+
+    /// Export the disabled rules data for storage in FileIndex
+    ///
+    /// Returns (file_disabled_rules, line_disabled_rules) for use in cross-file checks.
+    /// Merges both persistent disables and line-specific disables into a single map.
+    pub fn export_for_file_index(&self) -> (HashSet<String>, HashMap<usize, HashSet<String>>) {
+        let file_disabled = self.file_disabled_rules.clone();
+
+        // Merge disabled_at_line and line_disabled_rules into a single map
+        let mut line_disabled: HashMap<usize, HashSet<String>> = HashMap::new();
+
+        for (line, rules) in &self.disabled_at_line {
+            line_disabled.entry(*line).or_default().extend(rules.clone());
+        }
+        for (line, rules) in &self.line_disabled_rules {
+            line_disabled.entry(*line).or_default().extend(rules.clone());
+        }
+
+        (file_disabled, line_disabled)
+    }
 }
 
 /// Parse a disable comment and return the list of rules (empty vec means all rules)
@@ -385,6 +414,11 @@ pub fn parse_disable_comment(line: &str) -> Option<Vec<&str>> {
         if let Some(start) = line.find(prefix) {
             let after_prefix = &line[start + prefix.len()..];
 
+            // Skip more specific variants (disable-line, disable-next-line, disable-file)
+            if after_prefix.starts_with('-') {
+                continue;
+            }
+
             // Global disable: <!-- markdownlint-disable -->
             if after_prefix.trim_start().starts_with("-->") {
                 return Some(Vec::new()); // Empty vec means all rules
@@ -411,6 +445,11 @@ pub fn parse_enable_comment(line: &str) -> Option<Vec<&str>> {
         if let Some(start) = line.find(prefix) {
             let after_prefix = &line[start + prefix.len()..];
 
+            // Skip more specific variants (enable-file)
+            if after_prefix.starts_with('-') {
+                continue;
+            }
+
             // Global enable: <!-- markdownlint-enable -->
             if after_prefix.trim_start().starts_with("-->") {
                 return Some(Vec::new()); // Empty vec means all rules
@@ -567,6 +606,131 @@ pub fn parse_configure_file_comment(line: &str) -> Option<JsonValue> {
     None
 }
 
+/// Warning about unknown rules in inline config comments
+#[derive(Debug, Clone, PartialEq, Eq)]
+pub struct InlineConfigWarning {
+    /// The line number where the warning occurred (1-indexed)
+    pub line_number: usize,
+    /// The rule name that was not recognized
+    pub rule_name: String,
+    /// The type of inline config comment
+    pub comment_type: String,
+    /// Optional suggestion for similar rule names
+    pub suggestion: Option<String>,
+}
+
+impl InlineConfigWarning {
+    /// Format the warning message
+    pub fn format_message(&self) -> String {
+        if let Some(ref suggestion) = self.suggestion {
+            format!(
+                "Unknown rule in inline {} comment: {} (did you mean: {}?)",
+                self.comment_type, self.rule_name, suggestion
+            )
+        } else {
+            format!(
+                "Unknown rule in inline {} comment: {}",
+                self.comment_type, self.rule_name
+            )
+        }
+    }
+
+    /// Print the warning to stderr with file context
+    pub fn print_warning(&self, file_path: &str) {
+        eprintln!(
+            "\x1b[33m[inline config warning]\x1b[0m {}:{}: {}",
+            file_path,
+            self.line_number,
+            self.format_message()
+        );
+    }
+}
+
+/// Validate all inline config comments in content and return warnings for unknown rules.
+///
+/// This function extracts rule names from all types of inline config comments
+/// (disable, enable, disable-line, disable-next-line, disable-file, enable-file)
+/// and validates them against the known rule alias map.
+pub fn validate_inline_config_rules(content: &str) -> Vec<InlineConfigWarning> {
+    use crate::config::{RULE_ALIAS_MAP, is_valid_rule_name, suggest_similar_key};
+
+    let mut warnings = Vec::new();
+    let all_rule_names: Vec<String> = RULE_ALIAS_MAP.keys().map(|s| s.to_string()).collect();
+
+    for (idx, line) in content.lines().enumerate() {
+        let line_num = idx + 1;
+
+        // Collect all rule names from various comment types
+        let mut rule_entries: Vec<(&str, &str)> = Vec::new();
+
+        // Check each comment type and collect rules with their type names
+        if let Some(rules) = parse_disable_comment(line) {
+            for rule in rules {
+                rule_entries.push((rule, "disable"));
+            }
+        }
+        if let Some(rules) = parse_enable_comment(line) {
+            for rule in rules {
+                rule_entries.push((rule, "enable"));
+            }
+        }
+        if let Some(rules) = parse_disable_line_comment(line) {
+            for rule in rules {
+                rule_entries.push((rule, "disable-line"));
+            }
+        }
+        if let Some(rules) = parse_disable_next_line_comment(line) {
+            for rule in rules {
+                rule_entries.push((rule, "disable-next-line"));
+            }
+        }
+        if let Some(rules) = parse_disable_file_comment(line) {
+            for rule in rules {
+                rule_entries.push((rule, "disable-file"));
+            }
+        }
+        if let Some(rules) = parse_enable_file_comment(line) {
+            for rule in rules {
+                rule_entries.push((rule, "enable-file"));
+            }
+        }
+
+        // Check configure-file comments - rule names are JSON keys
+        if let Some(json_config) = parse_configure_file_comment(line)
+            && let Some(obj) = json_config.as_object()
+        {
+            for rule_name in obj.keys() {
+                if !is_valid_rule_name(rule_name) {
+                    let suggestion = suggest_similar_key(rule_name, &all_rule_names)
+                        .map(|s| if s.starts_with("MD") { s } else { s.to_lowercase() });
+                    warnings.push(InlineConfigWarning {
+                        line_number: line_num,
+                        rule_name: rule_name.to_string(),
+                        comment_type: "configure-file".to_string(),
+                        suggestion,
+                    });
+                }
+            }
+        }
+
+        // Validate each rule name
+        for (rule_name, comment_type) in rule_entries {
+            if !is_valid_rule_name(rule_name) {
+                let suggestion = suggest_similar_key(rule_name, &all_rule_names)
+                    .map(|s| if s.starts_with("MD") { s } else { s.to_lowercase() });
+                warnings.push(InlineConfigWarning {
+                    line_number: line_num,
+                    rule_name: rule_name.to_string(),
+                    comment_type: comment_type.to_string(),
+                    suggestion,
+                });
+            }
+        }
+    }
+
+    warnings
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -665,4 +829,154 @@ Some content after restore
         assert!(!config.is_rule_disabled("MD002", 5));
         assert!(!config.is_rule_disabled("MD003", 5));
     }
+
+    #[test]
+    fn test_validate_inline_config_rules_unknown_rule() {
+        let content = "<!-- rumdl-disable abc -->\nSome content";
+        let warnings = validate_inline_config_rules(content);
+        assert_eq!(warnings.len(), 1);
+        assert_eq!(warnings[0].line_number, 1);
+        assert_eq!(warnings[0].rule_name, "abc");
+        assert_eq!(warnings[0].comment_type, "disable");
+    }
+
+    #[test]
+    fn test_validate_inline_config_rules_valid_rule() {
+        let content = "<!-- rumdl-disable MD001 -->\nSome content";
+        let warnings = validate_inline_config_rules(content);
+        assert!(
+            warnings.is_empty(),
+            "MD001 is a valid rule, should not produce warnings"
+        );
+    }
+
+    #[test]
+    fn test_validate_inline_config_rules_alias() {
+        let content = "<!-- rumdl-disable heading-increment -->\nSome content";
+        let warnings = validate_inline_config_rules(content);
+        assert!(warnings.is_empty(), "heading-increment is a valid alias for MD001");
+    }
+
+    #[test]
+    fn test_validate_inline_config_rules_multiple_unknown() {
+        let content = r#"<!-- rumdl-disable abc xyz -->
+<!-- rumdl-disable-line foo -->
+<!-- markdownlint-disable-next-line bar -->
+"#;
+        let warnings = validate_inline_config_rules(content);
+        assert_eq!(warnings.len(), 4);
+        assert_eq!(warnings[0].rule_name, "abc");
+        assert_eq!(warnings[1].rule_name, "xyz");
+        assert_eq!(warnings[2].rule_name, "foo");
+        assert_eq!(warnings[3].rule_name, "bar");
+    }
+
+    #[test]
+    fn test_validate_inline_config_rules_suggestion() {
+        // "MD00" should suggest "MD001" (or similar)
+        let content = "<!-- rumdl-disable MD00 -->\n";
+        let warnings = validate_inline_config_rules(content);
+        assert_eq!(warnings.len(), 1);
+        // Should have a suggestion since "MD00" is close to "MD001"
+        assert!(warnings[0].suggestion.is_some());
+    }
+
+    #[test]
+    fn test_validate_inline_config_rules_file_comments() {
+        let content = "<!-- rumdl-disable-file nonexistent -->\n<!-- markdownlint-enable-file another_fake -->";
+        let warnings = validate_inline_config_rules(content);
+        assert_eq!(warnings.len(), 2);
+        assert_eq!(warnings[0].comment_type, "disable-file");
+        assert_eq!(warnings[1].comment_type, "enable-file");
+    }
+
+    #[test]
+    fn test_validate_inline_config_rules_global_disable() {
+        // Global disable (no specific rules) should not produce warnings
+        let content = "<!-- rumdl-disable -->\n<!-- markdownlint-enable -->";
+        let warnings = validate_inline_config_rules(content);
+        assert!(warnings.is_empty(), "Global disable/enable should not produce warnings");
+    }
+
+    #[test]
+    fn test_validate_inline_config_rules_mixed_valid_invalid() {
+        // Use MD001 and MD003 which are valid rules; abc and xyz are invalid
+        let content = "<!-- rumdl-disable MD001 abc MD003 xyz -->";
+        let warnings = validate_inline_config_rules(content);
+        assert_eq!(warnings.len(), 2);
+        assert_eq!(warnings[0].rule_name, "abc");
+        assert_eq!(warnings[1].rule_name, "xyz");
+    }
+
+    #[test]
+    fn test_validate_inline_config_rules_configure_file() {
+        // configure-file comments contain rule names as JSON keys
+        let content =
+            r#"<!-- rumdl-configure-file { "MD013": { "line_length": 120 }, "nonexistent": { "foo": true } } -->"#;
+        let warnings = validate_inline_config_rules(content);
+        assert_eq!(warnings.len(), 1);
+        assert_eq!(warnings[0].rule_name, "nonexistent");
+        assert_eq!(warnings[0].comment_type, "configure-file");
+    }
+
+    #[test]
+    fn test_validate_inline_config_rules_markdownlint_variants() {
+        // Test markdownlint-* variants (not just rumdl-*)
+        let content = r#"<!-- markdownlint-disable unknown_rule -->
+<!-- markdownlint-enable another_fake -->
+<!-- markdownlint-disable-line bad_rule -->
+<!-- markdownlint-disable-next-line fake_rule -->
+<!-- markdownlint-disable-file missing_rule -->
+<!-- markdownlint-enable-file nonexistent -->
+"#;
+        let warnings = validate_inline_config_rules(content);
+        assert_eq!(warnings.len(), 6);
+        assert_eq!(warnings[0].rule_name, "unknown_rule");
+        assert_eq!(warnings[1].rule_name, "another_fake");
+        assert_eq!(warnings[2].rule_name, "bad_rule");
+        assert_eq!(warnings[3].rule_name, "fake_rule");
+        assert_eq!(warnings[4].rule_name, "missing_rule");
+        assert_eq!(warnings[5].rule_name, "nonexistent");
+    }
+
+    #[test]
+    fn test_validate_inline_config_rules_markdownlint_configure_file() {
+        let content = r#"<!-- markdownlint-configure-file { "fake_rule": {} } -->"#;
+        let warnings = validate_inline_config_rules(content);
+        assert_eq!(warnings.len(), 1);
+        assert_eq!(warnings[0].rule_name, "fake_rule");
+        assert_eq!(warnings[0].comment_type, "configure-file");
+    }
+
+    #[test]
+    fn test_get_rule_config_from_configure_file() {
+        let content = r#"<!-- markdownlint-configure-file {"MD013": {"line_length": 50}} -->
+
+This is a test line."#;
+
+        let inline_config = InlineConfig::from_content(content);
+        let config_override = inline_config.get_rule_config("MD013");
+
+        assert!(config_override.is_some(), "MD013 config should be found");
+        let json = config_override.unwrap();
+        assert!(json.is_object(), "Config should be an object");
+        let obj = json.as_object().unwrap();
+        assert!(obj.contains_key("line_length"), "Should have line_length key");
+        assert_eq!(obj.get("line_length").unwrap().as_u64().unwrap(), 50);
+    }
+
+    #[test]
+    fn test_get_rule_config_tables_false() {
+        // Test that tables=false inline config is correctly parsed
+        let content = r#"<!-- markdownlint-configure-file {"MD013": {"tables": false}} -->"#;
+
+        let inline_config = InlineConfig::from_content(content);
+        let config_override = inline_config.get_rule_config("MD013");
+
+        assert!(config_override.is_some(), "MD013 config should be found");
+        let json = config_override.unwrap();
+        let obj = json.as_object().unwrap();
+        assert!(obj.contains_key("tables"), "Should have tables key");
+        assert!(!obj.get("tables").unwrap().as_bool().unwrap());
+    }
 }
