@@ -42,46 +42,53 @@ impl MD003HeadingStyle {
         }
 
         // Count all heading styles to determine most prevalent (prevalence-based approach)
-        let mut atx_count = 0;
-        let mut atx_closed_count = 0;
-        let mut setext1_count = 0;
-        let mut setext2_count = 0;
+        let mut style_counts = std::collections::HashMap::new();
 
         for line_info in &ctx.lines {
             if let Some(heading) = &line_info.heading {
+                // Skip invalid headings (e.g., `#NoSpace` which lacks required space after #)
+                if !heading.is_valid {
+                    continue;
+                }
+
                 // Map from LintContext heading style to rules heading style and count
-                match heading.style {
+                let style = match heading.style {
                     crate::lint_context::HeadingStyle::ATX => {
                         if heading.has_closing_sequence {
-                            atx_closed_count += 1;
+                            HeadingStyle::AtxClosed
                         } else {
-                            atx_count += 1;
+                            HeadingStyle::Atx
                         }
                     }
-                    crate::lint_context::HeadingStyle::Setext1 => setext1_count += 1,
-                    crate::lint_context::HeadingStyle::Setext2 => setext2_count += 1,
-                }
+                    crate::lint_context::HeadingStyle::Setext1 => HeadingStyle::Setext1,
+                    crate::lint_context::HeadingStyle::Setext2 => HeadingStyle::Setext2,
+                };
+                *style_counts.entry(style).or_insert(0) += 1;
             }
         }
 
-        // Determine most prevalent style
-        // In case of tie, prefer ATX (most common, widely supported)
-        let max_count = atx_count.max(atx_closed_count).max(setext1_count).max(setext2_count);
-
-        if max_count == 0 {
-            // No headings found, default to ATX
-            return HeadingStyle::Atx;
-        }
-
-        if atx_count == max_count {
-            HeadingStyle::Atx
-        } else if atx_closed_count == max_count {
-            HeadingStyle::AtxClosed
-        } else if setext1_count == max_count {
-            HeadingStyle::Setext1
-        } else {
-            HeadingStyle::Setext2
-        }
+        // Return most prevalent style
+        // In case of tie, prefer ATX as the default (deterministic tiebreaker)
+        style_counts
+            .into_iter()
+            .max_by(|(style_a, count_a), (style_b, count_b)| {
+                match count_a.cmp(count_b) {
+                    std::cmp::Ordering::Equal => {
+                        // Tiebreaker: prefer ATX (most common), then Setext1, then Setext2, then AtxClosed
+                        let priority = |s: &HeadingStyle| match s {
+                            HeadingStyle::Atx => 0,
+                            HeadingStyle::Setext1 => 1,
+                            HeadingStyle::Setext2 => 2,
+                            HeadingStyle::AtxClosed => 3,
+                            _ => 4,
+                        };
+                        priority(style_b).cmp(&priority(style_a)) // Reverse for min priority wins
+                    }
+                    other => other,
+                }
+            })
+            .map(|(style, _)| style)
+            .unwrap_or(HeadingStyle::Atx)
     }
 }
 
@@ -103,6 +110,11 @@ impl Rule for MD003HeadingStyle {
         // Process headings using cached heading information
         for (line_num, line_info) in ctx.lines.iter().enumerate() {
             if let Some(heading) = &line_info.heading {
+                // Skip invalid headings (e.g., `#NoSpace` which lacks required space after #)
+                if !heading.is_valid {
+                    continue;
+                }
+
                 let level = heading.level;
 
                 // Map the cached heading style to the rule's HeadingStyle
@@ -168,8 +180,10 @@ impl Rule for MD003HeadingStyle {
                         let converted_heading =
                             HeadingUtils::convert_heading_style(&heading.text, level as u32, expected_style);
 
-                        // Add indentation
-                        let final_heading = format!("{}{}", " ".repeat(line_info.indent), converted_heading);
+                        // Preserve original indentation (including tabs)
+                        let line = line_info.content(ctx.content);
+                        let original_indent = &line[..line_info.indent];
+                        let final_heading = format!("{original_indent}{converted_heading}");
 
                         // Calculate the correct range for the heading
                         let range = ctx.line_index.line_content_range(line_num + 1);
@@ -299,7 +313,7 @@ mod tests {
     fn test_atx_heading_style() {
         let rule = MD003HeadingStyle::default();
         let content = "# Heading 1\n## Heading 2\n### Heading 3";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
     }
@@ -308,7 +322,7 @@ mod tests {
     fn test_setext_heading_style() {
         let rule = MD003HeadingStyle::new(HeadingStyle::Setext1);
         let content = "Heading 1\n=========\n\nHeading 2\n---------";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
     }
@@ -319,7 +333,7 @@ mod tests {
         let content = "---\ntitle: Test\n---\n\n# Heading 1\n## Heading 2";
 
         // Test should detect headings and apply consistent style
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert!(
             result.is_empty(),
@@ -332,7 +346,7 @@ mod tests {
         // Default rule uses Atx which serves as our "consistent" mode
         let rule = MD003HeadingStyle::default();
         let content = "# Heading 1\n## Heading 2\n### Heading 3";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
     }
@@ -342,7 +356,7 @@ mod tests {
         // Test with consistent style (ATX)
         let rule = MD003HeadingStyle::new(HeadingStyle::Consistent);
         let content = "# Heading 1\n## Heading 2\n### Heading 3";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Make test more resilient
@@ -354,7 +368,7 @@ mod tests {
         // Test with incorrect style
         let rule = MD003HeadingStyle::new(HeadingStyle::Atx);
         let content = "# Heading 1 #\nHeading 2\n-----\n### Heading 3";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert!(
             !result.is_empty(),
@@ -364,7 +378,7 @@ mod tests {
         // Test with setext style
         let rule = MD003HeadingStyle::new(HeadingStyle::Setext1);
         let content = "Heading 1\n=========\nHeading 2\n---------\n### Heading 3";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         // The level 3 heading can't be setext, so it's valid as ATX
         assert!(
@@ -378,7 +392,7 @@ mod tests {
         let rule = MD003HeadingStyle::new(HeadingStyle::SetextWithAtx);
         // Setext for h1/h2, ATX for h3-h6
         let content = "Heading 1\n=========\n\nHeading 2\n---------\n\n### Heading 3\n\n#### Heading 4";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert!(
             result.is_empty(),
@@ -387,7 +401,7 @@ mod tests {
 
         // Test incorrect usage - ATX for h1/h2
         let content_wrong = "# Heading 1\n## Heading 2\n### Heading 3";
-        let ctx_wrong = LintContext::new(content_wrong, crate::config::MarkdownFlavor::Standard);
+        let ctx_wrong = LintContext::new(content_wrong, crate::config::MarkdownFlavor::Standard, None);
         let result_wrong = rule.check(&ctx_wrong).unwrap();
         assert_eq!(
             result_wrong.len(),
@@ -401,7 +415,7 @@ mod tests {
         let rule = MD003HeadingStyle::new(HeadingStyle::SetextWithAtxClosed);
         // Setext for h1/h2, ATX closed for h3-h6
         let content = "Heading 1\n=========\n\nHeading 2\n---------\n\n### Heading 3 ###\n\n#### Heading 4 ####";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert!(
             result.is_empty(),
@@ -410,7 +424,7 @@ mod tests {
 
         // Test incorrect usage - regular ATX for h3+
         let content_wrong = "Heading 1\n=========\n\n### Heading 3\n\n#### Heading 4";
-        let ctx_wrong = LintContext::new(content_wrong, crate::config::MarkdownFlavor::Standard);
+        let ctx_wrong = LintContext::new(content_wrong, crate::config::MarkdownFlavor::Standard, None);
         let result_wrong = rule.check(&ctx_wrong).unwrap();
         assert_eq!(
             result_wrong.len(),
