@@ -64,6 +64,8 @@ impl Rule for MD009TrailingSpaces {
 
         let mut warnings = Vec::new();
 
+        // Store lines in a Vec only for accessing previous line (for list item check)
+        // This is still necessary due to the need to look back at prev_line
         let lines: Vec<&str> = content.lines().collect();
 
         for (line_num, &line) in lines.iter().enumerate() {
@@ -150,7 +152,7 @@ impl Rule for MD009TrailingSpaces {
                 fix: Some(Fix {
                     range: _line_index.line_col_to_byte_range_with_length(
                         line_num + 1,
-                        trimmed.len() + 1,
+                        trimmed.chars().count() + 1,
                         trailing_spaces,
                     ),
                     replacement: if !self.config.strict
@@ -181,6 +183,7 @@ impl Rule for MD009TrailingSpaces {
         }
 
         // For complex cases, we need line-by-line processing but with optimizations
+        // We need to collect lines since we need to look at previous lines for list item checks
         let lines: Vec<&str> = content.lines().collect();
         let mut result = String::with_capacity(content.len()); // Pre-allocate capacity
 
@@ -314,7 +317,7 @@ mod tests {
     fn test_no_trailing_spaces() {
         let rule = MD009TrailingSpaces::default();
         let content = "This is a line\nAnother line\nNo trailing spaces";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
     }
@@ -323,7 +326,7 @@ mod tests {
     fn test_basic_trailing_spaces() {
         let rule = MD009TrailingSpaces::default();
         let content = "Line with spaces   \nAnother line  \nClean line";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         // Default br_spaces=2, so line with 2 spaces is OK
         assert_eq!(result.len(), 1);
@@ -335,7 +338,7 @@ mod tests {
     fn test_fix_basic_trailing_spaces() {
         let rule = MD009TrailingSpaces::default();
         let content = "Line with spaces   \nAnother line  \nClean line";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let fixed = rule.fix(&ctx).unwrap();
         // Line 1: 3 spaces -> removed (doesn't match br_spaces=2)
         // Line 2: 2 spaces -> kept (matches br_spaces=2)
@@ -347,7 +350,7 @@ mod tests {
     fn test_strict_mode() {
         let rule = MD009TrailingSpaces::new(2, true);
         let content = "Line with spaces  \nCode block:  \n```  \nCode with spaces  \n```  ";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         // In strict mode, all trailing spaces are flagged
         assert_eq!(result.len(), 5);
@@ -360,7 +363,7 @@ mod tests {
     fn test_non_strict_mode_with_code_blocks() {
         let rule = MD009TrailingSpaces::new(2, false);
         let content = "Line with spaces  \n```\nCode with spaces  \n```\nOutside code  ";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         // In non-strict mode, code blocks are not checked
         // Line 1 has 2 spaces (= br_spaces), so it's OK
@@ -373,7 +376,7 @@ mod tests {
     fn test_br_spaces_preservation() {
         let rule = MD009TrailingSpaces::new(2, false);
         let content = "Line with two spaces  \nLine with three spaces   \nLine with one space ";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         // br_spaces=2, so lines with exactly 2 spaces are OK
         // Line 2 has 3 spaces (should be removed, not normalized)
@@ -396,7 +399,7 @@ mod tests {
     fn test_empty_lines_with_spaces() {
         let rule = MD009TrailingSpaces::default();
         let content = "Normal line\n   \n  \nAnother line";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2);
         assert_eq!(result[0].message, "Empty line has trailing spaces");
@@ -410,7 +413,7 @@ mod tests {
     fn test_empty_blockquote_lines() {
         let rule = MD009TrailingSpaces::default();
         let content = "> Quote\n>   \n> More quote";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         assert_eq!(result[0].line, 2);
@@ -426,7 +429,7 @@ mod tests {
 
         // Content without final newline
         let content = "First line  \nLast line  ";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         // Last line without newline should have trailing spaces removed
         assert_eq!(result.len(), 1);
@@ -437,7 +440,7 @@ mod tests {
 
         // Content with final newline
         let content_with_newline = "First line  \nLast line  \n";
-        let ctx = LintContext::new(content_with_newline, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content_with_newline, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         // Both lines should preserve br_spaces
         assert!(result.is_empty());
@@ -447,7 +450,7 @@ mod tests {
     fn test_single_trailing_space() {
         let rule = MD009TrailingSpaces::new(2, false);
         let content = "Line with one space ";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         assert_eq!(result[0].message, "Trailing space found");
@@ -457,7 +460,7 @@ mod tests {
     fn test_tabs_not_spaces() {
         let rule = MD009TrailingSpaces::default();
         let content = "Line with tab\t\nLine with spaces  ";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         // Only spaces are checked, not tabs
         assert_eq!(result.len(), 1);
@@ -474,7 +477,7 @@ mod tests {
         content.push('\n');
         content.push_str("Normal paragraph\n> Blockquote\n>\n```\nCode block\n```\n- List item\n");
 
-        let ctx = LintContext::new(&content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(&content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         // Should flag the line with trailing spaces
         assert_eq!(result.len(), 1);
@@ -486,7 +489,7 @@ mod tests {
     fn test_column_positions() {
         let rule = MD009TrailingSpaces::default();
         let content = "Text   ";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         assert_eq!(result[0].column, 5); // After "Text"
@@ -516,7 +519,7 @@ mod tests {
 
         let rule = MD009TrailingSpaces::from_config(&config);
         let content = "Line   ";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
 
@@ -536,20 +539,20 @@ mod tests {
 
         // Test unordered list with empty line
         let content = "- First item\n  \n- Second item";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         // Should not flag the empty line with spaces after list item
         assert!(result.is_empty());
 
         // Test ordered list with empty line
         let content = "1. First item\n  \n2. Second item";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
 
         // Test that non-list empty lines are still flagged
         let content = "Normal paragraph\n  \nAnother paragraph";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         assert_eq!(result[0].line, 2);
@@ -561,7 +564,7 @@ mod tests {
         let rule = MD009TrailingSpaces::default();
 
         let content = "- First item\n  \n- Second item";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         // Should flag the empty line with spaces
         assert_eq!(result.len(), 1);
@@ -575,7 +578,7 @@ mod tests {
         for i in 0..1000 {
             content.push_str(&format!("Line {i} with spaces  \n"));
         }
-        let ctx = LintContext::new(&content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(&content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         // Default br_spaces=2, so all lines with 2 spaces are OK
         assert_eq!(result.len(), 0);
@@ -585,7 +588,7 @@ mod tests {
     fn test_preserve_content_after_fix() {
         let rule = MD009TrailingSpaces::new(2, false);
         let content = "**Bold** text  \n*Italic* text  \n[Link](url)  ";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, "**Bold** text  \n*Italic* text  \n[Link](url)");
     }
@@ -594,7 +597,7 @@ mod tests {
     fn test_nested_blockquotes() {
         let rule = MD009TrailingSpaces::default();
         let content = "> > Nested  \n> >   \n> Normal  ";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         // Line 2 has empty blockquote with 3 spaces, line 3 is last line without newline
         assert_eq!(result.len(), 2);
@@ -613,7 +616,7 @@ mod tests {
         let rule = MD009TrailingSpaces::default();
         // In production, content is normalized to LF at I/O boundary
         let content = "Line with spaces  \nAnother line  ";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         // Line 1 has 2 spaces (= br_spaces) so it's OK
         // Line 2 is last line without newline, so it's flagged
@@ -628,7 +631,7 @@ mod tests {
 
         // Test that 1 trailing space is removed, not normalized to 2
         let content = "Line with one space \nNext line";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         assert_eq!(result[0].line, 1);
@@ -639,7 +642,7 @@ mod tests {
 
         // Test that 3 trailing spaces are removed, not normalized to 2
         let content = "Line with three spaces   \nNext line";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         assert_eq!(result[0].line, 1);
@@ -650,7 +653,7 @@ mod tests {
 
         // Test that exactly 2 trailing spaces are preserved
         let content = "Line with two spaces  \nNext line";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 0); // Should not flag lines with exact br_spaces
 
