@@ -119,10 +119,11 @@ impl Rule for MD019NoMultipleSpaceAtx {
                         let space_count = self.count_spaces_after_marker(trimmed, heading.marker.len());
 
                         if space_count > 1 {
-                            // Normalize to single space
+                            // Normalize to single space, preserving original indentation (including tabs)
+                            let line = line_info.content(ctx.content);
+                            let original_indent = &line[..line_info.indent];
                             lines.push(format!(
-                                "{}{} {}",
-                                " ".repeat(line_info.indent),
+                                "{original_indent}{} {}",
                                 heading.marker,
                                 trimmed[heading.marker.len()..].trim_start()
                             ));
@@ -178,7 +179,7 @@ mod tests {
 
         // Test with heading that has multiple spaces
         let content = "#  Multiple Spaces\n\nRegular content\n\n##   More Spaces";
-        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2); // Should flag both headings
         assert_eq!(result[0].line, 1);
@@ -186,7 +187,7 @@ mod tests {
 
         // Test with proper headings
         let content = "# Single Space\n\n## Also correct";
-        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert!(
             result.is_empty(),
