@@ -86,7 +86,7 @@ impl Rule for MD021NoMultipleSpaceClosedAtx {
         for (line_num, line_info) in ctx.lines.iter().enumerate() {
             if let Some(heading) = &line_info.heading {
                 // Skip headings indented 4+ spaces (they're code blocks)
-                if line_info.indent >= 4 {
+                if line_info.visual_indent >= 4 {
                     continue;
                 }
 
@@ -160,7 +160,7 @@ impl Rule for MD021NoMultipleSpaceClosedAtx {
 
             if let Some(heading) = &line_info.heading {
                 // Skip headings indented 4+ spaces (they're code blocks)
-                if line_info.indent >= 4 {
+                if line_info.visual_indent >= 4 {
                     lines.push(line_info.content(ctx.content).to_string());
                     continue;
                 }
@@ -222,13 +222,13 @@ mod tests {
 
         // Test with correct spacing
         let content = "# Heading 1 #\n## Heading 2 ##\n### Heading 3 ###";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
 
         // Test with multiple spaces
         let content = "#  Heading 1 #\n## Heading 2 ##\n### Heading 3  ###";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2); // Should flag the two headings with multiple spaces
         assert_eq!(result[0].line, 1);
