@@ -74,6 +74,11 @@ impl Rule for MD024NoDuplicateHeading {
             }
 
             if let Some(heading) = &line_info.heading {
+                // Skip invalid headings (e.g., `#NoSpace` which lacks required space after #)
+                if !heading.is_valid {
+                    continue;
+                }
+
                 // Skip empty headings
                 if heading.text.is_empty() {
                     continue;
@@ -124,7 +129,7 @@ impl Rule for MD024NoDuplicateHeading {
                             column: start_col,
                             end_line,
                             end_column: end_col,
-                            severity: Severity::Warning,
+                            severity: Severity::Error,
                             fix: None,
                         });
                     } else {
@@ -144,7 +149,7 @@ impl Rule for MD024NoDuplicateHeading {
                             column: start_col,
                             end_line,
                             end_column: end_col,
-                            severity: Severity::Warning,
+                            severity: Severity::Error,
                             fix: None,
                         });
                     } else {
@@ -160,7 +165,7 @@ impl Rule for MD024NoDuplicateHeading {
                             column: start_col,
                             end_line,
                             end_column: end_col,
-                            severity: Severity::Warning,
+                            severity: Severity::Error,
                             fix: None,
                         });
                     } else {
@@ -228,13 +233,13 @@ mod tests {
     use crate::lint_context::LintContext;
 
     fn run_test(content: &str, config: MD024Config) -> LintResult {
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let rule = MD024NoDuplicateHeading::from_config_struct(config);
         rule.check(&ctx)
     }
 
     fn run_fix_test(content: &str, config: MD024Config) -> Result<String, LintError> {
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let rule = MD024NoDuplicateHeading::from_config_struct(config);
         rule.fix(&ctx)
     }
