@@ -206,8 +206,13 @@ impl Rule for MD026NoTrailingPunctuation {
         // Use pre-computed heading information from LintContext
         for (line_num, line_info) in ctx.lines.iter().enumerate() {
             if let Some(heading) = &line_info.heading {
+                // Skip invalid headings (e.g., `#NoSpace` which lacks required space after #)
+                if !heading.is_valid {
+                    continue;
+                }
+
                 // Skip deeply indented headings (they're code blocks)
-                if line_info.indent >= 4 && matches!(heading.style, crate::lint_context::HeadingStyle::ATX) {
+                if line_info.visual_indent >= 4 && matches!(heading.style, crate::lint_context::HeadingStyle::ATX) {
                     continue;
                 }
 
@@ -299,8 +304,13 @@ impl Rule for MD026NoTrailingPunctuation {
         // Use pre-computed heading information from LintContext
         for (line_num, line_info) in ctx.lines.iter().enumerate() {
             if let Some(heading) = &line_info.heading {
+                // Skip invalid headings (e.g., `#NoSpace` which lacks required space after #)
+                if !heading.is_valid {
+                    continue;
+                }
+
                 // Skip deeply indented headings (they're code blocks)
-                if line_info.indent >= 4 && matches!(heading.style, crate::lint_context::HeadingStyle::ATX) {
+                if line_info.visual_indent >= 4 && matches!(heading.style, crate::lint_context::HeadingStyle::ATX) {
                     continue;
                 }
 
@@ -361,7 +371,7 @@ mod tests {
     fn test_no_trailing_punctuation() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "# This is a heading\n\n## Another heading";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Headings without punctuation should not be flagged");
     }
@@ -370,7 +380,7 @@ mod tests {
     fn test_trailing_period() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "# This is a heading.\n\n## Another one.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2);
         assert_eq!(result[0].line, 1);
@@ -384,7 +394,7 @@ mod tests {
     fn test_trailing_comma() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "# Heading,\n## Sub-heading,";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2);
         assert!(result[0].message.contains("ends with punctuation ','"));
@@ -394,7 +404,7 @@ mod tests {
     fn test_trailing_semicolon() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "# Title;\n## Subtitle;";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2);
         assert!(result[0].message.contains("ends with punctuation ';'"));
@@ -404,7 +414,7 @@ mod tests {
     fn test_custom_punctuation() {
         let rule = MD026NoTrailingPunctuation::new(Some("!".to_string()));
         let content = "# Important!\n## Regular heading.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1, "Only exclamation should be flagged with custom config");
         assert_eq!(result[0].line, 1);
@@ -415,7 +425,7 @@ mod tests {
     fn test_legitimate_question_mark() {
         let rule = MD026NoTrailingPunctuation::new(Some(".,;?".to_string()));
         let content = "# What is this?\n# This is bad.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         // With custom punctuation, legitimate punctuation exceptions don't apply
         assert_eq!(result.len(), 2, "Both should be flagged with custom punctuation");
@@ -425,7 +435,7 @@ mod tests {
     fn test_question_marks_not_in_default() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "# What is Rust?\n# How does it work?\n# Is it fast?";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Question marks are not in default punctuation list");
     }
@@ -434,7 +444,7 @@ mod tests {
     fn test_colons_in_default() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "# FAQ:\n# API Reference:\n# Step 1:\n# Version 2.0:";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(
             result.len(),
@@ -447,7 +457,7 @@ mod tests {
     fn test_fix_atx_headings() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "# Title.\n## Subtitle,\n### Sub-subtitle;";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, "# Title\n## Subtitle\n### Sub-subtitle");
     }
@@ -456,7 +466,7 @@ mod tests {
     fn test_fix_setext_headings() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "Title.\n======\n\nSubtitle,\n---------";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, "Title\n======\n\nSubtitle\n---------");
     }
@@ -465,7 +475,7 @@ mod tests {
     fn test_fix_preserves_trailing_hashes() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "# Title. #\n## Subtitle, ##";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, "# Title #\n## Subtitle ##");
     }
@@ -474,7 +484,7 @@ mod tests {
     fn test_indented_headings() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "   # Title.\n  ## Subtitle.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2, "Indented headings (< 4 spaces) should be checked");
     }
@@ -483,7 +493,7 @@ mod tests {
     fn test_deeply_indented_ignored() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "    # This is code.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Deeply indented lines (4+ spaces) should be ignored");
     }
@@ -492,7 +502,7 @@ mod tests {
     fn test_multiple_punctuation() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "# Title...";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         assert_eq!(result[0].column, 8); // Points to first period
@@ -502,7 +512,7 @@ mod tests {
     fn test_empty_content() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
     }
@@ -511,7 +521,7 @@ mod tests {
     fn test_no_headings() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "This is just text.\nMore text with punctuation.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Non-heading lines should not be checked");
     }
@@ -550,7 +560,7 @@ mod tests {
 
         let rule = MD026NoTrailingPunctuation::from_config(&config);
         let content = "# Title!\n# Another?";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2, "Custom punctuation from config should be used");
     }
@@ -559,7 +569,7 @@ mod tests {
     fn test_fix_removes_punctuation() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "# Title.   \n## Subtitle,  ";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let fixed = rule.fix(&ctx).unwrap();
         // The current implementation doesn't preserve trailing whitespace after punctuation removal
         assert_eq!(fixed, "# Title\n## Subtitle");
@@ -569,12 +579,12 @@ mod tests {
     fn test_final_newline_preservation() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "# Title.\n";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, "# Title\n");
 
         let content_no_newline = "# Title.";
-        let ctx2 = LintContext::new(content_no_newline, crate::config::MarkdownFlavor::Standard);
+        let ctx2 = LintContext::new(content_no_newline, crate::config::MarkdownFlavor::Standard, None);
         let fixed2 = rule.fix(&ctx2).unwrap();
         assert_eq!(fixed2, "# Title");
     }
