@@ -100,10 +100,10 @@ impl MD044ProperNames {
     // Helper function for consistent ASCII normalization
     fn ascii_normalize(s: &str) -> String {
         s.replace(['é', 'è', 'ê', 'ë'], "e")
-            .replace(['à', 'á', 'â', 'ä'], "a")
+            .replace(['à', 'á', 'â', 'ä', 'ã', 'å'], "a")
             .replace(['ï', 'î', 'í', 'ì'], "i")
             .replace(['ü', 'ú', 'ù', 'û'], "u")
-            .replace(['ö', 'ó', 'ò', 'ô'], "o")
+            .replace(['ö', 'ó', 'ò', 'ô', 'õ'], "o")
             .replace('ñ', "n")
             .replace('ç', "c")
     }
@@ -207,8 +207,9 @@ impl MD044ProperNames {
         let hash = fast_hash(content);
         {
             // Use a separate scope for borrowing to minimize lock time
-            let cache = self.content_cache.lock().expect("MD044 content cache mutex poisoned");
-            if let Some(cached) = cache.get(&hash) {
+            if let Ok(cache) = self.content_cache.lock()
+                && let Some(cached) = cache.get(&hash)
+            {
                 return cached.clone();
             }
         }
@@ -257,6 +258,11 @@ impl MD044ProperNames {
                 continue;
             }
 
+            // Skip JSX expressions and MDX comments (MDX flavor)
+            if line_info.in_jsx_expression || line_info.in_mdx_comment {
+                continue;
+            }
+
             // Early return: skip lines that don't contain any potential matches
             let line_lower = line.to_lowercase();
             let has_line_matches = self.config.names.iter().any(|name| {
@@ -332,11 +338,10 @@ impl MD044ProperNames {
             }
         }
 
-        // Store in cache
-        self.content_cache
-            .lock()
-            .expect("MD044 content cache mutex poisoned")
-            .insert(hash, violations.clone());
+        // Store in cache (ignore if mutex is poisoned)
+        if let Ok(mut cache) = self.content_cache.lock() {
+            cache.insert(hash, violations.clone());
+        }
         violations
     }
 
@@ -611,7 +616,7 @@ mod tests {
     use crate::lint_context::LintContext;
 
     fn create_context(content: &str) -> LintContext<'_> {
-        LintContext::new(content, crate::config::MarkdownFlavor::Standard)
+        LintContext::new(content, crate::config::MarkdownFlavor::Standard, None)
     }
 
     #[test]
