@@ -2,6 +2,7 @@ use crate::filtered_lines::FilteredLinesExt;
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, Severity};
 use crate::rules::emphasis_style::EmphasisStyle;
 use crate::utils::emphasis_utils::{find_emphasis_markers, find_single_emphasis_spans, replace_inline_code};
+use crate::utils::skip_context::is_in_mkdocs_markup;
 
 mod md049_config;
 use md049_config::MD049Config;
@@ -106,12 +107,16 @@ impl Rule for MD049EmphasisStyle {
         // Collect all emphasis from the document
         let mut emphasis_info = vec![];
 
-        // Process content lines, automatically skipping front matter, code blocks, and HTML comments
+        // Process content lines, automatically skipping front matter, code blocks, HTML comments, MDX constructs, and math blocks
+        // Math blocks contain LaTeX syntax where _ and * have special meaning
         for line in ctx
             .filtered_lines()
             .skip_front_matter()
             .skip_code_blocks()
             .skip_html_comments()
+            .skip_jsx_expressions()
+            .skip_mdx_comments()
+            .skip_math_blocks()
         {
             // Skip if the line doesn't contain any emphasis markers
             if !line.content.contains('*') && !line.content.contains('_') {
@@ -123,8 +128,22 @@ impl Rule for MD049EmphasisStyle {
             self.collect_emphasis_from_line(line.content, line.line_num, line_start, &mut emphasis_info);
         }
 
-        // Filter out emphasis markers that are inside links
-        emphasis_info.retain(|(_, _, abs_pos, _, _)| !self.is_in_link(ctx, *abs_pos));
+        // Filter out emphasis markers that are inside links or MkDocs markup
+        let lines: Vec<&str> = ctx.content.lines().collect();
+        emphasis_info.retain(|(line_num, col, abs_pos, _, _)| {
+            // Skip if inside a link
+            if self.is_in_link(ctx, *abs_pos) {
+                return false;
+            }
+            // Skip if inside MkDocs markup (Keys, Caret, Mark, icon shortcodes)
+            if let Some(line) = lines.get(*line_num - 1) {
+                let line_pos = col.saturating_sub(1); // Convert 1-indexed col to 0-indexed position
+                if is_in_mkdocs_markup(line, line_pos, ctx.flavor) {
+                    return false;
+                }
+            }
+            true
+        });
 
         match self.config.style {
             EmphasisStyle::Consistent => {
@@ -279,7 +298,7 @@ Also see the [`__init__`][__init__] reference.
 This should be _flagged_ since we're using asterisk style.
 
 [__init__]: https://example.com/__init__.py"#;
-        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Only the real emphasis outside links should be flagged
@@ -295,7 +314,7 @@ This should be _flagged_ since we're using asterisk style.
         let content = r#"Check [*emphasis*](https://example.com/*test*) and inline *real emphasis* text.
 
 [*link*]: https://example.com/*path*"#;
-        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Only the actual emphasis outside links should be flagged
@@ -304,4 +323,73 @@ This should be _flagged_ since we're using asterisk style.
         // Should be the "real emphasis" text on line 1
         assert!(result[0].line == 1);
     }
+
+    #[test]
+    fn test_mkdocs_keys_notation_not_flagged() {
+        // Keys notation uses ++ which shouldn't be confused with emphasis
+        let rule = MD049EmphasisStyle::new(EmphasisStyle::Asterisk);
+        let content = "Press ++ctrl+alt+del++ to restart.";
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::MkDocs, None);
+        let result = rule.check(&ctx).unwrap();
+
+        // Keys notation should not be flagged as emphasis
+        assert!(
+            result.is_empty(),
+            "Keys notation should not be flagged as emphasis. Got: {result:?}"
+        );
+    }
+
+    #[test]
+    fn test_mkdocs_caret_notation_not_flagged() {
+        // Caret notation (^superscript^ and ^^insert^^) should not be flagged
+        let rule = MD049EmphasisStyle::new(EmphasisStyle::Asterisk);
+        let content = "This is ^superscript^ and ^^inserted^^ text.";
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::MkDocs, None);
+        let result = rule.check(&ctx).unwrap();
+
+        assert!(
+            result.is_empty(),
+            "Caret notation should not be flagged as emphasis. Got: {result:?}"
+        );
+    }
+
+    #[test]
+    fn test_mkdocs_mark_notation_not_flagged() {
+        // Mark notation (==highlight==) should not be flagged
+        let rule = MD049EmphasisStyle::new(EmphasisStyle::Asterisk);
+        let content = "This is ==highlighted== text.";
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::MkDocs, None);
+        let result = rule.check(&ctx).unwrap();
+
+        assert!(
+            result.is_empty(),
+            "Mark notation should not be flagged as emphasis. Got: {result:?}"
+        );
+    }
+
+    #[test]
+    fn test_mkdocs_mixed_content_with_real_emphasis() {
+        // Mixed content: MkDocs markup + real emphasis that should be flagged
+        let rule = MD049EmphasisStyle::new(EmphasisStyle::Asterisk);
+        let content = "Press ++ctrl++ and _underscore emphasis_ here.";
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::MkDocs, None);
+        let result = rule.check(&ctx).unwrap();
+
+        // Only the real underscore emphasis should be flagged (not Keys notation)
+        assert_eq!(result.len(), 1, "Expected 1 warning, got: {result:?}");
+        assert!(result[0].message.contains("Emphasis should use * instead of _"));
+    }
+
+    #[test]
+    fn test_mkdocs_icon_shortcode_not_flagged() {
+        // Icon shortcodes like :material-star: should not affect emphasis detection
+        let rule = MD049EmphasisStyle::new(EmphasisStyle::Asterisk);
+        let content = "Click :material-check: and _this should be flagged_.";
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::MkDocs, None);
+        let result = rule.check(&ctx).unwrap();
+
+        // The underscore emphasis should still be flagged
+        assert_eq!(result.len(), 1);
+        assert!(result[0].message.contains("Emphasis should use * instead of _"));
+    }
 }
