@@ -7,6 +7,9 @@ use regex::Regex;
 use std::collections::{HashMap, HashSet};
 use std::sync::LazyLock;
 
+mod md052_config;
+use md052_config::MD052Config;
+
 // Pattern to match reference definitions [ref]: url
 // Note: \S* instead of \S+ to allow empty definitions like [ref]:
 // The capturing group handles nested brackets to support cases like [`union[t, none]`]:
@@ -45,12 +48,27 @@ static URL_WITH_BRACKETS: LazyLock<Regex> =
 /// See [docs/md052.md](../../docs/md052.md) for full documentation, configuration, and examples.
 ///
 /// This rule is triggered when a reference link or image uses a reference that isn't defined.
+///
+/// ## Configuration
+///
+/// - `shortcut-syntax`: Whether to check shortcut reference syntax `[text]` (default: false)
+///
+/// By default, only full (`[text][ref]`) and collapsed (`[text][]`) reference syntax is checked.
+/// Shortcut syntax is ambiguous because `[text]` could be a reference link OR just text in brackets.
 #[derive(Clone, Default)]
-pub struct MD052ReferenceLinkImages {}
+pub struct MD052ReferenceLinkImages {
+    config: MD052Config,
+}
 
 impl MD052ReferenceLinkImages {
     pub fn new() -> Self {
-        Self {}
+        Self {
+            config: MD052Config::default(),
+        }
+    }
+
+    pub fn from_config_struct(config: MD052Config) -> Self {
+        Self { config }
     }
 
     /// Strip surrounding backticks from a string
@@ -77,10 +95,17 @@ impl MD052ReferenceLinkImages {
     ///
     /// These are deterministic patterns from markdown extensions or code examples,
     /// not heuristics. Returns true for:
+    /// - User-configured names via `ignore` config option
     /// - Markdown extensions: [^footnote], [@citation], [!alert], [TOC]
     /// - Programming syntax: [T], [null], [i32], ["string"]
     /// - Descriptive text: [default: value], [0-9]
-    fn is_known_non_reference_pattern(text: &str) -> bool {
+    fn is_known_non_reference_pattern(&self, text: &str) -> bool {
+        // Check user-configured ignore list first (case-insensitive match)
+        // Reference IDs are normalized to lowercase during parsing,
+        // so we use case-insensitive comparison for user convenience
+        if self.config.ignore.iter().any(|p| p.eq_ignore_ascii_case(text)) {
+            return true;
+        }
         // Skip numeric patterns (array indices, ranges)
         if text.chars().all(|c| c.is_ascii_digit()) {
             return true;
@@ -391,11 +416,23 @@ impl MD052ReferenceLinkImages {
                 continue;
             }
 
+            // Skip Quarto/Pandoc citations ([@citation], @citation)
+            // Citations look like reference links but are bibliography references
+            if ctx.flavor == crate::config::MarkdownFlavor::Quarto && ctx.is_in_citation(link.byte_offset) {
+                continue;
+            }
+
+            // Skip links inside shortcodes ({{< ... >}} or {{% ... %}})
+            // Shortcodes may contain template syntax that looks like reference links
+            if ctx.is_in_shortcode(link.byte_offset) {
+                continue;
+            }
+
             if let Some(ref_id) = &link.reference_id {
                 let reference_lower = ref_id.to_lowercase();
 
                 // Skip known non-reference patterns (markdown extensions, code examples)
-                if Self::is_known_non_reference_pattern(ref_id) {
+                if self.is_known_non_reference_pattern(ref_id) {
                     continue;
                 }
 
@@ -490,7 +527,7 @@ impl MD052ReferenceLinkImages {
                 let reference_lower = ref_id.to_lowercase();
 
                 // Skip known non-reference patterns (markdown extensions, code examples)
-                if Self::is_known_non_reference_pattern(ref_id) {
+                if self.is_known_non_reference_pattern(ref_id) {
                     continue;
                 }
 
@@ -557,7 +594,14 @@ impl MD052ReferenceLinkImages {
         covered_ranges.sort_by_key(|&(start, _)| start);
 
         // Handle shortcut references [text] which aren't captured in ctx.links
-        // Need to use regex for these
+        // Only check these if shortcut_syntax is enabled (default: false)
+        // Shortcut syntax is ambiguous because [text] could be a reference link
+        // OR just text in brackets (like spec notation in quotes)
+        if !self.config.shortcut_syntax {
+            return undefined;
+        }
+
+        // Need to use regex for shortcut references
         let lines: Vec<&str> = content.lines().collect();
         in_example_section = false; // Reset for line-by-line processing
 
@@ -690,7 +734,7 @@ impl MD052ReferenceLinkImages {
                         let reference_lower = reference.to_lowercase();
 
                         // Skip known non-reference patterns (markdown extensions, code examples)
-                        if Self::is_known_non_reference_pattern(reference) {
+                        if self.is_known_non_reference_pattern(reference) {
                             continue;
                         }
 
@@ -932,12 +976,12 @@ impl Rule for MD052ReferenceLinkImages {
         self
     }
 
-    fn from_config(_config: &crate::config::Config) -> Box<dyn Rule>
+    fn from_config(config: &crate::config::Config) -> Box<dyn Rule>
     where
         Self: Sized,
     {
-        // Flavor is now accessed from LintContext during check
-        Box::new(MD052ReferenceLinkImages::new())
+        let rule_config = crate::rule_config_serde::load_rule_config::<MD052Config>(config);
+        Box::new(Self::from_config_struct(rule_config))
     }
 }
 
@@ -950,7 +994,7 @@ mod tests {
     fn test_valid_reference_link() {
         let rule = MD052ReferenceLinkImages::new();
         let content = "[text][ref]\n\n[ref]: https://example.com";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -960,7 +1004,7 @@ mod tests {
     fn test_undefined_reference_link() {
         let rule = MD052ReferenceLinkImages::new();
         let content = "[text][undefined]";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -971,7 +1015,7 @@ mod tests {
     fn test_valid_reference_image() {
         let rule = MD052ReferenceLinkImages::new();
         let content = "![alt][img]\n\n[img]: image.jpg";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -981,7 +1025,7 @@ mod tests {
     fn test_undefined_reference_image() {
         let rule = MD052ReferenceLinkImages::new();
         let content = "![alt][missing]";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -992,7 +1036,7 @@ mod tests {
     fn test_case_insensitive_references() {
         let rule = MD052ReferenceLinkImages::new();
         let content = "[Text][REF]\n\n[ref]: https://example.com";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -1002,28 +1046,45 @@ mod tests {
     fn test_shortcut_reference_valid() {
         let rule = MD052ReferenceLinkImages::new();
         let content = "[ref]\n\n[ref]: https://example.com";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
     }
 
     #[test]
-    fn test_shortcut_reference_undefined() {
-        let rule = MD052ReferenceLinkImages::new();
+    fn test_shortcut_reference_undefined_with_shortcut_syntax_enabled() {
+        // Shortcut syntax checking is disabled by default
+        // Enable it to test undefined shortcut references
+        let rule = MD052ReferenceLinkImages::from_config_struct(MD052Config {
+            shortcut_syntax: true,
+            ..Default::default()
+        });
         let content = "[undefined]";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
         assert!(result[0].message.contains("Reference 'undefined' not found"));
     }
 
+    #[test]
+    fn test_shortcut_reference_not_checked_by_default() {
+        // By default, shortcut references are NOT checked (matches markdownlint behavior)
+        let rule = MD052ReferenceLinkImages::new();
+        let content = "[undefined]";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let result = rule.check(&ctx).unwrap();
+
+        // Should be 0 because shortcut_syntax is false by default
+        assert_eq!(result.len(), 0);
+    }
+
     #[test]
     fn test_inline_links_ignored() {
         let rule = MD052ReferenceLinkImages::new();
         let content = "[text](https://example.com)";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -1033,7 +1094,7 @@ mod tests {
     fn test_inline_images_ignored() {
         let rule = MD052ReferenceLinkImages::new();
         let content = "![alt](image.jpg)";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -1043,7 +1104,7 @@ mod tests {
     fn test_references_in_code_blocks_ignored() {
         let rule = MD052ReferenceLinkImages::new();
         let content = "```\n[undefined]\n```\n\n[ref]: https://example.com";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -1053,7 +1114,7 @@ mod tests {
     fn test_references_in_inline_code_ignored() {
         let rule = MD052ReferenceLinkImages::new();
         let content = "`[undefined]`";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // References inside inline code spans should be ignored
@@ -1062,7 +1123,11 @@ mod tests {
 
     #[test]
     fn test_comprehensive_inline_code_detection() {
-        let rule = MD052ReferenceLinkImages::new();
+        // Enable shortcut_syntax to test comprehensive detection
+        let rule = MD052ReferenceLinkImages::from_config_struct(MD052Config {
+            shortcut_syntax: true,
+            ..Default::default()
+        });
         let content = r#"# Test
 
 This `[inside]` should be ignored.
@@ -1080,7 +1145,7 @@ Multiple `[one]` and `[two]` in code ignored, but [three] is not.
 
 `Multiple [refs] in [same] code span` ignored."#;
 
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should only flag: outside, missing, badimg, three (4 total)
@@ -1104,7 +1169,7 @@ Multiple `[one]` and `[two]` in code ignored, but [three] is not.
     fn test_multiple_undefined_references() {
         let rule = MD052ReferenceLinkImages::new();
         let content = "[link1][ref1] [link2][ref2] [link3][ref3]";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 3);
@@ -1117,7 +1182,7 @@ Multiple `[one]` and `[two]` in code ignored, but [three] is not.
     fn test_mixed_valid_and_undefined() {
         let rule = MD052ReferenceLinkImages::new();
         let content = "[valid][ref] [invalid][missing]\n\n[ref]: https://example.com";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -1128,7 +1193,7 @@ Multiple `[one]` and `[two]` in code ignored, but [three] is not.
     fn test_empty_reference() {
         let rule = MD052ReferenceLinkImages::new();
         let content = "[text][]\n\n[ref]: https://example.com";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Empty reference should use the link text as reference
@@ -1139,7 +1204,7 @@ Multiple `[one]` and `[two]` in code ignored, but [three] is not.
     fn test_escaped_brackets_ignored() {
         let rule = MD052ReferenceLinkImages::new();
         let content = "\\[not a link\\]";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -1149,7 +1214,7 @@ Multiple `[one]` and `[two]` in code ignored, but [three] is not.
     fn test_list_items_ignored() {
         let rule = MD052ReferenceLinkImages::new();
         let content = "- [undefined]\n* [another]\n+ [third]";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // List items that look like shortcut references should be ignored
@@ -1158,9 +1223,13 @@ Multiple `[one]` and `[two]` in code ignored, but [three] is not.
 
     #[test]
     fn test_output_example_section_ignored() {
-        let rule = MD052ReferenceLinkImages::new();
+        // Enable shortcut_syntax to test example section handling
+        let rule = MD052ReferenceLinkImages::from_config_struct(MD052Config {
+            shortcut_syntax: true,
+            ..Default::default()
+        });
         let content = "## Output\n\n[undefined]\n\n## Normal Section\n\n[missing]";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Only the reference outside the Output section should be flagged
@@ -1172,7 +1241,7 @@ Multiple `[one]` and `[two]` in code ignored, but [three] is not.
     fn test_reference_definitions_in_code_blocks_ignored() {
         let rule = MD052ReferenceLinkImages::new();
         let content = "[link][ref]\n\n```\n[ref]: https://example.com\n```";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Reference defined in code block should not count
@@ -1184,7 +1253,7 @@ Multiple `[one]` and `[two]` in code ignored, but [three] is not.
     fn test_multiple_references_to_same_undefined() {
         let rule = MD052ReferenceLinkImages::new();
         let content = "[first][missing] [second][missing] [third][missing]";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should only report once per unique reference
@@ -1196,7 +1265,7 @@ Multiple `[one]` and `[two]` in code ignored, but [three] is not.
     fn test_reference_with_special_characters() {
         let rule = MD052ReferenceLinkImages::new();
         let content = "[text][ref-with-hyphens]\n\n[ref-with-hyphens]: https://example.com";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -1215,7 +1284,7 @@ Want to fill out this form?
 <form method="post">
     <input type="email" name="fields[email]" id="drip-email" placeholder="email@domain.com">
 </form>"#;
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(
@@ -1239,7 +1308,11 @@ Want to fill out this form?
 
     #[test]
     fn test_inline_code_not_flagged() {
-        let rule = MD052ReferenceLinkImages::new();
+        // Enable shortcut_syntax to test inline code detection
+        let rule = MD052ReferenceLinkImages::from_config_struct(MD052Config {
+            shortcut_syntax: true,
+            ..Default::default()
+        });
 
         // Test that arrays in inline code are not flagged as references
         let content = r#"# Test
@@ -1253,7 +1326,7 @@ But this [reference] should be flagged.
 And this `[inline code]` should not be flagged.
 "#;
 
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let warnings = rule.check(&ctx).unwrap();
 
         // Should only flag [reference], not the ones in backticks
@@ -1263,7 +1336,11 @@ And this `[inline code]` should not be flagged.
 
     #[test]
     fn test_code_block_references_ignored() {
-        let rule = MD052ReferenceLinkImages::new();
+        // Enable shortcut_syntax to test code block handling
+        let rule = MD052ReferenceLinkImages::from_config_struct(MD052Config {
+            shortcut_syntax: true,
+            ..Default::default()
+        });
 
         let content = r#"# Test
 
@@ -1275,7 +1352,7 @@ And this `[inline code]` should not be flagged.
 [real-undefined] reference outside
 "#;
 
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let warnings = rule.check(&ctx).unwrap();
 
         // Should only flag [real-undefined], not the ones in code block
@@ -1297,7 +1374,7 @@ $ python3 vote.py
 3 votes for: 2
 2 votes for: 3, 4
 ```"#;
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 0, "Should not flag [1:] inside HTML comments");
 
@@ -1305,7 +1382,7 @@ $ python3 vote.py
         let content = r#"<!-- This is [ref1] and [ref2][ref3] -->
 Normal [text][undefined]
 <!-- Another [comment][with] references -->"#;
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(
             result.len(),
@@ -1320,7 +1397,7 @@ Normal [text][undefined]
 [ref2][ref3]
 -->
 [actual][undefined]"#;
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(
             result.len(),
@@ -1336,7 +1413,7 @@ Valid [link][ref]
 ![image][missing]
 
 [ref]: https://example.com"#;
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1, "Should only flag missing image reference");
         assert!(result[0].message.contains("missing"));
@@ -1345,7 +1422,11 @@ Valid [link][ref]
     #[test]
     fn test_frontmatter_ignored() {
         // Test for issue #24 - MD052 should not flag content inside frontmatter
-        let rule = MD052ReferenceLinkImages::new();
+        // Enable shortcut_syntax to test frontmatter handling
+        let rule = MD052ReferenceLinkImages::from_config_struct(MD052Config {
+            shortcut_syntax: true,
+            ..Default::default()
+        });
 
         // Test YAML frontmatter with arrays and references
         let content = r#"---
@@ -1366,7 +1447,7 @@ This is the actual markdown content that should be linted.
 ## Section 1
 
 Some content here."#;
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should only flag [undefined] in the content, not the ["test", "example"] array in frontmatter
@@ -1386,7 +1467,7 @@ tags = ["example", "test"]
 # Content
 
 [missing] reference should be flagged."#;
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(
             result.len(),
@@ -1399,7 +1480,11 @@ tags = ["example", "test"]
     #[test]
     fn test_mkdocs_snippet_markers_not_flagged() {
         // Test for issue #68 - MkDocs snippet selection markers should not be flagged as undefined references
-        let rule = MD052ReferenceLinkImages::new();
+        // Enable shortcut_syntax to test snippet marker handling
+        let rule = MD052ReferenceLinkImages::from_config_struct(MD052Config {
+            shortcut_syntax: true,
+            ..Default::default()
+        });
 
         // Test snippet section markers
         let content = r#"# Document with MkDocs Snippets
@@ -1417,7 +1502,7 @@ More content here.
 <!-- --8<-- [start:another-section] -->
 Content in another section
 <!-- --8<-- [end:another-section] -->"#;
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::MkDocs);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::MkDocs, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should not flag any snippet markers as undefined references
@@ -1436,7 +1521,7 @@ Content with [reference] inside snippet section
 # -8<- [end:section]
 
 Regular [undefined] reference outside snippet markers."#;
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::MkDocs);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::MkDocs, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(
@@ -1453,7 +1538,7 @@ Regular [undefined] reference outside snippet markers."#;
 
 # -8<- [start:section]
 # -8<- [end:section]"#;
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(
@@ -1466,7 +1551,11 @@ Regular [undefined] reference outside snippet markers."#;
     #[test]
     fn test_pandoc_citations_not_flagged() {
         // Test that Pandoc/RMarkdown/Quarto citation syntax is not flagged
-        let rule = MD052ReferenceLinkImages::new();
+        // Enable shortcut_syntax to test citation handling
+        let rule = MD052ReferenceLinkImages::from_config_struct(MD052Config {
+            shortcut_syntax: true,
+            ..Default::default()
+        });
 
         let content = r#"# Research Paper
 
@@ -1477,7 +1566,7 @@ Multiple citations [@citation1; @citation2; @citation3] are also supported.
 
 Regular [undefined] reference should still be flagged.
 "#;
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should only flag the undefined reference, not the citations
@@ -1492,7 +1581,11 @@ Regular [undefined] reference should still be flagged.
     #[test]
     fn test_pandoc_inline_footnotes_not_flagged() {
         // Test that Pandoc inline footnote syntax is not flagged
-        let rule = MD052ReferenceLinkImages::new();
+        // Enable shortcut_syntax to test inline footnote handling
+        let rule = MD052ReferenceLinkImages::from_config_struct(MD052Config {
+            shortcut_syntax: true,
+            ..Default::default()
+        });
 
         let content = r#"# Math Document
 
@@ -1502,7 +1595,7 @@ Another footnote^[with some text and a [link](https://example.com)].
 
 But this [reference] without ^ should be flagged.
 "#;
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should only flag the reference without ^
@@ -1517,7 +1610,11 @@ But this [reference] without ^ should be flagged.
     #[test]
     fn test_github_alerts_not_flagged() {
         // Test for issue #60 - GitHub alerts should not be flagged as undefined references
-        let rule = MD052ReferenceLinkImages::new();
+        // Enable shortcut_syntax to test GitHub alert handling
+        let rule = MD052ReferenceLinkImages::from_config_struct(MD052Config {
+            shortcut_syntax: true,
+            ..Default::default()
+        });
 
         // Test various GitHub alert types
         let content = r#"# Document with GitHub Alerts
@@ -1538,7 +1635,7 @@ But this [reference] without ^ should be flagged.
 > This is a caution alert.
 
 Regular content with [undefined] reference."#;
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should only flag the undefined reference, not the GitHub alerts
@@ -1556,7 +1653,7 @@ Regular content with [undefined] reference."#;
 > Multiple lines are allowed.
 
 [something] is mentioned but not defined."#;
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should flag only the [something] outside blockquotes
@@ -1570,10 +1667,133 @@ Regular content with [undefined] reference."#;
 > See [reference] for more details.
 
 [reference]: https://example.com"#;
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should not flag anything - [!NOTE] is GitHub alert and [reference] is defined
         assert_eq!(result.len(), 0, "Should not flag GitHub alerts or defined references");
     }
+
+    #[test]
+    fn test_ignore_config() {
+        // Test that user-configured ignore list is respected
+        let config = MD052Config {
+            shortcut_syntax: true,
+            ignore: vec!["Vec".to_string(), "HashMap".to_string(), "Option".to_string()],
+        };
+        let rule = MD052ReferenceLinkImages::from_config_struct(config);
+
+        let content = r#"# Document with Custom Types
+
+Use [Vec] for dynamic arrays.
+Use [HashMap] for key-value storage.
+Use [Option] for nullable values.
+Use [Result] for error handling.
+"#;
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let result = rule.check(&ctx).unwrap();
+
+        // Should only flag [Result] because it's not in ignore
+        assert_eq!(result.len(), 1, "Should only flag names not in ignore");
+        assert!(result[0].message.contains("Result"));
+    }
+
+    #[test]
+    fn test_ignore_case_insensitive() {
+        // Test that ignore list is case-insensitive
+        let config = MD052Config {
+            shortcut_syntax: true,
+            ignore: vec!["Vec".to_string()],
+        };
+        let rule = MD052ReferenceLinkImages::from_config_struct(config);
+
+        let content = r#"# Case Insensitivity Test
+
+[Vec] should be ignored.
+[vec] should also be ignored (different case, same match).
+[VEC] should also be ignored (different case, same match).
+[undefined] should be flagged (not in ignore list).
+"#;
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let result = rule.check(&ctx).unwrap();
+
+        // Should only flag [undefined] because ignore is case-insensitive
+        assert_eq!(result.len(), 1, "Should only flag non-ignored reference");
+        assert!(result[0].message.contains("undefined"));
+    }
+
+    #[test]
+    fn test_ignore_empty_by_default() {
+        // Test that empty ignore list doesn't affect existing behavior
+        let rule = MD052ReferenceLinkImages::new();
+
+        let content = "[text][undefined]";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let result = rule.check(&ctx).unwrap();
+
+        // Should still flag undefined references
+        assert_eq!(result.len(), 1);
+        assert!(result[0].message.contains("undefined"));
+    }
+
+    #[test]
+    fn test_ignore_with_reference_links() {
+        // Test ignore list with full reference link syntax [text][ref]
+        let config = MD052Config {
+            shortcut_syntax: false,
+            ignore: vec!["CustomType".to_string()],
+        };
+        let rule = MD052ReferenceLinkImages::from_config_struct(config);
+
+        let content = r#"# Test
+
+See [documentation][CustomType] for details.
+See [other docs][MissingRef] for more.
+"#;
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let result = rule.check(&ctx).unwrap();
+
+        // Debug: print warnings if test fails
+        for (i, w) in result.iter().enumerate() {
+            eprintln!("Warning {}: {}", i, w.message);
+        }
+
+        // Should flag [MissingRef] but not [CustomType]
+        // Note: reference IDs are lowercased in the message
+        assert_eq!(result.len(), 1, "Expected 1 warning, got {}", result.len());
+        assert!(
+            result[0].message.contains("missingref"),
+            "Expected 'missingref' in message: {}",
+            result[0].message
+        );
+    }
+
+    #[test]
+    fn test_ignore_multiple() {
+        // Test multiple ignored names work correctly
+        let config = MD052Config {
+            shortcut_syntax: true,
+            ignore: vec![
+                "i32".to_string(),
+                "u64".to_string(),
+                "String".to_string(),
+                "Arc".to_string(),
+                "Mutex".to_string(),
+            ],
+        };
+        let rule = MD052ReferenceLinkImages::from_config_struct(config);
+
+        let content = r#"# Types
+
+[i32] [u64] [String] [Arc] [Mutex] [Box]
+"#;
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let result = rule.check(&ctx).unwrap();
+
+        // Note: i32 and u64 are already in the hardcoded list, so they'd be skipped anyway
+        // String is NOT in the hardcoded list, so we test that the user config works
+        // [Box] should be flagged (not in ignore)
+        assert_eq!(result.len(), 1);
+        assert!(result[0].message.contains("Box"));
+    }
 }
