@@ -138,11 +138,21 @@ impl MD053LinkImageReferenceDefinitions {
             return true;
         }
 
-        // Skip descriptive patterns with colon like [default: the project root]
-        // But allow simple numeric ranges which are handled above
-        // And allow patterns with backticks (valid code references)
+        // Skip descriptive prose patterns with colon like [default: the project root]
+        // But allow reference-style patterns like [RFC: 1234], [Issue: 42], [See: Section 2]
+        // These are distinguished by having a short prefix (typically 1-2 words) before the colon
         if text.contains(':') && text.contains(' ') && !text.contains('`') {
-            return true;
+            // Check if this looks like a reference pattern (short prefix before colon)
+            // vs a prose description (longer text before colon)
+            if let Some((before_colon, _)) = text.split_once(':') {
+                let before_trimmed = before_colon.trim();
+                // Count words before colon - references typically have 1-2 words
+                let word_count = before_trimmed.split_whitespace().count();
+                // If there are 3+ words before the colon, it's likely prose
+                if word_count >= 3 {
+                    return true;
+                }
+            }
         }
 
         // Skip alert/admonition patterns like [!WARN], [!NOTE], etc.
@@ -313,7 +323,18 @@ impl MD053LinkImageReferenceDefinitions {
             }
         }
 
-        // 3. Find shortcut references [ref] not already handled by DocumentStructure.links
+        // 3. Add usages from footnote references (e.g., [^1], [^note])
+        // pulldown-cmark returns the id without the ^ prefix, but definitions have it
+        for footnote_ref in &ctx.footnote_refs {
+            // Ensure the footnote reference is not inside a code block line
+            if !ctx.line_info(footnote_ref.line).is_some_and(|info| info.in_code_block) {
+                // Add ^ prefix to match definition format
+                let ref_id = format!("^{}", footnote_ref.id);
+                usages.insert(ref_id.to_lowercase());
+            }
+        }
+
+        // 4. Find shortcut references [ref] not already handled by DocumentStructure.links
         //    and ensure they are not within code spans or code blocks.
         // Cache code spans once before the loop
         let code_spans = ctx.code_spans();
@@ -569,7 +590,7 @@ mod tests {
     fn test_used_reference_link() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[text][ref]\n\n[ref]: https://example.com";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -579,7 +600,7 @@ mod tests {
     fn test_unused_reference_definition() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[unused]: https://example.com";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -590,7 +611,7 @@ mod tests {
     fn test_used_reference_image() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "![alt][img]\n\n[img]: image.jpg";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -600,7 +621,7 @@ mod tests {
     fn test_case_insensitive_matching() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[Text][REF]\n\n[ref]: https://example.com";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -610,7 +631,7 @@ mod tests {
     fn test_shortcut_reference() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[ref]\n\n[ref]: https://example.com";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -620,7 +641,7 @@ mod tests {
     fn test_collapsed_reference() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[ref][]\n\n[ref]: https://example.com";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -630,7 +651,7 @@ mod tests {
     fn test_multiple_unused_definitions() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[unused1]: url1\n[unused2]: url2\n[unused3]: url3";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 3);
@@ -646,7 +667,7 @@ mod tests {
     fn test_mixed_used_and_unused() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[used]\n\n[used]: url1\n[unused]: url2";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -657,7 +678,7 @@ mod tests {
     fn test_multiline_definition() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[ref]: https://example.com\n  \"Title on next line\"";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1); // Still unused
@@ -667,7 +688,7 @@ mod tests {
     fn test_reference_in_code_block() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "```\n[ref]\n```\n\n[ref]: https://example.com";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Reference used only in code block is still considered unused
@@ -678,7 +699,7 @@ mod tests {
     fn test_reference_in_inline_code() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "`[ref]`\n\n[ref]: https://example.com";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Reference in inline code is not a usage
@@ -689,7 +710,7 @@ mod tests {
     fn test_escaped_reference() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[example\\-ref]\n\n[example-ref]: https://example.com";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should match despite escaping
@@ -700,7 +721,7 @@ mod tests {
     fn test_duplicate_definitions() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[ref]: url1\n[ref]: url2\n\n[ref]";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should flag the duplicate definition even though it's used (matches markdownlint)
@@ -712,7 +733,7 @@ mod tests {
         // MD053 is warning-only, fix should return original content
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[used]\n\n[used]: url1\n[unused]: url2\n\nMore content";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let fixed = rule.fix(&ctx).unwrap();
 
         assert_eq!(fixed, content);
@@ -723,7 +744,7 @@ mod tests {
         // MD053 is warning-only, fix should preserve all content
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "Content\n\n[unused]: url\n\nMore content";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let fixed = rule.fix(&ctx).unwrap();
 
         assert_eq!(fixed, content);
@@ -734,7 +755,7 @@ mod tests {
         // MD053 is warning-only, fix should not remove anything
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[unused1]: url1\n[unused2]: url2\n[unused3]: url3";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let fixed = rule.fix(&ctx).unwrap();
 
         assert_eq!(fixed, content);
@@ -744,7 +765,7 @@ mod tests {
     fn test_special_characters_in_reference() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[ref-with_special.chars]\n\n[ref-with_special.chars]: url";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -754,7 +775,7 @@ mod tests {
     fn test_find_definitions() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[ref1]: url1\n[ref2]: url2\nSome text\n[ref3]: url3";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let defs = rule.find_definitions(&ctx);
 
         assert_eq!(defs.len(), 3);
@@ -767,7 +788,7 @@ mod tests {
     fn test_find_usages() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[text][ref1] and [ref2] and ![img][ref3]";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let usages = rule.find_usages(&ctx);
 
         assert!(usages.contains("ref1"));
@@ -784,7 +805,7 @@ mod tests {
         let rule = MD053LinkImageReferenceDefinitions::from_config_struct(config);
 
         let content = "[todo]: https://example.com/todo\n[draft]: https://example.com/draft\n[unused]: https://example.com/unused";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should only flag "unused", not "todo" or "draft"
@@ -803,7 +824,7 @@ mod tests {
         let rule = MD053LinkImageReferenceDefinitions::from_config_struct(config);
 
         let content = "[todo]: https://example.com/todo\n[unused]: https://example.com/unused";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should only flag "unused", not "todo" (matches "TODO" case-insensitively)
@@ -839,7 +860,7 @@ mod tests {
         let rule = MD053LinkImageReferenceDefinitions::from_config_struct(config);
 
         let content = "[template]: https://example.com/template\n[unused]: https://example.com/unused\n\nSome content.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let fixed = rule.fix(&ctx).unwrap();
 
         // Should keep everything since MD053 doesn't fix
@@ -850,7 +871,7 @@ mod tests {
     fn test_duplicate_definitions_exact_case() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[ref]: url1\n[ref]: url2\n[ref]: url3";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should have 2 duplicate warnings (for the 2nd and 3rd definitions)
@@ -866,7 +887,7 @@ mod tests {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content =
             "[method resolution order]: url1\n[Method Resolution Order]: url2\n[METHOD RESOLUTION ORDER]: url3";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should have 2 duplicate warnings (for the 2nd and 3rd definitions)
@@ -884,7 +905,7 @@ mod tests {
     fn test_duplicate_and_unused() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[used]\n[used]: url1\n[used]: url2\n[unused]: url3";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should have 1 duplicate warning and 1 unused warning
@@ -902,7 +923,7 @@ mod tests {
         let rule = MD053LinkImageReferenceDefinitions::new();
         // Even if used, duplicates should still be reported
         let content = "[ref]\n\n[ref]: url1\n[ref]: url2";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should have 1 duplicate warning (no unused since it's referenced)
@@ -918,7 +939,7 @@ mod tests {
     fn test_no_duplicate_different_ids() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[ref1]: url1\n[ref2]: url2\n[ref3]: url3";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should have no duplicate warnings, only unused warnings
@@ -931,7 +952,7 @@ mod tests {
         let rule = MD053LinkImageReferenceDefinitions::new();
         // Most popular comment pattern: [//]: # (comment)
         let content = "[//]: # (This is a comment)\n\nSome regular text.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should not report as unused - it's recognized as a comment
@@ -943,7 +964,7 @@ mod tests {
         let rule = MD053LinkImageReferenceDefinitions::new();
         // Semantic comment pattern: [comment]: # (text)
         let content = "[comment]: # (This is a semantic comment)\n\n[note]: # (This is a note)";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should not report either as unused
@@ -955,7 +976,7 @@ mod tests {
         let rule = MD053LinkImageReferenceDefinitions::new();
         // Task tracking patterns: [todo]: # and [fixme]: #
         let content = "[todo]: # (Add more examples)\n[fixme]: # (Fix this later)\n[hack]: # (Temporary workaround)";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should not report any as unused
@@ -967,7 +988,7 @@ mod tests {
         let rule = MD053LinkImageReferenceDefinitions::new();
         // Any reference with just "#" as URL should be treated as a comment
         let content = "[anything]: #\n[ref]: #\n\nSome text.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should not report as unused - fragment-only URLs are often comments
@@ -979,7 +1000,7 @@ mod tests {
         let rule = MD053LinkImageReferenceDefinitions::new();
         // Mix of comment and real reference - only real one should be flagged if unused
         let content = "[//]: # (This is a comment)\n[real-ref]: https://example.com\n\nSome text.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should only report the real reference as unused
@@ -992,7 +1013,7 @@ mod tests {
         let rule = MD053LinkImageReferenceDefinitions::new();
         // Comment pattern with a fragment section (still a comment)
         let content = "[//]: #section (Comment about section)\n\nSome text.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should not report as unused - it's still a comment pattern
@@ -1031,4 +1052,80 @@ mod tests {
             "Real URL should not be recognized as comment"
         );
     }
+
+    #[test]
+    fn test_reference_with_colon_in_name() {
+        // References containing colons and spaces should be recognized as valid references
+        let rule = MD053LinkImageReferenceDefinitions::new();
+        let content = "Check [RFC: 1234] for specs.\n\n[RFC: 1234]: https://example.com\n";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let result = rule.check(&ctx).unwrap();
+
+        assert!(
+            result.is_empty(),
+            "Reference with colon should be recognized as used, got warnings: {result:?}"
+        );
+    }
+
+    #[test]
+    fn test_reference_with_colon_various_styles() {
+        // Test various RFC-style and similar references with colons
+        let rule = MD053LinkImageReferenceDefinitions::new();
+        let content = r#"See [RFC: 1234] and [Issue: 42] and [PR: 100].
+
+[RFC: 1234]: https://example.com/rfc1234
+[Issue: 42]: https://example.com/issue42
+[PR: 100]: https://example.com/pr100
+"#;
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let result = rule.check(&ctx).unwrap();
+
+        assert!(
+            result.is_empty(),
+            "All colon-style references should be recognized as used, got warnings: {result:?}"
+        );
+    }
+
+    #[test]
+    fn test_should_skip_pattern_allows_rfc_style() {
+        // Verify that should_skip_pattern does NOT skip RFC-style references with colons
+        // This tests the fix for the bug where references with ": " were incorrectly skipped
+        assert!(
+            !MD053LinkImageReferenceDefinitions::should_skip_pattern("RFC: 1234"),
+            "RFC-style references should NOT be skipped"
+        );
+        assert!(
+            !MD053LinkImageReferenceDefinitions::should_skip_pattern("Issue: 42"),
+            "Issue-style references should NOT be skipped"
+        );
+        assert!(
+            !MD053LinkImageReferenceDefinitions::should_skip_pattern("PR: 100"),
+            "PR-style references should NOT be skipped"
+        );
+        assert!(
+            !MD053LinkImageReferenceDefinitions::should_skip_pattern("See: Section 2"),
+            "References with 'See:' should NOT be skipped"
+        );
+        assert!(
+            !MD053LinkImageReferenceDefinitions::should_skip_pattern("foo:bar"),
+            "References without space after colon should NOT be skipped"
+        );
+    }
+
+    #[test]
+    fn test_should_skip_pattern_skips_prose() {
+        // Verify that prose-like patterns (3+ words before colon) are still skipped
+        assert!(
+            MD053LinkImageReferenceDefinitions::should_skip_pattern("default value is: something"),
+            "Prose with 3+ words before colon SHOULD be skipped"
+        );
+        assert!(
+            MD053LinkImageReferenceDefinitions::should_skip_pattern("this is a label: description"),
+            "Prose with 4 words before colon SHOULD be skipped"
+        );
+        assert!(
+            MD053LinkImageReferenceDefinitions::should_skip_pattern("the project root: path/to/dir"),
+            "Prose-like descriptions SHOULD be skipped"
+        );
+    }
 }
