@@ -1,6 +1,6 @@
 use crate::rule::{LintError, LintResult, LintWarning, Rule, Severity};
 use crate::utils::range_utils::calculate_line_range;
-use crate::utils::table_utils::TableUtils;
+use crate::utils::table_utils::{TableBlock, TableUtils};
 
 mod md055_config;
 use md055_config::MD055Config;
@@ -93,6 +93,61 @@ impl MD055TablePipeStyle {
         Self { config }
     }
 
+    /// Determine the most prevalent table style in a table block
+    fn determine_table_style(&self, table_block: &TableBlock, lines: &[&str]) -> Option<&'static str> {
+        let mut leading_and_trailing_count = 0;
+        let mut no_leading_or_trailing_count = 0;
+        let mut leading_only_count = 0;
+        let mut trailing_only_count = 0;
+
+        // Count style of header row
+        if let Some(style) = TableUtils::determine_pipe_style(lines[table_block.header_line]) {
+            match style {
+                "leading_and_trailing" => leading_and_trailing_count += 1,
+                "no_leading_or_trailing" => no_leading_or_trailing_count += 1,
+                "leading_only" => leading_only_count += 1,
+                "trailing_only" => trailing_only_count += 1,
+                _ => {}
+            }
+        }
+
+        // Count style of content rows
+        for &line_idx in &table_block.content_lines {
+            if let Some(style) = TableUtils::determine_pipe_style(lines[line_idx]) {
+                match style {
+                    "leading_and_trailing" => leading_and_trailing_count += 1,
+                    "no_leading_or_trailing" => no_leading_or_trailing_count += 1,
+                    "leading_only" => leading_only_count += 1,
+                    "trailing_only" => trailing_only_count += 1,
+                    _ => {}
+                }
+            }
+        }
+
+        // Determine most prevalent style
+        // In case of tie, prefer leading_and_trailing (most common, widely supported)
+        let max_count = leading_and_trailing_count
+            .max(no_leading_or_trailing_count)
+            .max(leading_only_count)
+            .max(trailing_only_count);
+
+        if max_count > 0 {
+            if leading_and_trailing_count == max_count {
+                Some("leading_and_trailing")
+            } else if no_leading_or_trailing_count == max_count {
+                Some("no_leading_or_trailing")
+            } else if leading_only_count == max_count {
+                Some("leading_only")
+            } else if trailing_only_count == max_count {
+                Some("trailing_only")
+            } else {
+                None
+            }
+        } else {
+            None
+        }
+    }
+
     /// Fix a table row to match the target style
     /// Uses surgical fixes: only adds/removes pipes, preserves all user formatting
     fn fix_table_row(&self, line: &str, target_style: &str) -> String {
@@ -213,59 +268,13 @@ impl Rule for MD055TablePipeStyle {
 
         // Process each table block
         for table_block in table_blocks {
-            let mut table_style = None;
-
             // First pass: determine the table's style for "consistent" mode
             // Count all rows to determine most prevalent style (prevalence-based approach)
-            if configured_style == "consistent" {
-                let mut leading_and_trailing_count = 0;
-                let mut no_leading_or_trailing_count = 0;
-                let mut leading_only_count = 0;
-                let mut trailing_only_count = 0;
-
-                // Count style of header row
-                if let Some(style) = TableUtils::determine_pipe_style(lines[table_block.header_line]) {
-                    match style {
-                        "leading_and_trailing" => leading_and_trailing_count += 1,
-                        "no_leading_or_trailing" => no_leading_or_trailing_count += 1,
-                        "leading_only" => leading_only_count += 1,
-                        "trailing_only" => trailing_only_count += 1,
-                        _ => {}
-                    }
-                }
-
-                // Count style of content rows
-                for &line_idx in &table_block.content_lines {
-                    if let Some(style) = TableUtils::determine_pipe_style(lines[line_idx]) {
-                        match style {
-                            "leading_and_trailing" => leading_and_trailing_count += 1,
-                            "no_leading_or_trailing" => no_leading_or_trailing_count += 1,
-                            "leading_only" => leading_only_count += 1,
-                            "trailing_only" => trailing_only_count += 1,
-                            _ => {}
-                        }
-                    }
-                }
-
-                // Determine most prevalent style
-                // In case of tie, prefer leading_and_trailing (most common, widely supported)
-                let max_count = leading_and_trailing_count
-                    .max(no_leading_or_trailing_count)
-                    .max(leading_only_count)
-                    .max(trailing_only_count);
-
-                if max_count > 0 {
-                    if leading_and_trailing_count == max_count {
-                        table_style = Some("leading_and_trailing");
-                    } else if no_leading_or_trailing_count == max_count {
-                        table_style = Some("no_leading_or_trailing");
-                    } else if leading_only_count == max_count {
-                        table_style = Some("leading_only");
-                    } else if trailing_only_count == max_count {
-                        table_style = Some("trailing_only");
-                    }
-                }
-            }
+            let table_style = if configured_style == "consistent" {
+                self.determine_table_style(table_block, &lines)
+            } else {
+                None
+            };
 
             // Determine target style for this table
             let target_style = if configured_style == "consistent" {
@@ -274,12 +283,33 @@ impl Rule for MD055TablePipeStyle {
                 configured_style
             };
 
-            // Check all rows in the table
-            let all_lines = std::iter::once(table_block.header_line)
+            // Collect all table lines for building the whole-table fix
+            let all_line_indices: Vec<usize> = std::iter::once(table_block.header_line)
                 .chain(std::iter::once(table_block.delimiter_line))
-                .chain(table_block.content_lines.iter().copied());
+                .chain(table_block.content_lines.iter().copied())
+                .collect();
 
-            for line_idx in all_lines {
+            // Build the whole-table fix once for all warnings in this table
+            // This ensures that applying Quick Fix on any row fixes the entire table
+            let table_start_line = table_block.start_line + 1; // Convert to 1-indexed
+            let table_end_line = table_block.end_line + 1; // Convert to 1-indexed
+
+            // Build the complete fixed table content
+            let mut fixed_table_lines: Vec<String> = Vec::with_capacity(all_line_indices.len());
+            for &line_idx in &all_line_indices {
+                let line = lines[line_idx];
+                let fixed_line = self.fix_table_row(line, target_style);
+                if line_idx < lines.len() - 1 {
+                    fixed_table_lines.push(format!("{fixed_line}\n"));
+                } else {
+                    fixed_table_lines.push(fixed_line);
+                }
+            }
+            let table_replacement = fixed_table_lines.concat();
+            let table_range = line_index.multi_line_range(table_start_line, table_end_line);
+
+            // Check all rows in the table
+            for &line_idx in &all_line_indices {
                 let line = lines[line_idx];
                 if let Some(current_style) = TableUtils::determine_pipe_style(line) {
                     // Only flag lines with actual style mismatches
@@ -299,7 +329,8 @@ impl Rule for MD055TablePipeStyle {
                             }
                         );
 
-                        let fixed_line = self.fix_table_row(line, target_style);
+                        // Each warning uses the same whole-table fix
+                        // This ensures Quick Fix on any row fixes the entire table
                         warnings.push(LintWarning {
                             rule_name: Some(self.name().to_string()),
                             severity: Severity::Warning,
@@ -309,12 +340,8 @@ impl Rule for MD055TablePipeStyle {
                             end_line,
                             end_column: end_col,
                             fix: Some(crate::rule::Fix {
-                                range: line_index.whole_line_range(line_idx + 1),
-                                replacement: if line_idx < lines.len() - 1 {
-                                    format!("{fixed_line}\n")
-                                } else {
-                                    fixed_line
-                                },
+                                range: table_range.clone(),
+                                replacement: table_replacement.clone(),
                             }),
                         });
                     }
@@ -348,59 +375,13 @@ impl Rule for MD055TablePipeStyle {
 
         // Process each table block
         for table_block in table_blocks {
-            let mut table_style = None;
-
             // First pass: determine the table's style for "consistent" mode
             // Count all rows to determine most prevalent style (prevalence-based approach)
-            if configured_style == "consistent" {
-                let mut leading_and_trailing_count = 0;
-                let mut no_leading_or_trailing_count = 0;
-                let mut leading_only_count = 0;
-                let mut trailing_only_count = 0;
-
-                // Count style of header row
-                if let Some(style) = TableUtils::determine_pipe_style(lines[table_block.header_line]) {
-                    match style {
-                        "leading_and_trailing" => leading_and_trailing_count += 1,
-                        "no_leading_or_trailing" => no_leading_or_trailing_count += 1,
-                        "leading_only" => leading_only_count += 1,
-                        "trailing_only" => trailing_only_count += 1,
-                        _ => {}
-                    }
-                }
-
-                // Count style of content rows
-                for &line_idx in &table_block.content_lines {
-                    if let Some(style) = TableUtils::determine_pipe_style(lines[line_idx]) {
-                        match style {
-                            "leading_and_trailing" => leading_and_trailing_count += 1,
-                            "no_leading_or_trailing" => no_leading_or_trailing_count += 1,
-                            "leading_only" => leading_only_count += 1,
-                            "trailing_only" => trailing_only_count += 1,
-                            _ => {}
-                        }
-                    }
-                }
-
-                // Determine most prevalent style
-                // In case of tie, prefer leading_and_trailing (most common, widely supported)
-                let max_count = leading_and_trailing_count
-                    .max(no_leading_or_trailing_count)
-                    .max(leading_only_count)
-                    .max(trailing_only_count);
-
-                if max_count > 0 {
-                    if leading_and_trailing_count == max_count {
-                        table_style = Some("leading_and_trailing");
-                    } else if no_leading_or_trailing_count == max_count {
-                        table_style = Some("no_leading_or_trailing");
-                    } else if leading_only_count == max_count {
-                        table_style = Some("leading_only");
-                    } else if trailing_only_count == max_count {
-                        table_style = Some("trailing_only");
-                    }
-                }
-            }
+            let table_style = if configured_style == "consistent" {
+                self.determine_table_style(table_block, &lines)
+            } else {
+                None
+            };
 
             // Determine target style for this table
             let target_style = if configured_style == "consistent" {
@@ -460,7 +441,7 @@ mod tests {
         let rule = MD055TablePipeStyle::new("no_leading_or_trailing".to_string());
 
         let content = "| Header 1 | Header 2 | Header 3 |\n|----------|----------|----------|\n| Data 1   | Data 2   | Data 3   |";
-        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.fix(&ctx).unwrap();
 
         // With the fixed implementation, the delimiter row should have pipes removed
@@ -482,7 +463,7 @@ mod tests {
         let rule = MD055TablePipeStyle::new("leading_and_trailing".to_string());
 
         let content = "Header 1 | Header 2 | Header 3\n----------|----------|----------\nData 1   | Data 2   | Data 3";
-        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.fix(&ctx).unwrap();
 
         // The delimiter row should have pipes added
@@ -498,7 +479,7 @@ mod tests {
         let rule = MD055TablePipeStyle::new("no_leading_or_trailing".to_string());
 
         let content = "| Header 1 | Header 2 | Header 3 |\n|----------|----------|----------|\n| Data 1   | Data 2   | Data 3   |";
-        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let warnings = rule.check(&ctx).unwrap();
 
         // Should have 3 warnings - header row, delimiter row, and data row
@@ -519,7 +500,7 @@ mod tests {
         let rule = MD055TablePipeStyle::new("no_leading_or_trailing".to_string());
 
         let content = "# Table Example\n\nHere's a table with leading and trailing pipes:\n\n| Header 1 | Header 2 | Header 3 |\n|----------|----------|----------|\n| Data 1   | Data 2   | Data 3   |\n| Data 4   | Data 5   | Data 6   |\n\nMore content after the table.";
-        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.fix(&ctx).unwrap();
 
         // The table should be fixed, with pipes removed
@@ -545,7 +526,7 @@ mod tests {
         let rule = MD055TablePipeStyle::new("leading_or_trailing".to_string()); // Invalid style
 
         let content = "| Header 1 | Header 2 | Header 3 |\n|----------|----------|----------|\n| Data 1   | Data 2   | Data 3   |";
-        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.fix(&ctx).unwrap();
 
         // Should default to "leading_and_trailing"
@@ -556,7 +537,7 @@ mod tests {
 
         // Now check a content that needs actual modification
         let content = "Header 1 | Header 2 | Header 3\n----------|----------|----------\nData 1   | Data 2   | Data 3";
-        let ctx2 = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx2 = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.fix(&ctx2).unwrap();
 
         // Should add pipes to match the default "leading_and_trailing" style
