@@ -17,8 +17,41 @@ impl Default for MD056TableColumnCount {
 
 impl MD056TableColumnCount {
     /// Try to fix a table row to match the expected column count
-    fn fix_table_row(&self, row: &str, expected_count: usize) -> Option<String> {
-        let current_count = TableUtils::count_cells(row);
+    fn fix_table_row(&self, row: &str, expected_count: usize, flavor: crate::config::MarkdownFlavor) -> Option<String> {
+        let current_count = TableUtils::count_cells_with_flavor(row, flavor);
+
+        if current_count == expected_count || current_count == 0 {
+            return None;
+        }
+
+        // For standard flavor with too many cells, first try escaping pipes in inline code.
+        // This preserves content and produces valid GitHub-compatible output.
+        if flavor == crate::config::MarkdownFlavor::Standard && current_count > expected_count {
+            let escaped_row = TableUtils::escape_pipes_in_inline_code(row);
+            let escaped_count = TableUtils::count_cells_with_flavor(&escaped_row, flavor);
+
+            // If escaping pipes in inline code fixes the cell count, use that
+            if escaped_count == expected_count {
+                return Some(escaped_row.trim().to_string());
+            }
+
+            // If escaping reduced cell count, continue fixing with escaped version
+            if escaped_count < current_count {
+                return self.fix_row_by_truncation(&escaped_row, expected_count, flavor);
+            }
+        }
+
+        self.fix_row_by_truncation(row, expected_count, flavor)
+    }
+
+    /// Fix a table row by truncating or adding cells
+    fn fix_row_by_truncation(
+        &self,
+        row: &str,
+        expected_count: usize,
+        flavor: crate::config::MarkdownFlavor,
+    ) -> Option<String> {
+        let current_count = TableUtils::count_cells_with_flavor(row, flavor);
 
         if current_count == expected_count || current_count == 0 {
             return None;
@@ -28,30 +61,30 @@ impl MD056TableColumnCount {
         let has_leading_pipe = trimmed.starts_with('|');
         let has_trailing_pipe = trimmed.ends_with('|');
 
-        let parts: Vec<&str> = trimmed.split('|').collect();
-        let mut cells = Vec::new();
+        // Use flavor-aware cell splitting
+        let cells = Self::split_row_into_cells(trimmed, flavor);
 
-        // Extract actual cell content
-        for (i, part) in parts.iter().enumerate() {
+        let mut cell_contents: Vec<&str> = Vec::new();
+        for (i, cell) in cells.iter().enumerate() {
             // Skip empty leading/trailing parts
-            if (i == 0 && part.trim().is_empty() && has_leading_pipe)
-                || (i == parts.len() - 1 && part.trim().is_empty() && has_trailing_pipe)
+            if (i == 0 && cell.trim().is_empty() && has_leading_pipe)
+                || (i == cells.len() - 1 && cell.trim().is_empty() && has_trailing_pipe)
             {
                 continue;
             }
-            cells.push(part.trim());
+            cell_contents.push(cell.trim());
         }
 
         // Adjust cell count to match expected count
         match current_count.cmp(&expected_count) {
             std::cmp::Ordering::Greater => {
                 // Too many cells, remove excess
-                cells.truncate(expected_count);
+                cell_contents.truncate(expected_count);
             }
             std::cmp::Ordering::Less => {
                 // Too few cells, add empty ones
-                while cells.len() < expected_count {
-                    cells.push("");
+                while cell_contents.len() < expected_count {
+                    cell_contents.push("");
                 }
             }
             std::cmp::Ordering::Equal => {
@@ -65,15 +98,49 @@ impl MD056TableColumnCount {
             result.push('|');
         }
 
-        for (i, cell) in cells.iter().enumerate() {
+        for (i, cell) in cell_contents.iter().enumerate() {
             result.push_str(&format!(" {cell} "));
-            if i < cells.len() - 1 || has_trailing_pipe {
+            if i < cell_contents.len() - 1 || has_trailing_pipe {
                 result.push('|');
             }
         }
 
         Some(result)
     }
+
+    /// Split a table row into cells, respecting flavor-specific behavior
+    ///
+    /// For Standard/GFM flavor, pipes in inline code ARE cell delimiters.
+    /// For MkDocs flavor, pipes in inline code are NOT cell delimiters.
+    fn split_row_into_cells(row: &str, flavor: crate::config::MarkdownFlavor) -> Vec<String> {
+        // First, mask escaped pipes (same for all flavors)
+        let masked = TableUtils::mask_pipes_for_table_parsing(row);
+
+        // For MkDocs flavor, also mask pipes inside inline code
+        let final_masked = if flavor == crate::config::MarkdownFlavor::MkDocs {
+            TableUtils::mask_pipes_in_inline_code(&masked)
+        } else {
+            masked
+        };
+
+        // Split by pipes on the masked string, then extract corresponding
+        // original content from the unmasked row
+        let masked_parts: Vec<&str> = final_masked.split('|').collect();
+        let mut cells = Vec::new();
+        let mut pos = 0;
+
+        for masked_part in masked_parts {
+            let cell_len = masked_part.len();
+            if pos + cell_len <= row.len() {
+                cells.push(row[pos..pos + cell_len].to_string());
+            } else {
+                cells.push(masked_part.to_string());
+            }
+            pos += cell_len + 1; // +1 for the pipe delimiter
+        }
+
+        cells
+    }
 }
 
 impl Rule for MD056TableColumnCount {
@@ -92,6 +159,7 @@ impl Rule for MD056TableColumnCount {
 
     fn check(&self, ctx: &crate::lint_context::LintContext) -> LintResult {
         let content = ctx.content;
+        let flavor = ctx.flavor;
         let mut warnings = Vec::new();
 
         // Early return for empty content or content without tables
@@ -106,27 +174,50 @@ impl Rule for MD056TableColumnCount {
 
         for table_block in table_blocks {
             // Determine expected column count from header row
-            let expected_count = TableUtils::count_cells(lines[table_block.header_line]);
+            let expected_count = TableUtils::count_cells_with_flavor(lines[table_block.header_line], flavor);
 
             if expected_count == 0 {
                 continue; // Skip invalid tables
             }
 
-            // Check all rows in the table
-            let all_lines = std::iter::once(table_block.header_line)
+            // Collect all table lines for building the whole-table fix
+            let all_line_indices: Vec<usize> = std::iter::once(table_block.header_line)
                 .chain(std::iter::once(table_block.delimiter_line))
-                .chain(table_block.content_lines.iter().copied());
+                .chain(table_block.content_lines.iter().copied())
+                .collect();
 
-            for line_idx in all_lines {
+            // Build the whole-table fix once for all warnings in this table
+            // This ensures that applying Quick Fix on any row fixes the entire table
+            let table_start_line = table_block.start_line + 1; // Convert to 1-indexed
+            let table_end_line = table_block.end_line + 1; // Convert to 1-indexed
+
+            // Build the complete fixed table content
+            let mut fixed_table_lines: Vec<String> = Vec::with_capacity(all_line_indices.len());
+            for &line_idx in &all_line_indices {
                 let line = lines[line_idx];
-                let count = TableUtils::count_cells(line);
+                let fixed_line = self
+                    .fix_table_row(line, expected_count, flavor)
+                    .unwrap_or_else(|| line.to_string());
+                if line_idx < lines.len() - 1 {
+                    fixed_table_lines.push(format!("{fixed_line}\n"));
+                } else {
+                    fixed_table_lines.push(fixed_line);
+                }
+            }
+            let table_replacement = fixed_table_lines.concat();
+            let table_range = ctx.line_index.multi_line_range(table_start_line, table_end_line);
+
+            // Check all rows in the table
+            for &line_idx in &all_line_indices {
+                let line = lines[line_idx];
+                let count = TableUtils::count_cells_with_flavor(line, flavor);
 
                 if count > 0 && count != expected_count {
-                    let fix_result = self.fix_table_row(line, expected_count);
-
                     // Calculate precise character range for the entire table row
                     let (start_line, start_col, end_line, end_col) = calculate_line_range(line_idx + 1, line);
 
+                    // Each warning uses the same whole-table fix
+                    // This ensures Quick Fix on any row fixes the entire table
                     warnings.push(LintWarning {
                         rule_name: Some(self.name().to_string()),
                         message: format!("Table row has {count} cells, but expected {expected_count}"),
@@ -135,9 +226,9 @@ impl Rule for MD056TableColumnCount {
                         end_line,
                         end_column: end_col,
                         severity: Severity::Warning,
-                        fix: fix_result.map(|fixed_row| Fix {
-                            range: ctx.line_index.line_col_to_byte_range(line_idx + 1, 1),
-                            replacement: fixed_row,
+                        fix: Some(Fix {
+                            range: table_range.clone(),
+                            replacement: table_replacement.clone(),
                         }),
                     });
                 }
@@ -149,32 +240,40 @@ impl Rule for MD056TableColumnCount {
 
     fn fix(&self, ctx: &crate::lint_context::LintContext) -> Result<String, LintError> {
         let content = ctx.content;
-        let warnings = self.check(ctx)?;
-        if warnings.is_empty() {
-            return Ok(content.to_string());
-        }
-
+        let flavor = ctx.flavor;
         let lines: Vec<&str> = content.lines().collect();
-        let mut result = Vec::new();
+        let table_blocks = &ctx.table_blocks;
 
-        for (i, line) in lines.iter().enumerate() {
-            let warning_idx = warnings.iter().position(|w| w.line == i + 1);
+        let mut result_lines: Vec<String> = lines.iter().map(|&s| s.to_string()).collect();
 
-            if let Some(idx) = warning_idx
-                && let Some(fix) = &warnings[idx].fix
-            {
-                result.push(fix.replacement.clone());
-                continue;
+        for table_block in table_blocks {
+            // Determine expected column count from header row
+            let expected_count = TableUtils::count_cells_with_flavor(lines[table_block.header_line], flavor);
+
+            if expected_count == 0 {
+                continue; // Skip invalid tables
+            }
+
+            // Fix all rows in the table
+            let all_line_indices: Vec<usize> = std::iter::once(table_block.header_line)
+                .chain(std::iter::once(table_block.delimiter_line))
+                .chain(table_block.content_lines.iter().copied())
+                .collect();
+
+            for &line_idx in &all_line_indices {
+                let line = lines[line_idx];
+                if let Some(fixed_line) = self.fix_table_row(line, expected_count, flavor) {
+                    result_lines[line_idx] = fixed_line;
+                }
             }
-            result.push(line.to_string());
         }
 
-        // Preserve the original line endings
-        if content.ends_with('\n') {
-            Ok(result.join("\n") + "\n")
-        } else {
-            Ok(result.join("\n"))
+        let mut fixed = result_lines.join("\n");
+        // Preserve trailing newline if original content had one
+        if content.ends_with('\n') && !fixed.ends_with('\n') {
+            fixed.push('\n');
         }
+        Ok(fixed)
     }
 
     fn as_any(&self) -> &dyn std::any::Any {
@@ -201,7 +300,7 @@ mod tests {
 |----------|----------|----------|
 | Cell 1   | Cell 2   | Cell 3   |
 | Cell 4   | Cell 5   | Cell 6   |";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -214,7 +313,7 @@ mod tests {
 |----------|----------|----------|
 | Cell 1   | Cell 2   |
 | Cell 4   | Cell 5   | Cell 6   |";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -229,7 +328,7 @@ mod tests {
 |----------|----------|
 | Cell 1   | Cell 2   | Cell 3   | Cell 4   |
 | Cell 5   | Cell 6   |";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -243,7 +342,7 @@ mod tests {
         let content = "| Header 1 | Header 2 | Header 3 |
 |----------|----------|
 | Cell 1   | Cell 2   | Cell 3   |";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -258,7 +357,7 @@ mod tests {
 |----------|----------|----------|
 | Cell 1   | Cell 2   |
 | Cell 4   | Cell 5   | Cell 6   |";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let fixed = rule.fix(&ctx).unwrap();
 
         assert!(fixed.contains("| Cell 1 | Cell 2 |  |"));
@@ -271,7 +370,7 @@ mod tests {
 |----------|----------|
 | Cell 1   | Cell 2   | Cell 3   | Cell 4   |
 | Cell 5   | Cell 6   |";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let fixed = rule.fix(&ctx).unwrap();
 
         assert!(fixed.contains("| Cell 1 | Cell 2 |"));
@@ -286,7 +385,7 @@ mod tests {
 ---------|----------|----------|
 Cell 1   | Cell 2   |
 Cell 4   | Cell 5   | Cell 6   |";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -300,7 +399,7 @@ Cell 4   | Cell 5   | Cell 6   |";
 |----------|----------|----------
 | Cell 1   | Cell 2
 | Cell 4   | Cell 5   | Cell 6";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -313,7 +412,7 @@ Cell 4   | Cell 5   | Cell 6   |";
         let content = "This is not a table
 Just regular text
 No pipes here";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -326,7 +425,7 @@ No pipes here";
 |----------|----------|----------|
 |          |          |          |
 | Cell 1   |          | Cell 3   |";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -345,7 +444,7 @@ Some text in between.
 |----------------|----------------|----------------|
 | Data 3         | Data 4         |
 | Data 5         | Data 6         | Data 7         |";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -354,25 +453,34 @@ Some text in between.
     }
 
     #[test]
-    #[ignore = "Table utils doesn't handle escaped pipes in code correctly yet"]
     fn test_table_with_escaped_pipes() {
         let rule = MD056TableColumnCount;
+
+        // Single backslash escapes the pipe: \| keeps pipe as content (2 columns)
         let content = "| Command | Description |
 |---------|-------------|
 | `echo \\| grep` | Pipe example |
 | `ls` | List files |";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
+        assert_eq!(result.len(), 0, "escaped pipe \\| should not split cells");
 
-        // Should handle escaped pipes correctly
-        assert_eq!(result.len(), 0);
+        // Double backslash + pipe: \\| means escaped backslash + pipe delimiter (3 columns)
+        let content_double = "| Command | Description |
+|---------|-------------|
+| `echo \\\\| grep` | Pipe example |
+| `ls` | List files |";
+        let ctx2 = LintContext::new(content_double, crate::config::MarkdownFlavor::Standard, None);
+        let result2 = rule.check(&ctx2).unwrap();
+        // Line 3 has \\| which becomes 3 cells, but header expects 2
+        assert_eq!(result2.len(), 1, "double backslash \\\\| should split cells");
     }
 
     #[test]
     fn test_empty_content() {
         let rule = MD056TableColumnCount;
         let content = "";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -390,7 +498,7 @@ Some text in between.
 | Real | Table |
 |------|-------|
 | Data | Here  |";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should not check tables inside code blocks
@@ -404,7 +512,7 @@ Some text in between.
         let content = "| Header 1 | Header 2 | Header 3
 |----------|----------|----------
 | Cell 1   | Cell 2";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let fixed = rule.fix(&ctx).unwrap();
 
         let lines: Vec<&str> = fixed.lines().collect();
@@ -420,7 +528,7 @@ Some text in between.
 |---------|
 | Cell 1  |
 | Cell 2  |";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -433,7 +541,7 @@ Some text in between.
 |:-----|:------:|------:|
 | L    | C      | R     |
 | Left | Center |";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -447,7 +555,7 @@ Some text in between.
 |------|------|------|
 | 田中 | 25   | 東京 |
 | 佐藤 | 30   |";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -460,7 +568,7 @@ Some text in between.
         let content = "| Short | Very very very very very very very very very very long header | Another |
 |-------|--------------------------------------------------------------|---------|
 | Data  | This is an extremely long cell content that goes on and on   |";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -474,7 +582,7 @@ Some text in between.
 |---|---|---|
 | 1 | 2 |
 ";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let fixed = rule.fix(&ctx).unwrap();
 
         assert!(fixed.ends_with('\n'));
@@ -487,7 +595,7 @@ Some text in between.
         let content = "| A | B | C |
 |---|---|---|
 | 1 | 2 |";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let fixed = rule.fix(&ctx).unwrap();
 
         assert!(!fixed.ends_with('\n'));
