@@ -130,6 +130,8 @@ impl Rule for MD058BlanksAroundTables {
                         format!("Missing {needed} blank lines before table")
                     };
 
+                    let bq_prefix = ctx.blockquote_prefix_for_blank_line(table_block.start_line);
+                    let replacement = format!("{bq_prefix}\n").repeat(needed);
                     warnings.push(LintWarning {
                         rule_name: Some(self.name().to_string()),
                         message,
@@ -139,8 +141,9 @@ impl Rule for MD058BlanksAroundTables {
                         end_column: 2,
                         severity: Severity::Warning,
                         fix: Some(Fix {
+                            // Insert blank lines at the start of the table line
                             range: _line_index.line_col_to_byte_range(table_block.start_line + 1, 1),
-                            replacement: format!("{}{}", "\n".repeat(needed), lines[table_block.start_line]),
+                            replacement,
                         }),
                     });
                 }
@@ -166,6 +169,8 @@ impl Rule for MD058BlanksAroundTables {
                             format!("Missing {needed} blank lines after table")
                         };
 
+                        let bq_prefix = ctx.blockquote_prefix_for_blank_line(table_block.end_line);
+                        let replacement = format!("{bq_prefix}\n").repeat(needed);
                         warnings.push(LintWarning {
                             rule_name: Some(self.name().to_string()),
                             message,
@@ -175,11 +180,12 @@ impl Rule for MD058BlanksAroundTables {
                             end_column: lines[table_block.end_line].len() + 2,
                             severity: Severity::Warning,
                             fix: Some(Fix {
+                                // Insert blank lines at the end of the table's last line
                                 range: _line_index.line_col_to_byte_range(
                                     table_block.end_line + 1,
                                     lines[table_block.end_line].len() + 1,
                                 ),
-                                replacement: format!("{}{}", lines[table_block.end_line], "\n".repeat(needed)),
+                                replacement,
                             }),
                         });
                     }
@@ -224,9 +230,10 @@ impl Rule for MD058BlanksAroundTables {
                     1
                 };
 
-                // Add the required number of blank lines
+                // Add the required number of blank lines with blockquote prefix
+                let bq_prefix = ctx.blockquote_prefix_for_blank_line(i);
                 for _ in 0..needed_blanks {
-                    result.push("".to_string());
+                    result.push(bq_prefix.clone());
                 }
                 warnings.remove(idx);
             }
@@ -253,9 +260,10 @@ impl Rule for MD058BlanksAroundTables {
                     1
                 };
 
-                // Add the required number of blank lines
+                // Add the required number of blank lines with blockquote prefix
+                let bq_prefix = ctx.blockquote_prefix_for_blank_line(i);
                 for _ in 0..needed_blanks {
-                    result.push("".to_string());
+                    result.push(bq_prefix.clone());
                 }
                 warnings.remove(idx);
             }
@@ -310,7 +318,7 @@ mod tests {
 | Cell 1   | Cell 2   |
 
 Some text after.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -325,7 +333,7 @@ Some text after.";
 | Cell 1   | Cell 2   |
 
 Some text after.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -342,7 +350,7 @@ Some text after.";
 |----------|----------|
 | Cell 1   | Cell 2   |
 Some text after.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -358,7 +366,7 @@ Some text after.";
 |----------|----------|
 | Cell 1   | Cell 2   |
 Some text after.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 2);
@@ -374,7 +382,7 @@ Some text after.";
 | Cell 1   | Cell 2   |
 
 Some text after.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // No blank line needed before table at start of document
@@ -389,7 +397,7 @@ Some text after.";
 | Header 1 | Header 2 |
 |----------|----------|
 | Cell 1   | Cell 2   |";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // No blank line needed after table at end of document
@@ -408,7 +416,7 @@ Text between tables.
 |--------|-------|
 | Data 2 | Val 2 |
 Text after second table.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 4);
@@ -434,7 +442,7 @@ Text after second table.";
 | Data 2 | Val 2 |
 
 More text.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Tables separated by blank line should be OK
@@ -456,7 +464,7 @@ Text between.
 | Data 2 | Val 2 |
 
 More text.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should flag missing blanks around both tables
@@ -473,7 +481,7 @@ More text.";
 |--------|-------|
 | Cell   | Data  |
 Text after.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let fixed = rule.fix(&ctx).unwrap();
 
         let expected = "Text before.
@@ -498,7 +506,7 @@ Middle
 |----|----|
 | D2 | V2 |
 End";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let fixed = rule.fix(&ctx).unwrap();
 
         let expected = "Start
@@ -521,7 +529,7 @@ End";
     fn test_empty_content() {
         let rule = MD058BlanksAroundTables::default();
         let content = "";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -533,7 +541,7 @@ End";
         let content = "Just regular text.
 No tables here.
 Only paragraphs.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -549,7 +557,7 @@ Only paragraphs.";
 | In  | Code | Block |
 ```
 Text after.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Tables in code blocks should be ignored
@@ -565,7 +573,7 @@ Text after.";
 | Left     | Center   | Right    |
 | Data     | More     | Info     |
 ## Another Heading";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 2);
@@ -584,7 +592,7 @@ Text after.";
 | O   |     | X   |
 
 More text.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -599,7 +607,7 @@ More text.";
 | 田中 | 25   | 東京 |
 | 佐藤 | 30   | 大阪 |
 End.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 2);
@@ -615,7 +623,7 @@ End.";
 | Data  | This is an extremely long cell content that goes on |
 
 After.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -628,7 +636,7 @@ After.";
 | Header 1 | Header 2 |
 |----------|----------|
 Next paragraph.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should still require blanks around header-only table
@@ -645,7 +653,7 @@ Next paragraph.";
     | Data     | Here  |
 
     More content.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Indented tables should be detected
@@ -660,7 +668,7 @@ Next paragraph.";
 |--------|
 | Column |
 Text after.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Single column tables ARE now detected (fixed to support 1+ columns)
@@ -685,7 +693,7 @@ Text after.";
 | Cell   | Data  |
 
 Text after.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should pass with 1 blank line before (but we configured to require 2)
@@ -708,7 +716,7 @@ Text after.";
 | Cell   | Data  |
 
 More text.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should fail with only 1 blank line after (but we configured to require 3)
@@ -729,7 +737,7 @@ More text.";
 |--------|-------|
 | Cell   | Data  |
 More text.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should fail both before and after
@@ -751,7 +759,7 @@ More text.";
 |--------|-------|
 | Cell   | Data  |
 More text.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         // Should pass with zero blank lines required
@@ -771,7 +779,7 @@ More text.";
 |--------|-------|
 | Cell   | Data  |
 Text after.";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let fixed = rule.fix(&ctx).unwrap();
 
         let expected = "Text before.
@@ -830,7 +838,7 @@ Text after.";
         // Test case from issue #25 - table with very long line
         let rule = MD058BlanksAroundTables::default();
         let content = "# Title\n\nThis is a table:\n\n| Name          | Query                                                    |\n| ------------- | -------------------------------------------------------- |\n| b             | a                                                        |\n| c             | a                                                        |\n| d             | a                                                        |\n| long          | aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa |\n| e             | a                                                        |\n| f             | a                                                        |\n| g             | a                                                        |";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
 
         // Debug: Print detected table blocks
         let table_blocks = TableUtils::find_table_blocks(content, &ctx);
@@ -854,4 +862,102 @@ Text after.";
         // Should not flag any issues since table is complete and doesn't need blanks
         assert_eq!(result.len(), 0, "Should not flag any MD058 issues for a complete table");
     }
+
+    #[test]
+    fn test_fix_preserves_blockquote_prefix_before_table() {
+        // Issue #268: Fix should insert blockquote-prefixed blank lines inside blockquotes
+        let rule = MD058BlanksAroundTables::default();
+
+        let content = "> Text before
+> | H1 | H2 |
+> |----|---|
+> | a  | b |";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let fixed = rule.fix(&ctx).unwrap();
+
+        // The blank line inserted before the table should have the blockquote prefix
+        let expected = "> Text before
+>
+> | H1 | H2 |
+> |----|---|
+> | a  | b |";
+        assert_eq!(
+            fixed, expected,
+            "Fix should insert '>' blank line before table, not plain blank line"
+        );
+    }
+
+    #[test]
+    fn test_fix_preserves_blockquote_prefix_after_table() {
+        // Issue #268: Fix should insert blockquote-prefixed blank lines inside blockquotes
+        let rule = MD058BlanksAroundTables::default();
+
+        let content = "> | H1 | H2 |
+> |----|---|
+> | a  | b |
+> Text after";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let fixed = rule.fix(&ctx).unwrap();
+
+        // The blank line inserted after the table should have the blockquote prefix
+        let expected = "> | H1 | H2 |
+> |----|---|
+> | a  | b |
+>
+> Text after";
+        assert_eq!(
+            fixed, expected,
+            "Fix should insert '>' blank line after table, not plain blank line"
+        );
+    }
+
+    #[test]
+    fn test_fix_preserves_nested_blockquote_prefix_for_table() {
+        // Nested blockquotes should preserve the full prefix
+        let rule = MD058BlanksAroundTables::default();
+
+        let content = ">> Nested quote
+>> | H1 |
+>> |----|
+>> | a  |
+>> More text";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let fixed = rule.fix(&ctx).unwrap();
+
+        // Should insert ">>" blank lines
+        let expected = ">> Nested quote
+>>
+>> | H1 |
+>> |----|
+>> | a  |
+>>
+>> More text";
+        assert_eq!(fixed, expected, "Fix should preserve nested blockquote prefix '>>'");
+    }
+
+    #[test]
+    fn test_fix_preserves_triple_nested_blockquote_prefix_for_table() {
+        // Triple-nested blockquotes should preserve full prefix
+        let rule = MD058BlanksAroundTables::default();
+
+        let content = ">>> Triple nested
+>>> | A | B |
+>>> |---|---|
+>>> | 1 | 2 |
+>>> More text";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let fixed = rule.fix(&ctx).unwrap();
+
+        let expected = ">>> Triple nested
+>>>
+>>> | A | B |
+>>> |---|---|
+>>> | 1 | 2 |
+>>>
+>>> More text";
+        assert_eq!(
+            fixed, expected,
+            "Fix should preserve triple-nested blockquote prefix '>>>'"
+        );
+    }
 }
