@@ -8,7 +8,9 @@ use crate::lint_context::LintContext;
 use crate::utils::kramdown_utils::is_math_block_delimiter;
 use crate::utils::mkdocs_admonitions;
 use crate::utils::mkdocs_critic;
+use crate::utils::mkdocs_extensions;
 use crate::utils::mkdocs_footnotes;
+use crate::utils::mkdocs_icons;
 use crate::utils::mkdocs_snippets;
 use crate::utils::mkdocs_tabs;
 use crate::utils::mkdocstrings_refs;
@@ -16,8 +18,15 @@ use crate::utils::regex_cache::HTML_COMMENT_PATTERN;
 use regex::Regex;
 use std::sync::LazyLock;
 
-/// Enhanced inline math pattern that handles both single $ and double $$ delimiters
-static INLINE_MATH_REGEX: LazyLock<Regex> = LazyLock::new(|| Regex::new(r"\$(?:\$)?[^$]+\$(?:\$)?").unwrap());
+/// Enhanced inline math pattern that handles both single $ and double $$ delimiters.
+/// Matches:
+/// - Display math: $$...$$ (zero or more non-$ characters)
+/// - Inline math: $...$ (zero or more non-$ non-newline characters)
+///
+/// The display math pattern is tried first to correctly handle $$content$$.
+/// Critically, both patterns allow ZERO characters between delimiters,
+/// so empty math like $$ or $ $ is consumed and won't pair with other $ signs.
+static INLINE_MATH_REGEX: LazyLock<Regex> = LazyLock::new(|| Regex::new(r"\$\$[^$]*\$\$|\$[^$\n]*\$").unwrap());
 
 /// Range representing a span of bytes (start inclusive, end exclusive)
 #[derive(Debug, Clone, Copy)]
@@ -55,6 +64,18 @@ pub fn is_in_html_comment_ranges(ranges: &[ByteRange], byte_pos: usize) -> bool
         .is_ok()
 }
 
+/// Check if a line is ENTIRELY within a single HTML comment
+/// Returns true only if both the line start AND end are within the same comment range
+pub fn is_line_entirely_in_html_comment(ranges: &[ByteRange], line_start: usize, line_end: usize) -> bool {
+    for range in ranges {
+        // If line start is within this range, check if line end is also within it
+        if line_start >= range.start && line_start < range.end {
+            return line_end <= range.end;
+        }
+    }
+    false
+}
+
 /// Check if a line is within front matter (both YAML and TOML)
 pub fn is_in_front_matter(content: &str, line_num: usize) -> bool {
     let lines: Vec<&str> = content.lines().collect();
@@ -102,6 +123,18 @@ pub fn is_in_skip_context(ctx: &LintContext, byte_pos: usize) -> bool {
         return true;
     }
 
+    // Check MDX-specific contexts
+    if ctx.flavor == MarkdownFlavor::MDX {
+        // Check JSX expressions
+        if ctx.is_in_jsx_expression(byte_pos) {
+            return true;
+        }
+        // Check MDX comments
+        if ctx.is_in_mdx_comment(byte_pos) {
+            return true;
+        }
+    }
+
     // Check MkDocs snippet sections and multi-line blocks
     if ctx.flavor == MarkdownFlavor::MkDocs {
         if mkdocs_snippets::is_within_snippet_section(ctx.content, byte_pos) {
@@ -140,6 +173,18 @@ pub fn is_in_skip_context(ctx: &LintContext, byte_pos: usize) -> bool {
     false
 }
 
+/// Check if a byte position is within a JSX expression (MDX: {expression})
+#[inline]
+pub fn is_in_jsx_expression(ctx: &LintContext, byte_pos: usize) -> bool {
+    ctx.flavor == MarkdownFlavor::MDX && ctx.is_in_jsx_expression(byte_pos)
+}
+
+/// Check if a byte position is within an MDX comment ({/* ... */})
+#[inline]
+pub fn is_in_mdx_comment(ctx: &LintContext, byte_pos: usize) -> bool {
+    ctx.flavor == MarkdownFlavor::MDX && ctx.is_in_mdx_comment(byte_pos)
+}
+
 /// Check if a line should be skipped due to MkDocs snippet syntax
 pub fn is_mkdocs_snippet_line(line: &str, flavor: MarkdownFlavor) -> bool {
     flavor == MarkdownFlavor::MkDocs && mkdocs_snippets::is_snippet_marker(line)
@@ -281,6 +326,35 @@ pub fn is_table_line(line: &str) -> bool {
     false
 }
 
+/// Check if a byte position is within an MkDocs icon shortcode
+/// Icon shortcodes use format like `:material-check:`, `:octicons-mark-github-16:`
+pub fn is_in_icon_shortcode(line: &str, position: usize, _flavor: MarkdownFlavor) -> bool {
+    // Only skip for MkDocs flavor, but check pattern for all flavors
+    // since emoji shortcodes are universal
+    mkdocs_icons::is_in_any_shortcode(line, position)
+}
+
+/// Check if a byte position is within PyMdown extension markup
+/// Includes: Keys (++ctrl+alt++), Caret (^text^), Insert (^^text^^), Mark (==text==)
+pub fn is_in_pymdown_markup(line: &str, position: usize, flavor: MarkdownFlavor) -> bool {
+    if flavor != MarkdownFlavor::MkDocs {
+        return false;
+    }
+    mkdocs_extensions::is_in_pymdown_markup(line, position)
+}
+
+/// Check if a byte position is within any MkDocs-specific markup
+/// Combines icon shortcodes and PyMdown extensions
+pub fn is_in_mkdocs_markup(line: &str, position: usize, flavor: MarkdownFlavor) -> bool {
+    if is_in_icon_shortcode(line, position, flavor) {
+        return true;
+    }
+    if is_in_pymdown_markup(line, position, flavor) {
+        return true;
+    }
+    false
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -293,6 +367,37 @@ mod tests {
         assert!(!is_in_html_comment(content, 25)); // After comment
     }
 
+    #[test]
+    fn test_is_line_entirely_in_html_comment() {
+        // Test 1: Multi-line comment with content after closing
+        let content = "<!--\ncomment\n--> Content after comment";
+        let ranges = compute_html_comment_ranges(content);
+        // Line 0: "<!--" (bytes 0-4) - entirely in comment
+        assert!(is_line_entirely_in_html_comment(&ranges, 0, 4));
+        // Line 1: "comment" (bytes 5-12) - entirely in comment
+        assert!(is_line_entirely_in_html_comment(&ranges, 5, 12));
+        // Line 2: "--> Content after comment" (bytes 13-38) - NOT entirely in comment
+        assert!(!is_line_entirely_in_html_comment(&ranges, 13, 38));
+
+        // Test 2: Single-line comment with content after
+        let content2 = "<!-- comment --> Not a comment";
+        let ranges2 = compute_html_comment_ranges(content2);
+        // The entire line is NOT entirely in the comment
+        assert!(!is_line_entirely_in_html_comment(&ranges2, 0, 30));
+
+        // Test 3: Single-line comment alone
+        let content3 = "<!-- comment -->";
+        let ranges3 = compute_html_comment_ranges(content3);
+        // The entire line IS entirely in the comment
+        assert!(is_line_entirely_in_html_comment(&ranges3, 0, 16));
+
+        // Test 4: Content before comment
+        let content4 = "Text before <!-- comment -->";
+        let ranges4 = compute_html_comment_ranges(content4);
+        // Line start is NOT in the comment range
+        assert!(!is_line_entirely_in_html_comment(&ranges4, 0, 28));
+    }
+
     #[test]
     fn test_math_block_detection() {
         let content = "Text\n$$\nmath content\n$$\nmore text";
@@ -394,4 +499,46 @@ More content"#;
             "TOML block not at beginning should NOT be front matter"
         );
     }
+
+    #[test]
+    fn test_is_in_icon_shortcode() {
+        let line = "Click :material-check: to confirm";
+        // Position 0-5 is "Click"
+        assert!(!is_in_icon_shortcode(line, 0, MarkdownFlavor::MkDocs));
+        // Position 6-22 is ":material-check:"
+        assert!(is_in_icon_shortcode(line, 6, MarkdownFlavor::MkDocs));
+        assert!(is_in_icon_shortcode(line, 15, MarkdownFlavor::MkDocs));
+        assert!(is_in_icon_shortcode(line, 21, MarkdownFlavor::MkDocs));
+        // Position 22+ is " to confirm"
+        assert!(!is_in_icon_shortcode(line, 22, MarkdownFlavor::MkDocs));
+    }
+
+    #[test]
+    fn test_is_in_pymdown_markup() {
+        // Test Keys notation
+        let line = "Press ++ctrl+c++ to copy";
+        assert!(!is_in_pymdown_markup(line, 0, MarkdownFlavor::MkDocs));
+        assert!(is_in_pymdown_markup(line, 6, MarkdownFlavor::MkDocs));
+        assert!(is_in_pymdown_markup(line, 10, MarkdownFlavor::MkDocs));
+        assert!(!is_in_pymdown_markup(line, 17, MarkdownFlavor::MkDocs));
+
+        // Test Mark notation
+        let line2 = "This is ==highlighted== text";
+        assert!(!is_in_pymdown_markup(line2, 0, MarkdownFlavor::MkDocs));
+        assert!(is_in_pymdown_markup(line2, 8, MarkdownFlavor::MkDocs));
+        assert!(is_in_pymdown_markup(line2, 15, MarkdownFlavor::MkDocs));
+        assert!(!is_in_pymdown_markup(line2, 23, MarkdownFlavor::MkDocs));
+
+        // Should not match for Standard flavor
+        assert!(!is_in_pymdown_markup(line, 10, MarkdownFlavor::Standard));
+    }
+
+    #[test]
+    fn test_is_in_mkdocs_markup() {
+        // Should combine both icon and pymdown
+        let line = ":material-check: and ++ctrl++";
+        assert!(is_in_mkdocs_markup(line, 5, MarkdownFlavor::MkDocs)); // In icon
+        assert!(is_in_mkdocs_markup(line, 23, MarkdownFlavor::MkDocs)); // In keys
+        assert!(!is_in_mkdocs_markup(line, 17, MarkdownFlavor::MkDocs)); // In " and "
+    }
 }
