@@ -22,13 +22,7 @@ impl StringInterner {
 
     /// Intern a string, returning an `Arc<str>` that can be shared
     pub fn intern(&mut self, s: &str) -> Arc<str> {
-        if let Some(interned) = self.strings.get(s) {
-            interned.clone()
-        } else {
-            let arc_str: Arc<str> = Arc::from(s);
-            self.strings.insert(s.to_string(), arc_str.clone());
-            arc_str
-        }
+        Arc::clone(self.strings.entry(s.to_string()).or_insert_with(|| Arc::from(s)))
     }
 
     /// Get the number of interned strings
@@ -47,9 +41,14 @@ static GLOBAL_INTERNER: LazyLock<Arc<Mutex<StringInterner>>> =
     LazyLock::new(|| Arc::new(Mutex::new(StringInterner::new())));
 
 /// Intern a string globally
+///
+/// If the mutex is poisoned, returns a fresh Arc<str> without interning.
+/// This ensures the library never panics due to mutex poisoning.
 pub fn intern_string(s: &str) -> Arc<str> {
-    let mut interner = GLOBAL_INTERNER.lock().expect("String interner mutex poisoned");
-    interner.intern(s)
+    match GLOBAL_INTERNER.lock() {
+        Ok(mut interner) => interner.intern(s),
+        Err(_) => Arc::from(s),
+    }
 }
 
 /// Common interned strings for performance
