@@ -24,10 +24,31 @@ impl TableUtils {
         }
 
         // Skip lines that are clearly not table rows
-        if trimmed.starts_with("- ") || trimmed.starts_with("* ") || trimmed.starts_with("+ ") {
+        // Unordered list items with space or tab after marker
+        if trimmed.starts_with("- ")
+            || trimmed.starts_with("* ")
+            || trimmed.starts_with("+ ")
+            || trimmed.starts_with("-\t")
+            || trimmed.starts_with("*\t")
+            || trimmed.starts_with("+\t")
+        {
             return false;
         }
 
+        // Skip ordered list items: digits followed by . or ) then space/tab
+        if let Some(first_non_digit) = trimmed.find(|c: char| !c.is_ascii_digit())
+            && first_non_digit > 0
+        {
+            let after_digits = &trimmed[first_non_digit..];
+            if after_digits.starts_with(". ")
+                || after_digits.starts_with(".\t")
+                || after_digits.starts_with(") ")
+                || after_digits.starts_with(")\t")
+            {
+                return false;
+            }
+        }
+
         // Skip lines that are clearly code or inline code
         if trimmed.starts_with("`") || trimmed.contains("``") {
             return false;
@@ -111,6 +132,22 @@ impl TableUtils {
         total_non_empty_parts > 0 && valid_delimiter_parts == total_non_empty_parts
     }
 
+    /// Strip blockquote prefix from a line, returning the content without the prefix
+    fn strip_blockquote_prefix(line: &str) -> &str {
+        let trimmed = line.trim_start();
+        if trimmed.starts_with('>') {
+            // Strip all blockquote markers and following space
+            let mut rest = trimmed;
+            while rest.starts_with('>') {
+                rest = rest.strip_prefix('>').unwrap_or(rest);
+                rest = rest.trim_start_matches(' ');
+            }
+            rest
+        } else {
+            line
+        }
+    }
+
     /// Find all table blocks in the content with optimized detection
     /// This version accepts code_blocks and code_spans directly for use during LintContext construction
     pub fn find_table_blocks_with_code_info(
@@ -148,10 +185,18 @@ impl TableUtils {
                 continue;
             }
 
+            // Strip blockquote prefix for table detection
+            let line_content = Self::strip_blockquote_prefix(lines[i]);
+
             // Look for potential table start
-            if Self::is_potential_table_row(lines[i]) {
-                // Check if the next line is a delimiter row
-                if i + 1 < lines.len() && Self::is_delimiter_row(lines[i + 1]) {
+            if Self::is_potential_table_row(line_content) {
+                // Check if the next line is a delimiter row (also strip blockquote prefix)
+                let next_line_content = if i + 1 < lines.len() {
+                    Self::strip_blockquote_prefix(lines[i + 1])
+                } else {
+                    ""
+                };
+                if i + 1 < lines.len() && Self::is_delimiter_row(next_line_content) {
                     // Found a table! Find its end
                     let table_start = i;
                     let header_line = i;
@@ -163,11 +208,13 @@ impl TableUtils {
                     let mut j = i + 2;
                     while j < lines.len() {
                         let line = lines[j];
-                        if line.trim().is_empty() {
-                            // Empty line ends the table
+                        // Strip blockquote prefix for checking
+                        let line_content = Self::strip_blockquote_prefix(line);
+                        if line_content.trim().is_empty() {
+                            // Empty line ends the table (including blockquote blank lines like ">")
                             break;
                         }
-                        if Self::is_potential_table_row(line) {
+                        if Self::is_potential_table_row(line_content) {
                             content_lines.push(j);
                             table_end = j;
                             j += 1;
@@ -204,35 +251,15 @@ impl TableUtils {
 
     /// Count the number of cells in a table row
     pub fn count_cells(row: &str) -> usize {
-        let trimmed = row.trim();
+        Self::count_cells_with_flavor(row, crate::config::MarkdownFlavor::Standard)
+    }
 
-        // Skip non-table rows
-        if !trimmed.contains('|') {
-            return 0;
-        }
-
-        // Users shouldn't have to escape pipes in regex patterns, inline code, etc.
-        let masked_row = Self::mask_pipes_for_table_parsing(trimmed);
-
-        // Handle case with leading/trailing pipes
-        let mut cell_count = 0;
-        let parts: Vec<&str> = masked_row.split('|').collect();
-
-        for (i, part) in parts.iter().enumerate() {
-            // Skip first part if it's empty and there's a leading pipe
-            if i == 0 && part.trim().is_empty() && parts.len() > 1 {
-                continue;
-            }
-
-            // Skip last part if it's empty and there's a trailing pipe
-            if i == parts.len() - 1 && part.trim().is_empty() && parts.len() > 1 {
-                continue;
-            }
-
-            cell_count += 1;
-        }
-
-        cell_count
+    /// Count the number of cells in a table row with flavor-specific behavior
+    ///
+    /// For Standard/GFM flavor, pipes in inline code ARE cell delimiters (matches GitHub).
+    /// For MkDocs flavor, pipes in inline code are NOT cell delimiters.
+    pub fn count_cells_with_flavor(row: &str, flavor: crate::config::MarkdownFlavor) -> usize {
+        Self::split_table_row_with_flavor(row, flavor).len()
     }
 
     /// Mask pipes inside inline code blocks with a placeholder character
@@ -303,35 +330,60 @@ impl TableUtils {
         result
     }
 
-    /// Mask both inline code pipes AND escaped pipes for accurate table cell parsing
-    ///
-    /// This function combines two types of masking:
-    /// 1. Pipes inside inline code blocks (between backticks) → masked as '_'
-    /// 2. Escaped pipes `\|` → masked as `\_` (backslash + underscore)
-    ///
-    /// This allows `split('|')` to correctly identify cell boundaries without
-    /// accidentally splitting on:
-    /// - Literal pipes inside code: `| a | b |` → treated as single cell
-    /// - Escaped pipes: `a \| b` → treated as single cell containing literal pipe
-    ///
-    /// The original text is reconstructed from byte offsets, so these masks only
-    /// affect where we split, not the actual cell content.
-    pub fn mask_pipes_for_table_parsing(text: &str) -> String {
-        // First pass: mask inline code pipes
-        let after_code_masking = Self::mask_pipes_in_inline_code(text);
-
-        // Second pass: mask escaped pipes
+    /// Escape pipes inside inline code blocks with backslash.
+    /// Converts `|` to `\|` inside backtick spans.
+    /// Used by auto-fix to preserve content while making tables valid.
+    pub fn escape_pipes_in_inline_code(text: &str) -> String {
         let mut result = String::new();
-        let chars: Vec<char> = after_code_masking.chars().collect();
+        let chars: Vec<char> = text.chars().collect();
         let mut i = 0;
 
         while i < chars.len() {
-            if i + 1 < chars.len() && chars[i] == '\\' && chars[i + 1] == '|' {
-                // Found escaped pipe: \|
-                // Replace with \_ to keep same byte length while preventing split
-                result.push('\\');
-                result.push('_'); // Mask the pipe
-                i += 2;
+            if chars[i] == '`' {
+                let start = i;
+                let mut backtick_count = 0;
+                while i < chars.len() && chars[i] == '`' {
+                    backtick_count += 1;
+                    i += 1;
+                }
+
+                let mut found_closing = false;
+                let mut j = i;
+
+                while j < chars.len() {
+                    if chars[j] == '`' {
+                        let close_start = j;
+                        let mut close_count = 0;
+                        while j < chars.len() && chars[j] == '`' {
+                            close_count += 1;
+                            j += 1;
+                        }
+
+                        if close_count == backtick_count {
+                            found_closing = true;
+                            result.extend(chars[start..i].iter());
+
+                            for &ch in chars.iter().take(close_start).skip(i) {
+                                if ch == '|' {
+                                    result.push('\\');
+                                    result.push('|');
+                                } else {
+                                    result.push(ch);
+                                }
+                            }
+
+                            result.extend(chars[close_start..j].iter());
+                            i = j;
+                            break;
+                        }
+                    } else {
+                        j += 1;
+                    }
+                }
+
+                if !found_closing {
+                    result.extend(chars[start..i].iter());
+                }
             } else {
                 result.push(chars[i]);
                 i += 1;
@@ -341,6 +393,126 @@ impl TableUtils {
         result
     }
 
+    /// Mask escaped pipes for accurate table cell parsing
+    ///
+    /// In GFM tables, escape handling happens BEFORE cell boundary detection:
+    /// - `\|` → escaped pipe → masked (stays as cell content)
+    /// - `\\|` → escaped backslash + pipe → NOT masked (pipe is a delimiter)
+    ///
+    /// IMPORTANT: Inline code spans do NOT protect pipes in GFM tables!
+    /// The pipe in `` `a | b` `` still acts as a cell delimiter, splitting into
+    /// two cells: `` `a `` and ` b` ``. This matches GitHub's actual rendering.
+    ///
+    /// To include a literal pipe in a table cell (even in code), you must escape it:
+    /// `` `a \| b` `` → single cell containing `a | b` (with code formatting)
+    pub fn mask_pipes_for_table_parsing(text: &str) -> String {
+        let mut result = String::new();
+        let chars: Vec<char> = text.chars().collect();
+        let mut i = 0;
+
+        while i < chars.len() {
+            if chars[i] == '\\' {
+                if i + 1 < chars.len() && chars[i + 1] == '\\' {
+                    // Escaped backslash: \\ → push both and continue
+                    // The next character (if it's a pipe) will be a real delimiter
+                    result.push('\\');
+                    result.push('\\');
+                    i += 2;
+                } else if i + 1 < chars.len() && chars[i + 1] == '|' {
+                    // Escaped pipe: \| → mask the pipe
+                    result.push('\\');
+                    result.push('_'); // Mask the pipe
+                    i += 2;
+                } else {
+                    // Single backslash not followed by \ or | → just push it
+                    result.push(chars[i]);
+                    i += 1;
+                }
+            } else {
+                result.push(chars[i]);
+                i += 1;
+            }
+        }
+
+        result
+    }
+
+    /// Split a table row into individual cell contents with flavor-specific behavior.
+    ///
+    /// Returns a Vec of cell content strings (not trimmed - preserves original spacing).
+    /// This is the foundation for both cell counting and cell content extraction.
+    ///
+    /// For Standard/GFM flavor, pipes in inline code ARE cell delimiters (matches GitHub).
+    /// For MkDocs flavor, pipes in inline code are NOT cell delimiters.
+    pub fn split_table_row_with_flavor(row: &str, flavor: crate::config::MarkdownFlavor) -> Vec<String> {
+        let trimmed = row.trim();
+
+        if !trimmed.contains('|') {
+            return Vec::new();
+        }
+
+        // First, mask escaped pipes (same for all flavors)
+        let masked = Self::mask_pipes_for_table_parsing(trimmed);
+
+        // For MkDocs flavor, also mask pipes inside inline code
+        let final_masked = if flavor == crate::config::MarkdownFlavor::MkDocs {
+            Self::mask_pipes_in_inline_code(&masked)
+        } else {
+            masked
+        };
+
+        let has_leading = final_masked.starts_with('|');
+        let has_trailing = final_masked.ends_with('|');
+
+        let mut masked_content = final_masked.as_str();
+        let mut orig_content = trimmed;
+
+        if has_leading {
+            masked_content = &masked_content[1..];
+            orig_content = &orig_content[1..];
+        }
+
+        // Track whether we actually strip a trailing pipe
+        let stripped_trailing = has_trailing && !masked_content.is_empty();
+        if stripped_trailing {
+            masked_content = &masked_content[..masked_content.len() - 1];
+            orig_content = &orig_content[..orig_content.len() - 1];
+        }
+
+        // Handle edge cases for degenerate inputs
+        if masked_content.is_empty() {
+            if stripped_trailing {
+                // "||" case: two pipes with empty content between = one empty cell
+                return vec![String::new()];
+            } else {
+                // "|" case: single pipe, not a valid table row
+                return Vec::new();
+            }
+        }
+
+        let masked_parts: Vec<&str> = masked_content.split('|').collect();
+        let mut cells = Vec::new();
+        let mut pos = 0;
+
+        for masked_cell in masked_parts {
+            let cell_len = masked_cell.len();
+            let orig_cell = if pos + cell_len <= orig_content.len() {
+                &orig_content[pos..pos + cell_len]
+            } else {
+                masked_cell
+            };
+            cells.push(orig_cell.to_string());
+            pos += cell_len + 1; // +1 for the pipe delimiter
+        }
+
+        cells
+    }
+
+    /// Split a table row into individual cell contents using Standard/GFM behavior.
+    pub fn split_table_row(row: &str) -> Vec<String> {
+        Self::split_table_row_with_flavor(row, crate::config::MarkdownFlavor::Standard)
+    }
+
     /// Determine the pipe style of a table row
     pub fn determine_pipe_style(line: &str) -> Option<&'static str> {
         let trimmed = line.trim();
@@ -409,6 +581,39 @@ mod tests {
         assert!(TableUtils::is_potential_table_row("| | |")); // Two empty cells with spaces
     }
 
+    #[test]
+    fn test_list_items_with_pipes_not_table_rows() {
+        // Ordered list items should NOT be detected as table rows
+        assert!(!TableUtils::is_potential_table_row("1. Item with | pipe"));
+        assert!(!TableUtils::is_potential_table_row("10. Item with | pipe"));
+        assert!(!TableUtils::is_potential_table_row("999. Item with | pipe"));
+        assert!(!TableUtils::is_potential_table_row("1) Item with | pipe"));
+        assert!(!TableUtils::is_potential_table_row("10) Item with | pipe"));
+
+        // Unordered list items with tabs
+        assert!(!TableUtils::is_potential_table_row("-\tItem with | pipe"));
+        assert!(!TableUtils::is_potential_table_row("*\tItem with | pipe"));
+        assert!(!TableUtils::is_potential_table_row("+\tItem with | pipe"));
+
+        // Indented list items (the trim_start normalizes indentation)
+        assert!(!TableUtils::is_potential_table_row("  - Indented | pipe"));
+        assert!(!TableUtils::is_potential_table_row("    * Deep indent | pipe"));
+        assert!(!TableUtils::is_potential_table_row("  1. Ordered indent | pipe"));
+
+        // Task list items
+        assert!(!TableUtils::is_potential_table_row("- [ ] task | pipe"));
+        assert!(!TableUtils::is_potential_table_row("- [x] done | pipe"));
+
+        // Multiple pipes in list items
+        assert!(!TableUtils::is_potential_table_row("1. foo | bar | baz"));
+        assert!(!TableUtils::is_potential_table_row("- alpha | beta | gamma"));
+
+        // These SHOULD still be detected as potential table rows
+        assert!(TableUtils::is_potential_table_row("| cell | cell |"));
+        assert!(TableUtils::is_potential_table_row("cell | cell"));
+        assert!(TableUtils::is_potential_table_row("| Header | Header |"));
+    }
+
     #[test]
     fn test_is_delimiter_row() {
         // Basic delimiter rows
@@ -482,31 +687,38 @@ mod tests {
     }
 
     #[test]
-    fn test_count_cells_with_inline_code() {
-        // Test the user's actual example from Issue #34
+    fn test_count_cells_with_escaped_pipes() {
+        // In GFM tables, escape handling happens BEFORE cell splitting.
+        // Inline code does NOT protect pipes - they still act as cell delimiters.
+        // To include a literal pipe in a table cell, you MUST escape it with \|
+
+        // Basic table structure
         assert_eq!(TableUtils::count_cells("| Challenge | Solution |"), 2);
-        assert_eq!(
-            TableUtils::count_cells("| Hour:minute:second formats | `^([0-1]?\\d|2[0-3]):[0-5]\\d:[0-5]\\d$` |"),
-            2
-        );
-
-        // Test basic inline code with pipes
-        assert_eq!(TableUtils::count_cells("| Command | `echo | grep` |"), 2);
-        assert_eq!(TableUtils::count_cells("| A | `code | with | pipes` | B |"), 3);
-
-        // Test escaped pipes (correct GFM)
-        assert_eq!(TableUtils::count_cells("| Command | `echo \\| grep` |"), 2);
-
-        // Test multiple inline code blocks
-        assert_eq!(TableUtils::count_cells("| `code | one` | `code | two` |"), 2);
-
-        // Test edge cases
-        assert_eq!(TableUtils::count_cells("| Empty inline | `` | cell |"), 3);
-        assert_eq!(TableUtils::count_cells("| `single|pipe` |"), 1);
-
-        // Test that basic table structure still works
         assert_eq!(TableUtils::count_cells("| A | B | C |"), 3);
         assert_eq!(TableUtils::count_cells("| One | Two |"), 2);
+
+        // Escaped pipes: \| keeps the pipe as content
+        assert_eq!(TableUtils::count_cells(r"| Command | echo \| grep |"), 2);
+        assert_eq!(TableUtils::count_cells(r"| A | B \| C |"), 2); // B | C is one cell
+
+        // Escaped pipes inside backticks (correct way to include | in code in tables)
+        assert_eq!(TableUtils::count_cells(r"| Command | `echo \| grep` |"), 2);
+
+        // Double backslash + pipe: \\| means escaped backslash followed by pipe delimiter
+        assert_eq!(TableUtils::count_cells(r"| A | B \\| C |"), 3); // \\| is NOT escaped pipe
+        assert_eq!(TableUtils::count_cells(r"| A | `B \\| C` |"), 3); // Same inside code
+
+        // IMPORTANT: Bare pipes in inline code DO act as delimiters (GFM behavior)
+        // This matches GitHub's actual rendering where `a | b` splits into two cells
+        assert_eq!(TableUtils::count_cells("| Command | `echo | grep` |"), 3);
+        assert_eq!(TableUtils::count_cells("| `code | one` | `code | two` |"), 4);
+        assert_eq!(TableUtils::count_cells("| `single|pipe` |"), 2);
+
+        // The regex example from Issue #34 - pipes in regex patterns need escaping
+        // Unescaped: `^([0-1]?\d|2[0-3])` has a bare | which splits cells
+        assert_eq!(TableUtils::count_cells(r"| Hour formats | `^([0-1]?\d|2[0-3])` |"), 3);
+        // Escaped: `^([0-1]?\d\|2[0-3])` keeps the | as part of the regex
+        assert_eq!(TableUtils::count_cells(r"| Hour formats | `^([0-1]?\d\|2[0-3])` |"), 2);
     }
 
     #[test]
@@ -557,7 +769,7 @@ mod tests {
 | Cell 1    | Cell 2    |
 | Cell 3    | Cell 4    |";
 
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
 
         let tables = TableUtils::find_table_blocks(content, &ctx);
         assert_eq!(tables.len(), 1);
@@ -584,7 +796,7 @@ More text
 |----------|-------|
 | Data 2   | Data  |";
 
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
 
         let tables = TableUtils::find_table_blocks(content, &ctx);
         assert_eq!(tables.len(), 2);
@@ -611,7 +823,7 @@ More text
 
 Next paragraph";
 
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
 
         let tables = TableUtils::find_table_blocks(content, &ctx);
         assert_eq!(tables.len(), 1);
@@ -634,7 +846,7 @@ Next paragraph";
 |------|-------|
 | Data | Here  |";
 
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
 
         let tables = TableUtils::find_table_blocks(content, &ctx);
         assert_eq!(tables.len(), 1); // Only the table outside code block
@@ -651,7 +863,7 @@ No tables here
 - List item with | pipe
 * Another list item";
 
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
 
         let tables = TableUtils::find_table_blocks(content, &ctx);
         assert_eq!(tables.len(), 0);
@@ -667,7 +879,7 @@ But no delimiter row
 |---------|-------|
 | Data    | Here  |";
 
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
 
         let tables = TableUtils::find_table_blocks(content, &ctx);
         assert_eq!(tables.len(), 1); // Only the proper table
@@ -730,4 +942,70 @@ But no delimiter row
         assert_eq!(cloned.delimiter_line, block.delimiter_line);
         assert_eq!(cloned.content_lines, block.content_lines);
     }
+
+    #[test]
+    fn test_split_table_row() {
+        // Basic split
+        let cells = TableUtils::split_table_row("| Cell 1 | Cell 2 | Cell 3 |");
+        assert_eq!(cells.len(), 3);
+        assert_eq!(cells[0].trim(), "Cell 1");
+        assert_eq!(cells[1].trim(), "Cell 2");
+        assert_eq!(cells[2].trim(), "Cell 3");
+
+        // Without trailing pipe
+        let cells = TableUtils::split_table_row("| Cell 1 | Cell 2");
+        assert_eq!(cells.len(), 2);
+
+        // Empty cells
+        let cells = TableUtils::split_table_row("| | | |");
+        assert_eq!(cells.len(), 3);
+
+        // Single cell
+        let cells = TableUtils::split_table_row("| Cell |");
+        assert_eq!(cells.len(), 1);
+        assert_eq!(cells[0].trim(), "Cell");
+
+        // No pipes
+        let cells = TableUtils::split_table_row("No pipes here");
+        assert_eq!(cells.len(), 0);
+    }
+
+    #[test]
+    fn test_split_table_row_with_escaped_pipes() {
+        // Escaped pipes should be preserved in cell content
+        let cells = TableUtils::split_table_row(r"| A | B \| C |");
+        assert_eq!(cells.len(), 2);
+        assert!(cells[1].contains(r"\|"), "Escaped pipe should be in cell content");
+
+        // Double backslash + pipe is NOT escaped
+        let cells = TableUtils::split_table_row(r"| A | B \\| C |");
+        assert_eq!(cells.len(), 3);
+    }
+
+    #[test]
+    fn test_split_table_row_with_flavor_mkdocs() {
+        // MkDocs flavor: pipes in inline code are NOT cell delimiters
+        let cells =
+            TableUtils::split_table_row_with_flavor("| Type | `x | y` |", crate::config::MarkdownFlavor::MkDocs);
+        assert_eq!(cells.len(), 2);
+        assert!(
+            cells[1].contains("`x | y`"),
+            "Inline code with pipe should be single cell in MkDocs flavor"
+        );
+
+        // Multiple pipes in inline code
+        let cells =
+            TableUtils::split_table_row_with_flavor("| Type | `a | b | c` |", crate::config::MarkdownFlavor::MkDocs);
+        assert_eq!(cells.len(), 2);
+        assert!(cells[1].contains("`a | b | c`"));
+    }
+
+    #[test]
+    fn test_split_table_row_with_flavor_standard() {
+        // Standard/GFM flavor: pipes in inline code ARE cell delimiters
+        let cells =
+            TableUtils::split_table_row_with_flavor("| Type | `x | y` |", crate::config::MarkdownFlavor::Standard);
+        // In GFM, `x | y` splits into separate cells
+        assert_eq!(cells.len(), 3);
+    }
 }
