@@ -1,3 +1,4 @@
+use indexmap::IndexMap;
 use rumdl_lib::config::{Config, GlobalConfig, RuleConfig, normalize_key};
 use rumdl_lib::rule::Rule;
 use rumdl_lib::rules::*;
@@ -12,19 +13,27 @@ fn create_test_config() -> Config {
     md013_values.insert(normalize_key("line_length"), toml::Value::Integer(120));
     md013_values.insert(normalize_key("code_blocks"), toml::Value::Boolean(false));
     md013_values.insert(normalize_key("headings"), toml::Value::Boolean(true));
-    let md013_config = RuleConfig { values: md013_values };
+    let md013_config = RuleConfig {
+        severity: None,
+        values: md013_values,
+    };
     rules.insert(normalize_key("MD013"), md013_config);
 
     // Add MD004 config
     let mut md004_values = BTreeMap::new();
     md004_values.insert(normalize_key("style"), toml::Value::String("asterisk".to_string()));
-    let md004_config = RuleConfig { values: md004_values };
+    let md004_config = RuleConfig {
+        severity: None,
+        values: md004_values,
+    };
     rules.insert(normalize_key("MD004"), md004_config);
 
     Config {
         global: GlobalConfig::default(),
         per_file_ignores: HashMap::new(),
+        per_file_flavor: IndexMap::new(),
         rules,
+        project_root: None,
     }
 }
 
@@ -107,6 +116,7 @@ This is a line that exceeds the default 80 characters but is less than the confi
         &configured_rules,
         false,
         rumdl_lib::config::MarkdownFlavor::Standard,
+        None,
     )
     .expect("Linting should succeed");
 
@@ -166,6 +176,7 @@ fn test_config_priority() {
         &configured_rules_1,
         false,
         rumdl_lib::config::MarkdownFlavor::Standard,
+        None,
     )
     .expect("Linting should succeed");
 
@@ -182,7 +193,10 @@ fn test_config_priority() {
     // Now change config to 50 chars
     let mut md013_values = BTreeMap::new();
     md013_values.insert(normalize_key("line_length"), toml::Value::Integer(50));
-    let md013_config = RuleConfig { values: md013_values };
+    let md013_config = RuleConfig {
+        severity: None,
+        values: md013_values,
+    };
     // Need to use normalized key for insertion
     config.rules.insert(normalize_key("MD013"), md013_config);
 
@@ -195,6 +209,7 @@ fn test_config_priority() {
         &configured_rules_2,
         false,
         rumdl_lib::config::MarkdownFlavor::Standard,
+        None,
     )
     .expect("Linting should succeed");
     let md013_warnings = warnings
@@ -216,14 +231,19 @@ fn test_partial_rule_config() {
     let mut md013_values = BTreeMap::new();
     md013_values.insert(normalize_key("line_length"), toml::Value::Integer(100));
     // Note: code_blocks not specified, should keep default value
-    let md013_config = RuleConfig { values: md013_values };
+    let md013_config = RuleConfig {
+        severity: None,
+        values: md013_values,
+    };
     // Use normalized key
     rules_map.insert(normalize_key("MD013"), md013_config);
 
     let config = Config {
         global: GlobalConfig::default(),
         per_file_ignores: HashMap::new(),
+        per_file_flavor: IndexMap::new(),
         rules: rules_map,
+        project_root: None,
     };
 
     // Apply configs using LOCAL helper, getting a NEW vector
@@ -239,6 +259,7 @@ fn test_partial_rule_config() {
         &configured_rules_1,
         false,
         rumdl_lib::config::MarkdownFlavor::Standard,
+        None,
     )
     .expect("Linting should succeed");
 
@@ -253,14 +274,19 @@ fn test_partial_rule_config() {
     let mut rules_map = BTreeMap::new();
     let mut md013_values = BTreeMap::new();
     md013_values.insert(normalize_key("line_length"), toml::Value::Integer(60));
-    let md013_config = RuleConfig { values: md013_values };
+    let md013_config = RuleConfig {
+        severity: None,
+        values: md013_values,
+    };
     // Use normalized key
     rules_map.insert(normalize_key("MD013"), md013_config);
 
     let config = Config {
         global: GlobalConfig::default(),
         per_file_ignores: HashMap::new(),
+        per_file_flavor: IndexMap::new(),
         rules: rules_map,
+        project_root: None,
     };
 
     // Apply configs using LOCAL helper with modified config, getting ANOTHER NEW vector
@@ -272,6 +298,7 @@ fn test_partial_rule_config() {
         &configured_rules_2,
         false,
         rumdl_lib::config::MarkdownFlavor::Standard,
+        None,
     )
     .expect("Linting should succeed");
 
@@ -306,7 +333,7 @@ line_length = 20
     // Load using SourcedConfig::load_with_discovery with skip_auto_discovery: true
     let sourced_config_1 = rumdl_lib::config::SourcedConfig::load_with_discovery(Some(config_path_str), None, true)
         .expect("Failed to load config 1");
-    let config_1: Config = sourced_config_1.into(); // Convert
+    let config_1: Config = sourced_config_1.into_validated_unchecked().into(); // Convert
 
     // Test content with MD001 violation and MD013 violation
     let test_content = r#"
@@ -325,6 +352,7 @@ This line exceeds 20 characters.
         &configured_rules_1,
         false,
         rumdl_lib::config::MarkdownFlavor::Standard,
+        None,
     )
     .expect("Linting should succeed");
 
@@ -358,7 +386,7 @@ line_length = 20 # Set a low limit to trigger it
     // Load using SourcedConfig::load_with_discovery with skip_auto_discovery: true
     let sourced_config_2 = rumdl_lib::config::SourcedConfig::load_with_discovery(Some(config_path_str), None, true)
         .expect("Failed to load config 2");
-    let config_2: Config = sourced_config_2.into(); // Convert
+    let config_2: Config = sourced_config_2.into_validated_unchecked().into(); // Convert
 
     // Get all rules and apply config
     let initial_rules_2 = rumdl_lib::rules::all_rules(&rumdl_lib::config::Config::default());
@@ -370,6 +398,7 @@ line_length = 20 # Set a low limit to trigger it
         &configured_rules_2,
         false,
         rumdl_lib::config::MarkdownFlavor::Standard,
+        None,
     )
     .expect("Linting should succeed");
 
@@ -425,7 +454,7 @@ headings = true
     // Load using SourcedConfig::load_with_discovery with skip_auto_discovery: true
     let sourced_config = rumdl_lib::config::SourcedConfig::load_with_discovery(Some(config_path_str), None, true)
         .expect("Failed to load config");
-    let config: Config = sourced_config.into(); // Convert
+    let config: Config = sourced_config.into_validated_unchecked().into(); // Convert
 
     // Get all rules and apply config
     let initial_rules = rumdl_lib::rules::all_rules(&rumdl_lib::config::Config::default());
@@ -445,6 +474,7 @@ This line > 10.
         &configured_rules,
         false,
         rumdl_lib::config::MarkdownFlavor::Standard,
+        None,
     )
     .expect("Linting should succeed");
 
