@@ -11,7 +11,7 @@ fn test_md052_literal_brackets_not_reference() {
     let all_rules = rules::all_rules(&config);
     let md052_rules: Vec<_> = all_rules.into_iter().filter(|r| r.name() == "MD052").collect();
 
-    let warnings = rumdl_lib::lint(content, &md052_rules, false, MarkdownFlavor::Standard).unwrap();
+    let warnings = rumdl_lib::lint(content, &md052_rules, false, MarkdownFlavor::Standard, None).unwrap();
 
     // Should have NO warnings - [from ...] in backticks is literal text, not a reference
     assert_eq!(
@@ -25,7 +25,7 @@ fn test_md052_literal_brackets_not_reference() {
 #[test]
 fn test_md052_javascript_literals_not_flagged() {
     // Test for JavaScript/JSON literals that should not be flagged as references
-    // Note: [undefined] is excluded because it's too ambiguous (common English word)
+    // Note: Uses full reference syntax [text][label] since shortcut-syntax is disabled by default
     let content = r#"### Eval output
 (kind: ok) ["null"]
 [null]
@@ -35,15 +35,15 @@ fn test_md052_javascript_literals_not_flagged() {
 [Infinity]
 [object Object]
 
-But this [actual-reference] should be flagged."#;
+But this [link text][actual-reference] should be flagged."#;
 
     let config = Config::default();
     let all_rules = rules::all_rules(&config);
     let md052_rules: Vec<_> = all_rules.into_iter().filter(|r| r.name() == "MD052").collect();
 
-    let warnings = rumdl_lib::lint(content, &md052_rules, false, MarkdownFlavor::Standard).unwrap();
+    let warnings = rumdl_lib::lint(content, &md052_rules, false, MarkdownFlavor::Standard, None).unwrap();
 
-    // Should only flag [actual-reference], not the JavaScript literals
+    // Should only flag [link text][actual-reference], not the JavaScript literals
     assert_eq!(
         warnings.len(),
         1,
@@ -66,7 +66,7 @@ Some other text."#;
     let all_rules = rules::all_rules(&config);
     let md052_rules: Vec<_> = all_rules.into_iter().filter(|r| r.name() == "MD052").collect();
 
-    let warnings = rumdl_lib::lint(content, &md052_rules, false, MarkdownFlavor::Standard).unwrap();
+    let warnings = rumdl_lib::lint(content, &md052_rules, false, MarkdownFlavor::Standard, None).unwrap();
 
     // Should have a warning - this is an actual broken reference
     assert_eq!(warnings.len(), 1, "MD052 should report actual broken references");
