@@ -14,19 +14,19 @@ fn test_large_repository_simulation() {
     ];
 
     let rules: Vec<Box<dyn Rule>> = vec![
-        Box::new(MD001HeadingIncrement),
+        Box::new(MD001HeadingIncrement::default()),
         Box::new(MD009TrailingSpaces::default()),
         Box::new(MD011NoReversedLinks),
         Box::new(MD022BlanksAroundHeadings::default()),
         Box::new(MD031BlanksAroundFences::default()),
-        Box::new(MD032BlanksAroundLists),
+        Box::new(MD032BlanksAroundLists::default()),
     ];
 
     for (filename, content) in &test_files {
         println!("Testing file: {filename}");
         let start_time = Instant::now();
 
-        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
         let mut all_warnings = Vec::new();
 
         for rule in &rules {
@@ -425,7 +425,7 @@ fn test_memory_usage_with_large_content() {
     // Create LintContext ONCE and share it across all rules
     // This is more realistic to actual usage where the context is created once per file
     let ctx_start = Instant::now();
-    let ctx = LintContext::new(&large_content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(&large_content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let ctx_duration = ctx_start.elapsed();
     println!(
         "LintContext creation for 50k lines took: {:.2}s",
