@@ -11,7 +11,7 @@ fn test_unicode_list_items_valid() {
   * Nested item with 汉字
   * Nested item with こんにちは
 * Item with Arabic مرحبا";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
@@ -28,8 +28,10 @@ fn test_unicode_list_items_invalid() {
    * Nested item with 汉字 (wrong indent)
   * Another nested with こんにちは (wrong indent)
 * Item with Arabic مرحبا";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
+    // Dynamic detection: Line 3 with 3 spaces is accepted as a valid nested indent
+    // Only lines 2 (1 space) and 4 (2 spaces) are flagged as incorrect
     assert_eq!(
         result.len(),
         2,
@@ -40,11 +42,11 @@ fn test_unicode_list_items_invalid() {
     let violation_lines: Vec<usize> = result.iter().map(|w| w.line).collect();
     assert!(
         violation_lines.contains(&2),
-        "Should have violation on line 2 (1 space instead of 2)"
+        "Should have violation on line 2 (1 space instead of 0)"
     );
     assert!(
-        violation_lines.contains(&3),
-        "Should have violation on line 3 (3 spaces instead of 2)"
+        violation_lines.contains(&4),
+        "Should have violation on line 4 (2 spaces instead of 0 or 3)"
     );
 }
 
@@ -58,7 +60,7 @@ fn test_unicode_mixed_list_types() {
 * Back to unordered with こんにちは
   - Dash item with مرحبا
   + Plus item with ñáéíóú";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
@@ -75,7 +77,7 @@ fn test_unicode_complex_nesting() {
     * Level 3 with ñáéíóú
       * Level 4 with русский
         * Level 5 with עברית";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
@@ -92,7 +94,7 @@ fn test_unicode_complex_nesting_invalid() {
   * Level 2 with こんにちは (correct indent - 2 spaces)
      * Level 3 with ñáéíóú (wrong indent - 5 spaces)
     * Level 3 with русский (correct indent - 4 spaces)";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     // Dynamic detection: accepts 3-space pattern from line 2
     assert_eq!(
@@ -109,7 +111,7 @@ fn test_unicode_fix_functionality() {
 * Item with Unicode café
  * Wrong indent with 🔥
    * Also wrong with 汉字";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let fixed = rule.fix(&ctx).unwrap();
     // Dynamic detection: line 2 gets fixed to position 0 (top-level)
     assert_eq!(
@@ -127,7 +129,7 @@ fn test_unicode_in_blockquotes() {
 >   * Nested with 汉字
 >   * Another nested with 🔥
 > * Back to level 1 with こんにちは";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
@@ -145,7 +147,7 @@ fn test_unicode_with_continuation_text() {
   * Nested item with こんにちは
     Nested continuation with مرحبا
 * Another item with ñáéíóú";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
@@ -164,7 +166,7 @@ fn test_unicode_edge_cases() {
   * Arabic with diacritics: مَرْحَبًا
 * Unicode whitespace variants should still work";
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
@@ -180,7 +182,7 @@ fn test_unicode_rtl_content() {
   * Nested Hebrew: עוד טקסט עברי
   * Arabic text: مرحبا بالعالم
 * Mixed RTL and LTR: Hello שלום مرحبا";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
