@@ -6,7 +6,7 @@ use rumdl_lib::rules::MD011NoReversedLinks;
 fn test_md011_valid() {
     let rule = MD011NoReversedLinks {};
     let content = "[text](link)\n[more text](another/link)\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -15,7 +15,7 @@ fn test_md011_valid() {
 fn test_md011_invalid() {
     let rule = MD011NoReversedLinks {};
     let content = "(link)[text]\n(another/link)[more text]\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2);
     assert_eq!(result[0].line, 1);
@@ -26,7 +26,7 @@ fn test_md011_invalid() {
 fn test_md011_mixed() {
     let rule = MD011NoReversedLinks {};
     let content = "[text](link)\n(link)[reversed]\n[text](link)\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
     assert_eq!(result[0].line, 2);
@@ -36,7 +36,7 @@ fn test_md011_mixed() {
 fn test_md011_fix() {
     let rule = MD011NoReversedLinks {};
     let content = "(link)[text]\n(another/link)[more text]\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.fix(&ctx).unwrap();
     assert_eq!(result, "[text](link)\n[more text](another/link)\n");
 }
@@ -46,7 +46,7 @@ fn test_md011_url_in_brackets() {
     let rule = MD011NoReversedLinks {};
     // When URL is in the square brackets, we should detect and swap correctly
     let content = "(foobar)[https://boofar]\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.fix(&ctx).unwrap();
     assert_eq!(
         result, "[foobar](https://boofar)\n",
@@ -59,7 +59,7 @@ fn test_md011_various_url_patterns() {
     let rule = MD011NoReversedLinks {};
     // Test different URL patterns
     let content = "(text)[http://example.com]\n(more text)[https://example.org]\n(link text)[www.example.com]\n(description)[/path/to/page]\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.fix(&ctx).unwrap();
     assert_eq!(
         result,
@@ -72,7 +72,7 @@ fn test_md011_descriptive_text_detection() {
     let rule = MD011NoReversedLinks {};
     // When one part is clearly descriptive text and the other is a URL
     let content = "(Click here for more info)[https://example.com]\n(https://docs.rs)[Read the documentation]\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.fix(&ctx).unwrap();
     assert_eq!(
         result,
@@ -85,7 +85,7 @@ fn test_md011_fragment_links() {
     let rule = MD011NoReversedLinks {};
     // Fragment links should be detected as URLs
     let content = "(introduction)[#introduction]\n(#getting-started)[Getting Started]\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.fix(&ctx).unwrap();
     assert_eq!(
         result,
@@ -98,7 +98,7 @@ fn test_md011_relative_paths() {
     let rule = MD011NoReversedLinks {};
     // Relative paths should be detected as URLs
     let content = "(Guide)[./docs/guide.md]\n(../README.md)[Parent README]\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.fix(&ctx).unwrap();
     assert_eq!(result, "[Guide](./docs/guide.md)\n[Parent README](../README.md)\n");
 }
@@ -108,7 +108,7 @@ fn test_md011_mailto_links() {
     let rule = MD011NoReversedLinks {};
     // Mailto links should be detected as URLs
     let content = "(Contact us)[mailto:support@example.com]\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.fix(&ctx).unwrap();
     assert_eq!(result, "[Contact us](mailto:support@example.com)\n");
 }
@@ -118,7 +118,7 @@ fn test_md011_domain_with_tld() {
     let rule = MD011NoReversedLinks {};
     // Domains with common TLDs should be detected
     let content = "(Example Site)[example.com]\n(docs.rust-lang.org)[Rust Docs]\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.fix(&ctx).unwrap();
     assert_eq!(result, "[Example Site](example.com)\n[Rust Docs](docs.rust-lang.org)\n");
 }
@@ -128,7 +128,7 @@ fn test_md011_ambiguous_cases() {
     let rule = MD011NoReversedLinks {};
     // When both parts are ambiguous, assume standard reversed pattern (URL in parens)
     let content = "(foo)[bar]\n(test)[demo]\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.fix(&ctx).unwrap();
     assert_eq!(result, "[bar](foo)\n[demo](test)\n");
 }
@@ -138,7 +138,7 @@ fn test_md011_both_urls() {
     let rule = MD011NoReversedLinks {};
     // When both parts look like URLs, prefer parentheses as URL (standard reversed pattern)
     let content = "(https://example.com)[https://other.com]\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.fix(&ctx).unwrap();
     assert_eq!(result, "[https://other.com](https://example.com)\n");
 }
@@ -154,7 +154,7 @@ fn test_md011_mixed_complexity() {
 (simple)[link]
 (https://github.com)[Check out the code]
 "#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.fix(&ctx).unwrap();
     assert_eq!(
         result,
@@ -175,22 +175,8 @@ fn test_md011_not_false_positive_on_hashtags() {
     // Note: Current implementation will still treat valid-looking fragments as URLs
     // This test documents expected behavior for clear non-URL cases
     let content = "(define)[macro]\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.fix(&ctx).unwrap();
     // Ambiguous case: defaults to standard reversed pattern
     assert_eq!(result, "[macro](define)\n");
 }
-
-#[test]
-#[ignore] // TODO: Improve mathematical expression detection - currently partially implemented
-fn test_md011_mathematical_expressions_not_flagged() {
-    let rule = MD011NoReversedLinks {};
-    let content =
-        "The function f(x)[derivative] is important.\nAlso g(y)[second derivative] and h(x,y)[partial derivative].\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
-    let result = rule.check(&ctx).unwrap();
-    assert!(
-        result.is_empty(),
-        "Mathematical expressions should not be flagged as reversed links, but got: {result:?}"
-    );
-}
