@@ -6,7 +6,7 @@ use rumdl_lib::rules::MD019NoMultipleSpaceAtx;
 fn test_valid_atx_headings() {
     let rule = MD019NoMultipleSpaceAtx::new();
     let content = "# Heading 1\n## Heading 2\n### Heading 3";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -15,7 +15,7 @@ fn test_valid_atx_headings() {
 fn test_invalid_atx_headings() {
     let rule = MD019NoMultipleSpaceAtx::new();
     let content = "#  Heading 1\n##   Heading 2\n###    Heading 3";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 3);
     assert_eq!(result[0].line, 1);
@@ -27,7 +27,7 @@ fn test_invalid_atx_headings() {
 fn test_mixed_atx_headings() {
     let rule = MD019NoMultipleSpaceAtx::new();
     let content = "# Heading 1\n##  Heading 2\n### Heading 3\n####   Heading 4";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2);
 }
@@ -36,7 +36,7 @@ fn test_mixed_atx_headings() {
 fn test_code_block() {
     let rule = MD019NoMultipleSpaceAtx::new();
     let content = "```markdown\n#  Not a heading\n##   Also not a heading\n```\n# Real Heading";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -45,7 +45,7 @@ fn test_code_block() {
 fn test_fix_atx_headings() {
     let rule = MD019NoMultipleSpaceAtx::new();
     let content = "#  Heading 1\n##   Heading 2\n###    Heading 3";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let fixed = rule.fix(&ctx).unwrap();
     assert_eq!(fixed, "# Heading 1\n## Heading 2\n### Heading 3");
 }
@@ -54,7 +54,7 @@ fn test_fix_atx_headings() {
 fn test_fix_mixed_atx_headings() {
     let rule = MD019NoMultipleSpaceAtx::new();
     let content = "# Heading 1\n##  Heading 2\n### Heading 3\n####   Heading 4";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let fixed = rule.fix(&ctx).unwrap();
     assert_eq!(fixed, "# Heading 1\n## Heading 2\n### Heading 3\n#### Heading 4");
 }
@@ -63,7 +63,7 @@ fn test_fix_mixed_atx_headings() {
 fn test_preserve_code_blocks() {
     let rule = MD019NoMultipleSpaceAtx::new();
     let content = "# Real Heading\n```\n#  Not a heading\n```\n# Another Heading";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let fixed = rule.fix(&ctx).unwrap();
     assert_eq!(fixed, "# Real Heading\n```\n#  Not a heading\n```\n# Another Heading");
 }
@@ -72,7 +72,7 @@ fn test_preserve_code_blocks() {
 fn test_heading_with_multiple_hashes() {
     let rule = MD019NoMultipleSpaceAtx::new();
     let content = "######  Heading 6";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
     assert_eq!(result[0].message, "Multiple spaces (2) after ###### in heading");
@@ -84,7 +84,7 @@ fn test_heading_with_multiple_hashes() {
 fn test_not_a_heading() {
     let rule = MD019NoMultipleSpaceAtx::new();
     let content = "This is #  not a heading\nAnd this is also #   not a heading";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -93,7 +93,7 @@ fn test_not_a_heading() {
 fn test_closed_atx_headings() {
     let rule = MD019NoMultipleSpaceAtx::new();
     let content = "#  Heading 1 #\n##   Heading 2 ##\n###    Heading 3 ###";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 3);
     let fixed = rule.fix(&ctx).unwrap();
@@ -104,7 +104,7 @@ fn test_closed_atx_headings() {
 fn test_many_spaces() {
     let rule = MD019NoMultipleSpaceAtx::new();
     let content = "#     Heading with many spaces\n##      Another heading";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2);
     assert_eq!(result[0].message, "Multiple spaces (5) after # in heading");
@@ -116,7 +116,7 @@ fn test_many_spaces() {
 fn test_empty_headings() {
     let rule = MD019NoMultipleSpaceAtx::new();
     let content = "#\n##\n###";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -125,7 +125,7 @@ fn test_empty_headings() {
 fn test_invalid_multiple_spaces() {
     let rule = MD019NoMultipleSpaceAtx::new();
     let content = "#  Multiple Spaces\n\nRegular content\n\n##   More Spaces";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2);
     assert_eq!(result[0].line, 1);
@@ -136,7 +136,7 @@ fn test_invalid_multiple_spaces() {
 fn test_valid_single_space() {
     let rule = MD019NoMultipleSpaceAtx::new();
     let content = "# Single Space\n\n## Also correct";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -145,7 +145,7 @@ fn test_valid_single_space() {
 fn test_fix_multiple_spaces() {
     let rule = MD019NoMultipleSpaceAtx::new();
     let content = "#  Multiple Spaces\n\n##   More Spaces";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let fixed = rule.fix(&ctx).unwrap();
     assert_eq!(fixed, "# Multiple Spaces\n\n## More Spaces");
 }
