@@ -6,7 +6,7 @@ use rumdl_lib::rules::MD026NoTrailingPunctuation;
 fn test_md026_valid() {
     let rule = MD026NoTrailingPunctuation::default();
     let content = "# Heading 1\n## Heading 2\n### Heading 3\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -16,7 +16,7 @@ fn test_md026_invalid() {
     let rule = MD026NoTrailingPunctuation::default();
     // Default punctuation is ".,;:!" so ! and . are flagged, ? is not
     let content = "# Heading 1!\n## Heading 2?\n### Heading 3.\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     // ! and . should be flagged, ? should not
     assert_eq!(result.len(), 2);
@@ -29,7 +29,7 @@ fn test_md026_mixed() {
     let rule = MD026NoTrailingPunctuation::default();
     // Exclamation marks are now in the default punctuation list
     let content = "# Heading 1\n## Heading 2!\n### Heading 3\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     // Heading 2 should be flagged for the exclamation mark
     assert_eq!(result.len(), 1);
@@ -41,7 +41,7 @@ fn test_md026_fix() {
     let rule = MD026NoTrailingPunctuation::default();
     // Default punctuation is ".,;:!" so ! and . are fixed, ? is not
     let content = "# Heading 1!\n## Heading 2?\n### Heading 3.\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.fix(&ctx).unwrap();
     // ! and . should be removed, ? should remain
     assert_eq!(result, "# Heading 1\n## Heading 2?\n### Heading 3\n");
@@ -52,7 +52,7 @@ fn test_md026_custom_punctuation() {
     // When using custom punctuation, the lenient rules don't apply
     let rule = MD026NoTrailingPunctuation::new(Some("!?".to_string()));
     let content = "# Heading 1!\n## Heading 2?\n### Heading 3.\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2); // Only ! and ? should be detected, not .
     assert_eq!(result[0].line, 1);
@@ -64,7 +64,7 @@ fn test_md026_setext_headings() {
     let rule = MD026NoTrailingPunctuation::default();
     // Default punctuation is ".,;:!" so ! is flagged, ? is not
     let content = "Heading 1!\n=======\nHeading 2?\n-------\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     // Only the exclamation mark should be flagged
     assert_eq!(result.len(), 1);
@@ -76,7 +76,7 @@ fn test_md026_closed_atx() {
     let rule = MD026NoTrailingPunctuation::default();
     // Default punctuation is ".,;:!" so ! is flagged, ? is not
     let content = "# Heading 1! #\n## Heading 2? ##\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     // Only the exclamation mark should be flagged
     assert_eq!(result.len(), 1);
@@ -90,7 +90,7 @@ fn test_md026_closed_atx() {
 fn test_md026_empty_document() {
     let rule = MD026NoTrailingPunctuation::default();
     let content = "";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty(), "Empty documents should not produce warnings");
 }
@@ -99,7 +99,7 @@ fn test_md026_empty_document() {
 fn test_md026_with_code_blocks() {
     let rule = MD026NoTrailingPunctuation::default();
     let content = "# Valid heading\n\n```\n# This is a code block with heading syntax!\n```\n\n```rust\n# This is another code block with a punctuation mark.\n```";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty(), "Content in code blocks should be ignored");
 }
@@ -109,7 +109,7 @@ fn test_md026_with_front_matter() {
     let rule = MD026NoTrailingPunctuation::default();
     // Default punctuation is ".,;:!" so ! is flagged
     let content = "---\ntitle: This is a title with punctuation!\ndate: 2023-01-01\n---\n\n# Correct heading\n## Heading with punctuation!\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     // The second heading should be flagged for the exclamation mark
     assert_eq!(result.len(), 1, "Second heading should be flagged");
@@ -130,7 +130,7 @@ fn test_md026_multiple_trailing_punctuation() {
     // Default punctuation is ".,;:!" so . is flagged
     // The first heading ends with ??? which is allowed, so only periods are flagged
     let content = "# Heading with multiple marks!!!???\n## Another heading.....";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     // Only the second heading should be flagged (ends with periods)
     // The first heading ends with ??? which is not in the punctuation list
@@ -147,7 +147,7 @@ fn test_md026_indented_headings() {
     let rule = MD026NoTrailingPunctuation::default();
     // Default punctuation is ".,;:!" so ! is flagged, ? is not
     let content = "  # Indented heading!\n    ## Deeply indented heading?";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     // Only the exclamation mark should be flagged
@@ -164,7 +164,7 @@ fn test_md026_fix_setext_headings() {
     let rule = MD026NoTrailingPunctuation::default();
     // Default punctuation is ".,;:!" so ! is fixed, ? is not
     let content = "Heading 1!\n=======\nHeading 2?\n-------";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
 
     let fixed = rule.fix(&ctx).unwrap();
 
@@ -190,7 +190,7 @@ fn test_md026_performance() {
     // Measure performance
     use std::time::Instant;
     let start = Instant::now();
-    let ctx = LintContext::new(&content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(&content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     let duration = start.elapsed();
 
@@ -209,7 +209,7 @@ fn test_md026_performance() {
 fn test_md026_non_standard_punctuation() {
     let rule = MD026NoTrailingPunctuation::new(Some("@$%".to_string()));
     let content = "# Heading 1@\n## Heading 2$\n### Heading 3%\n#### Heading 4#\n##### Heading 5!\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 3);
     assert_eq!(result[0].line, 1);
@@ -234,7 +234,7 @@ fn test_md026_inline_code_with_punctuation() {
 #### Variable `x;`
 ##### Code `y,`"#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     // Only the headings ending with actual punctuation should be flagged
@@ -254,7 +254,7 @@ fn test_md026_unicode_punctuation() {
 ##### Spanish inverted exclamation¡
 ###### French guillemets»"#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     // Default rule only checks for ASCII punctuation
@@ -285,7 +285,7 @@ fn test_md026_edge_cases() {
 ## Heading with [brackets].
 ### Heading with {braces}."#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     // Count the actual violations
@@ -321,7 +321,7 @@ fn test_md026_fix_preserves_formatting() {
 
     // Test that fix preserves spacing and formatting
     let content = "# Heading with period.    \n## Another heading with comma,\t\n###No space heading;";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let fixed = rule.fix(&ctx).unwrap();
 
     // Check that punctuation is removed
@@ -338,7 +338,7 @@ fn test_md026_atx_closed_style_fix() {
 
     // Test closed ATX style headings
     let content = "# Heading 1. #\n## Heading 2, ##\n### Heading 3; ###";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let fixed = rule.fix(&ctx).unwrap();
 
     // Ensure closing hashes are preserved
@@ -358,7 +358,7 @@ Another with comma,
 Yet another with semicolon;
 ========"#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     // All should be flagged
@@ -390,7 +390,7 @@ fn test_md026_deeply_nested_headings() {
 ####### Seven hashes text.
 ######## Eight hashes text."#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     // Based on the output, it appears that 7+ hashes are treated as headings
@@ -427,7 +427,7 @@ Some paragraph with punctuation.
 |-------|--------|
 | Data. | More.  |"#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     // Should flag headings but not other content
@@ -443,7 +443,7 @@ fn test_md026_config_empty_punctuation() {
     // Test with empty punctuation config (should flag nothing)
     let rule = MD026NoTrailingPunctuation::new(Some("".to_string()));
     let content = "# Heading!\n## Heading?\n### Heading.\n#### Heading,\n##### Heading;";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     assert_eq!(result.len(), 0, "Empty punctuation config should not flag anything");
@@ -454,7 +454,7 @@ fn test_md026_single_character_punctuation() {
     // Test with single character punctuation
     let rule = MD026NoTrailingPunctuation::new(Some("!".to_string()));
     let content = "# Warning!\n## Question?\n### Statement.\n#### List,\n##### Code;";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     assert_eq!(result.len(), 1);
@@ -478,7 +478,7 @@ fn test_md026_special_regex_characters() {
 ##### Heading[
 ###### Heading]"#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     // Should handle regex special characters properly
@@ -499,7 +499,7 @@ fn test_md026_alphanumeric_as_punctuation() {
 ##### Heading ending with c
 ###### Heading ending with 3"#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     // Should flag headings ending with configured alphanumeric characters
@@ -529,7 +529,7 @@ fn test_md026_mixed_alphanumeric_and_punctuation() {
 #### Heading 1
 ##### Heading?"#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     // Should flag ., !, a, and 1 but not ?
