@@ -6,7 +6,7 @@ use rumdl_lib::rules::MD039NoSpaceInLinks;
 fn test_valid_links() {
     let rule = MD039NoSpaceInLinks;
     let content = "[link](url) and [another link](url) here";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -15,7 +15,7 @@ fn test_valid_links() {
 fn test_spaces_both_ends() {
     let rule = MD039NoSpaceInLinks;
     let content = "[ link ](url) and [ another link ](url) here";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2);
     let fixed = rule.fix(&ctx).unwrap();
@@ -26,7 +26,7 @@ fn test_spaces_both_ends() {
 fn test_space_at_start() {
     let rule = MD039NoSpaceInLinks;
     let content = "[ link](url) and [ another link](url) here";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2);
     let fixed = rule.fix(&ctx).unwrap();
@@ -37,7 +37,7 @@ fn test_space_at_start() {
 fn test_space_at_end() {
     let rule = MD039NoSpaceInLinks;
     let content = "[link ](url) and [another link ](url) here";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2);
     let fixed = rule.fix(&ctx).unwrap();
@@ -48,7 +48,7 @@ fn test_space_at_end() {
 fn test_link_in_code_block() {
     let rule = MD039NoSpaceInLinks;
     let content = "```\n[ link ](url)\n```\n[ link ](url)";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
     let fixed = rule.fix(&ctx).unwrap();
@@ -59,7 +59,7 @@ fn test_link_in_code_block() {
 fn test_multiple_links() {
     let rule = MD039NoSpaceInLinks;
     let content = "[ link ](url) and [ another ](url) in one line";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2);
     let fixed = rule.fix(&ctx).unwrap();
@@ -70,7 +70,7 @@ fn test_multiple_links() {
 fn test_link_with_internal_spaces() {
     let rule = MD039NoSpaceInLinks;
     let content = "[this is link](url) and [ this is also link ](url)";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
     let fixed = rule.fix(&ctx).unwrap();
@@ -81,7 +81,7 @@ fn test_link_with_internal_spaces() {
 fn test_link_with_punctuation() {
     let rule = MD039NoSpaceInLinks;
     let content = "[ link! ](url) and [ link? ](url) here";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2);
     let fixed = rule.fix(&ctx).unwrap();
@@ -97,7 +97,7 @@ mod parity_with_markdownlint {
     fn parity_leading_trailing_space() {
         let input = "[ link](url) and [another link ](url)";
         let expected = "[link](url) and [another link](url)";
-        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard, None);
         let rule = MD039NoSpaceInLinks::new();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -109,7 +109,7 @@ mod parity_with_markdownlint {
     fn parity_both_ends_spaced() {
         let input = "[ link ](url) and [ another link ](url)";
         let expected = "[link](url) and [another link](url)";
-        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard, None);
         let rule = MD039NoSpaceInLinks::new();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -121,7 +121,7 @@ mod parity_with_markdownlint {
     fn parity_internal_spaces_only() {
         let input = "[this is link](url) and [another link](url)";
         let expected = "[this is link](url) and [another link](url)";
-        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard, None);
         let rule = MD039NoSpaceInLinks::new();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -139,7 +139,7 @@ mod parity_with_markdownlint {
 [ link ](url)
 ```
 [link](url)";
-        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard, None);
         let rule = MD039NoSpaceInLinks::new();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -151,7 +151,7 @@ mod parity_with_markdownlint {
     fn parity_multiple_links_per_line() {
         let input = "[ link ](url) and [ another ](url) in one line";
         let expected = "[link](url) and [another](url) in one line";
-        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard, None);
         let rule = MD039NoSpaceInLinks::new();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -163,7 +163,7 @@ mod parity_with_markdownlint {
     fn parity_punctuation_in_link_text() {
         let input = "[ link! ](url) and [ link? ](url) here";
         let expected = "[link!](url) and [link?](url) here";
-        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard, None);
         let rule = MD039NoSpaceInLinks::new();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -176,7 +176,7 @@ mod parity_with_markdownlint {
         let input = "[   ](url) and [ ](url)";
         // markdownlint removes all spaces, resulting in empty link text
         let expected = "[](url) and [](url)";
-        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard, None);
         let rule = MD039NoSpaceInLinks::new();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -189,7 +189,7 @@ mod parity_with_markdownlint {
         let input = "[ link ][ref] and [ another ][ref2]\n\n[ref]: url\n[ref2]: url2";
         // markdownlint does not fix reference-style links for MD039, so output is unchanged
         let expected = "[ link ][ref] and [ another ][ref2]\n\n[ref]: url\n[ref2]: url2";
-        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard, None);
         let rule = MD039NoSpaceInLinks::new();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -202,7 +202,7 @@ mod parity_with_markdownlint {
     fn parity_unicode_whitespace() {
         let input = "[\u{00A0}link\u{00A0}](url) and [\u{2003}another\u{2003}](url)"; // non-breaking space and em space
         let expected = "[link](url) and [another](url)";
-        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard, None);
         let rule = MD039NoSpaceInLinks::new();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -214,7 +214,7 @@ mod parity_with_markdownlint {
     fn parity_tab_whitespace() {
         let input = "[\tlink\t](url) and [\tanother\t](url)";
         let expected = "[link](url) and [another](url)";
-        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard, None);
         let rule = MD039NoSpaceInLinks::new();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -226,7 +226,7 @@ mod parity_with_markdownlint {
     fn parity_only_whitespace_and_newlines() {
         let input = "[   \n  ](url) and [\t\n\t](url)";
         let expected = "[](url) and [](url)";
-        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard, None);
         let rule = MD039NoSpaceInLinks::new();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -238,7 +238,7 @@ mod parity_with_markdownlint {
     fn parity_internal_newlines() {
         let input = "[link\ntext](url) and [ another\nlink ](url)";
         let expected = "[link\ntext](url) and [another\nlink](url)";
-        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard, None);
         let rule = MD039NoSpaceInLinks::new();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -250,7 +250,7 @@ mod parity_with_markdownlint {
     fn parity_nested_formatting() {
         let input = "[ * link * ](url) and [ _ another _ ](url)";
         let expected = "[* link *](url) and [_ another _](url)";
-        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard, None);
         let rule = MD039NoSpaceInLinks::new();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -262,7 +262,7 @@ mod parity_with_markdownlint {
     fn parity_escaped_brackets() {
         let input = "[link\\]](url) and [link\\[]](url)";
         let expected = "[link\\]](url) and [link\\[]](url)";
-        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard, None);
         let rule = MD039NoSpaceInLinks::new();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -274,7 +274,7 @@ mod parity_with_markdownlint {
     fn parity_inline_images() {
         let input = "![ alt ](img.png) and ![ another ](img2.png)";
         let expected = "![alt](img.png) and ![another](img2.png)";
-        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard, None);
         let rule = MD039NoSpaceInLinks::new();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -286,7 +286,7 @@ mod parity_with_markdownlint {
     fn parity_html_entities() {
         let input = "[ &nbsp;link&nbsp; ](url)";
         let expected = "[&nbsp;link&nbsp;](url)";
-        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard, None);
         let rule = MD039NoSpaceInLinks::new();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
