@@ -10,7 +10,7 @@ fn test_matching_headings() {
     ];
     let rule = MD043RequiredHeadings::new(required);
     let content = "# Introduction\n\n# Methods\n\n# Results";
-    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -24,7 +24,7 @@ fn test_missing_heading() {
     ];
     let rule = MD043RequiredHeadings::new(required);
     let content = "# Introduction\n\n# Results";
-    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(!result.is_empty());
     let fixed = rule.fix(&ctx).unwrap();
@@ -37,7 +37,7 @@ fn test_extra_heading() {
     let required = vec!["# Introduction".to_string(), "# Results".to_string()];
     let rule = MD043RequiredHeadings::new(required);
     let content = "# Introduction\n\n# Methods\n\n# Results";
-    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(!result.is_empty());
     let fixed = rule.fix(&ctx).unwrap();
@@ -54,7 +54,7 @@ fn test_wrong_order() {
     ];
     let rule = MD043RequiredHeadings::new(required);
     let content = "# Introduction\n\n# Results\n\n# Methods";
-    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(!result.is_empty());
     let fixed = rule.fix(&ctx).unwrap();
@@ -67,7 +67,7 @@ fn test_empty_required_headings() {
     let required = vec![];
     let rule = MD043RequiredHeadings::new(required);
     let content = "# Any heading\n\n# Another heading";
-    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
     let fixed = rule.fix(&ctx).unwrap();
@@ -79,7 +79,7 @@ fn test_case_sensitive() {
     let required = vec!["# Introduction".to_string()];
     let rule = MD043RequiredHeadings::new(required);
     let content = "# INTRODUCTION";
-    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty()); // Should match because match_case is false by default
 }
@@ -89,7 +89,7 @@ fn test_mixed_heading_styles() {
     let required = vec!["# Introduction".to_string(), "======= Methods".to_string()];
     let rule = MD043RequiredHeadings::new(required);
     let content = "# Introduction\nContent\nMethods\n=======";
-    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -103,13 +103,13 @@ fn test_asterisk_wildcard_integration() {
 
     // Should pass with optional sections between README and License
     let content = "# README\n\n## Installation\n\n## Usage\n\n### Examples\n\n## License";
-    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 
     // Should pass with no sections between README and License
     let content = "# README\n\n## License";
-    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -125,13 +125,13 @@ fn test_plus_wildcard_integration() {
 
     // Should pass with one or more sections
     let content = "# Documentation\n\n## API\n\n## Contributing";
-    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 
     // Should fail with zero sections
     let content = "# Documentation\n\n## Contributing";
-    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(!result.is_empty());
 }
@@ -147,19 +147,19 @@ fn test_question_wildcard_integration() {
 
     // Should pass with variable project title
     let content = "# My Awesome Project\n\n## Description\n\n## Installation";
-    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 
     // Should pass with different title
     let content = "# Another Project\n\n## Description\n\n## Installation";
-    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 
     // Should fail without any title
     let content = "## Description\n\n## Installation";
-    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(!result.is_empty());
 }
@@ -179,19 +179,19 @@ fn test_real_world_documentation_pattern() {
 
     // Minimal documentation
     let content = "# MyLib\n\n## Overview\n\n## Installation\n\n## License";
-    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 
     // Full documentation with all optional sections
     let content = "# MyLib\n\n## Overview\n\n## Features\n\n## Screenshots\n\n## Installation\n\n## Usage\n\n## API Reference\n\n## Examples\n\n## License";
-    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 
     // Missing required section should fail
     let content = "# MyLib\n\n## Overview\n\n## Features\n\n## License";
-    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(!result.is_empty());
 }
