@@ -6,7 +6,7 @@ use rumdl_lib::rules::MD047SingleTrailingNewline;
 fn test_valid_file_end_newline() {
     let rule = MD047SingleTrailingNewline;
     let content = "Some text\nMore text\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -15,7 +15,7 @@ fn test_valid_file_end_newline() {
 fn test_missing_file_end_newline() {
     let rule = MD047SingleTrailingNewline;
     let content = "Some text\nMore text";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(!result.is_empty());
 }
@@ -24,7 +24,7 @@ fn test_missing_file_end_newline() {
 fn test_multiple_file_end_newlines() {
     let rule = MD047SingleTrailingNewline;
     let content = "Some text\nMore text\n\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     // MD047 only checks for presence of trailing newline, not multiple
     // MD012 handles multiple consecutive blank lines
@@ -35,7 +35,7 @@ fn test_multiple_file_end_newlines() {
 fn test_fix_file_end_newline() {
     let rule = MD047SingleTrailingNewline;
     let content = "Some text\nMore text";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.fix(&ctx).unwrap();
     assert_eq!(result, "Some text\nMore text\n");
 }
