@@ -23,11 +23,13 @@ mod md026_kramdown_test;
 mod md026_test;
 mod md027_test;
 mod md028_test;
+mod md029_broken_continuation_test;
 mod md029_code_block_separation_test;
 mod md029_fix_test;
 mod md029_issue42_test;
 mod md029_markdownlint_parity_test;
 mod md029_nested_list_continuation_test;
+mod md029_pathological_edge_cases_test;
 mod md029_test;
 mod md030_test;
 mod md031_kramdown_test;
@@ -37,6 +39,7 @@ mod md033_blockquote_test;
 mod md033_kramdown_test;
 // mod md033_extended_test; // Temporarily disabled - needs LintContext fixes
 mod md033_test;
+mod md034_comprehensive_test;
 mod md034_ipv6_test;
 mod md034_test;
 mod md035_test;
