@@ -16,7 +16,7 @@ use rumdl_lib::rules::*;
 /// 2. Applying the fix replacement text to that warning range only
 /// 3. Returning the result
 fn simulate_vscode_fix(content: &str, rule: &dyn Rule) -> Result<String, String> {
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let warnings = rule.check(&ctx).map_err(|e| format!("Check failed: {e:?}"))?;
 
     if warnings.is_empty() {
@@ -71,7 +71,10 @@ fn simulate_vscode_fix(content: &str, rule: &dyn Rule) -> Result<String, String>
 /// Helper function to create test cases for each rule
 fn create_test_case_for_rule(rule_name: &str) -> Option<(&'static str, Box<dyn Rule>)> {
     match rule_name {
-        "MD001" => Some(("# H1\n### H3 (should be H2)", Box::new(MD001HeadingIncrement))),
+        "MD001" => Some((
+            "# H1\n### H3 (should be H2)",
+            Box::new(MD001HeadingIncrement::default()),
+        )),
         "MD003" => Some(("# ATX\nSetext\n======", Box::new(MD003HeadingStyle::default()))),
         "MD004" => Some((
             "* Item 1\n- Item 2",
@@ -123,7 +126,7 @@ fn create_test_case_for_rule(rule_name: &str) -> Option<(&'static str, Box<dyn R
             "Text\n```\ncode\n```\nText",
             Box::new(MD031BlanksAroundFences::default()),
         )),
-        "MD032" => Some(("Text\n* List item\nText", Box::new(MD032BlanksAroundLists))),
+        "MD032" => Some(("Text\n* List item\nText", Box::new(MD032BlanksAroundLists::default()))),
         "MD033" => Some(("Text with <div>HTML</div>", Box::new(MD033NoInlineHtml::default()))),
         "MD034" => Some(("Visit https://example.com", Box::new(MD034NoBareUrls))),
         "MD035" => Some(("Text\n***\nText", Box::new(MD035HRStyle::default()))),
@@ -260,7 +263,9 @@ mod tests {
     fn test_md023_various_indentations() {
         let rule = MD023HeadingStartLeft;
 
-        let test_cases = vec![("  # H1", "# H1"), ("    ## H2", "## H2"), ("\t### H3", "### H3")];
+        // Note: 4+ spaces create code blocks per CommonMark, so test with max 3 spaces
+        // Tab before heading is handled by MD010, not MD023 (per markdownlint-cli)
+        let test_cases = vec![("  # H1", "# H1"), ("   ## H2", "## H2")];
 
         for (input, expected) in test_cases {
             let result = simulate_vscode_fix(input, &rule).unwrap();
@@ -315,7 +320,7 @@ mod tests {
 
     #[test]
     fn test_md032_vscode_fix_no_duplication() {
-        let rule = MD032BlanksAroundLists;
+        let rule = MD032BlanksAroundLists::default();
         let content = "Text\n* List item\nMore text";
 
         let result = simulate_vscode_fix(content, &rule);
